


/* 
   def.h 1.0
   Ben Allanach 27.02.2001
   
   Contains switches and default parameters
*/



#ifndef DEF_H
#define DEF_H

// For debugging purposes: how much output do you want?
// 0 None extra
// >0 mu, B on each iteration and initial data input
// >1 run down from MX to mt after convergence 
// >2 prints out sub-iteration information
const int PRINTOUT = 0;
const double EPS = 1.0e-3; // Accuracy of Runge-Kutta 

const double EPSTOL = 1.0e-14 / EPS;
const double PI = atan(1.0) * 4.0; // or 3.141592653589793 longhand;

// particle data book 2000 central values
const double GMU = 1.16637e-5;
const double MZ = 91.1882;
const double MW = 80.419;
const double ALPHAEM0 = 1.0 / 137.0359895; // hep-ph/9501277: update!

// masses, running
const double MUP = 2.5e-3;
const double MDOWN = 0.006;
const double MSTRANGE = 0.1225;
const double MCHARM = 1.25;
const double MBOTTOM = 4.2;
const double MTOP = 165.0;
const double MELECTRON = 5.10998902e-4;
const double MMUON = 1.05658357e-1;
const double MTAU = 1.77703;
const double ALPHASMZ = 0.1181;
const double ALPHAMZ = 1.0 / 127.9;

// masses, pole
const double PMTOP = 173.8;
const double PMBOTTOM = 4.9;

// errors
const double SIGMABOTTOM = 0.20;
const double SIGMATOP = 5.1;
const double SIGMAALPHASMZ = 0.002;

// limits on particle masses
const double LOWER_TANB_HIGGS_BOUND = 99.8;
const double HIGHER_TANB_HIGGS_BOUND = 89.3;
// the following are collated in hep-ph/9907331
const double NEUTRALINO_BOUND = 37.0; // from ALEPH hep-ex/0011047
const double CHARGINO_BOUND = 84.0;
const double SNEUTRINO_BOUND = 43.1;
const double SLEPTON_BOUND = 80.0;
const double SQUARK_BOUND = 250.0;
const double STOP_BOUND = 83.0;
const double SBOTTOM_BOUND = 83.0;
const double GLUINO_BOUND = 300.0;

char * dir(char a[80]);

#endif
