

/* 
   lowe.h
   Ben Allanach 27.02.2001

   QedQcd object contains Standard Model quark and lepton masses.
   It integrates them using 3 loop qcd x 1 loop qed effective theory.
*/

#ifndef LOWE_H
#define LOWE_H

#include<iostream.h>
#include<string.h>
#include<math.h>
#include<fstream.h>
#include<linalg.h>
#include<rge.h>

#include<def.h>

typedef enum {mUp=1, mCharm, mTop, mDown, mStrange, mBottom, mElectron,
	      mMuon, mTau} mass;
typedef enum {ALPHA=1, ALPHAS} leGauge;

DoubleVector gaugeDerivs(double, const DoubleVector &);

class QedQcd;
//  external object temp used to get objects into external routines, however:
//  don't use it!
static QedQcd *tempLe;

/* --------------RGELowe starts here------------ */
class QedQcd: public RGE
{
private:
  DoubleVector a;   // gauge couplings
  DoubleVector mf;  // fermion running masses
  double mtPole;
  
public:
  QedQcd();
  QedQcd(const QedQcd &);
  const QedQcd& operator=(const QedQcd & m);
  
  void setPoleMt(double mt) { mtPole = mt; };
  void setMass(mass mno, double m) { mf(mno) = m; };
  void setAlpha(leGauge ai, double ap) { a(ai) = ap; }; 
  void set(const DoubleVector &);     // For exporting beta functions to Runge-Kutta
  
  double displayPoleMt() const { return mtPole; };
  DoubleVector displayMass() const { return mf; };
  double displayMass(mass mno) const { return mf.display(mno); };
  double displayAlpha(leGauge ai) const { return a.display(ai); };
  DoubleVector display() const;
  
  int flavours(double) const;  // returns number of active flavours
  
  // Individual contributions to beta functions: alphaS, alphaEm, masses
  double qedBeta() const;
  double qcdBeta() const;
  void massBeta(DoubleVector &) const;
  DoubleVector beta() const;
  
  // Does not run the masses
  void runGauge(double, double);
  // Evolves object to running top mass
  void toMt();
  void toMz();
  DoubleVector  getGaugeMu(const double m2, const
		     double sinth) const;
};

// Input numbers into the object: by file stream
ostream & operator <<(ostream &, const QedQcd &);
istream & operator >>(istream &left, QedQcd &m);
void readIn(QedQcd &, char [80]); // or from a file

double getRunMt(double poleMt, double asmt);
double getAsmt(double mtop, double alphasMz);
double getRunMtFromMz(double poleMt, double asMZ);

inline QedQcd::QedQcd(const QedQcd &m)
  : a(m.a), mf(m.mf), mtPole(m.mtPole) { 
  setPars(11); 
  setMu(m.displayMu());
  setLoops(m.displayLoops());
  setThresholds(m.displayThresholds());
}

#endif

