
/*
  numerics.h 1.0
  Ben Allanach 27.02.2001

  Integration of ODEs by Runge Kutta, minimum finding and derivative
  calculation
 */

#ifndef NUMERICS_H
#define NUMERICS_H

#include "linalg.h"
void rungeKuttaStep(const DoubleVector & y, const DoubleVector & dydx, 
	     double x, double h, DoubleVector & yout, DoubleVector & yerr, 
	     DoubleVector (*derivs)(double, const DoubleVector &));

void odeStepper(DoubleVector & y, const DoubleVector & dydx, double *x, double
		htry, double eps, DoubleVector & yscal, double *hdid, 
		double *hnext,		
		DoubleVector (*derivs)(double, const DoubleVector &));

int integrateOdes(DoubleVector & ystart, double x1, double x2, double eps,
		  double h1, double hmin, 
		  DoubleVector (*derivs)(double, const DoubleVector &),
		  void (*rkqs)
		  (DoubleVector & y, const DoubleVector & dydx, double *x,
		   double htry, double eps, DoubleVector & yscal, double
		   *hdid, double *hnext, 
		   DoubleVector (*derivs)(double, const DoubleVector &)));

double calcDerivative(double (*func)(double), 
		     double x, double h, double *err);

double findMinimum(double ax, double bx, double cx, double (*f)(double),
		   double tol, double *xmin);

void shft2(double & a, double & b, double & c);
void shft3(double & a, double & b, double & c, double & d);

#endif
