
#include "rge.h"

// External variables required for Runge-Kutta
int kmax = 0, kount;
double *xp, **yp, dxsav;

// runto/run functions return >0 if there's a problem with the running
int RGE::runto(double x2, double eps)
{
  double x1 = this -> displayMu();
  return run(x1, x2, eps);
}

int RGE::run(double x1, double x2, double eps)
{
  int h = howMany(); 
  tempRge = this;
  DoubleVector y(this -> display());
  int err = callRK(x1, x2, y, allDerivs, eps);
  this -> set(y);
  tempRge -> setMu(x2);
  return err;
}

// Runge-Kutte user defined routine: given log renorm scale x and the dependent
// variables y of an RGE, will calculate the derivitives dydx.
DoubleVector allDerivs(double x, const DoubleVector & y)
{
  tempRge->setMu(exp(x));
  tempRge->set(y);
  return tempRge->beta();
}

//Does the actual calling of Runge Kutta: default precision is EPS defined in
//def.h
//Returns >0 if there's a problem with the running
int RGE::callRK(double x1, double x2, DoubleVector & v,
		DoubleVector (*derivs)(double, const DoubleVector &), double eps)
{
  // x1 == x2 with high precision
  if (close(x1, x2, EPSTOL)) return 0;

  // RGE in terms of natural log of renormalisation scale
  double from = log(x1);
  double to = log(x2);

  double guess = (from - to) * 0.1; //first step size
  double hmin = (from - to) * eps * 1.0e-5; 

  // NB EPS defined in 'def.h'  
  int err =
    integrateOdes(v, from, to, eps, guess, hmin, derivs, odeStepper);
  
  setMu(x2);
  return err;
}
 

 
