
#include "softsusy.h"

const sPhysical & sPhysical::operator=(const sPhysical &s) {
  if (this == &s) return *this;
  mhiggs = s.mhiggs; msnu = s.msnu; 
  mch = s.mch; mneut = s.mneut; mixNeut = s.mixNeut;
  thetaL = s.thetaL; thetaR = s.thetaR; mGluino = s.mGluino;
  thetat = s.thetat; thetab = s.thetab; thetatau = s.thetatau;
  mu = s.mu; md = s.md; me = s.me; thetaH = s.thetaH;
  t1OV1Ms = s.t1OV1Ms; t2OV2Ms = s.t2OV2Ms;
  aChi0ChicW = s.aChi0ChicW; bChi0ChicW = s.bChi0ChicW;
  return *this;
}

ostream & operator <<(ostream &st, const sProblem & p) {
  if (!p.test()) return st;
  st << "[ ";
  if (p.nonperturbative) st << "Non-perturbative ";
  if (p.noConvergence) st << "No convergence ";
  if (p.tachyon) st << "Tachyon ";
  if (p.muSqWrongSign) st << "MuSqWrongsign ";
  if (p.b) st << "B-problem ";
  if (p.higgsUfb) st << "Higgs potential ufb ";
  st << "]";
  return st;
};

const sProblem & sProblem::operator=(const sProblem &s) {
  if (this == &s) return *this;
  nonperturbative=s.nonperturbative;
  noConvergence=s.noConvergence;
  tachyon=s.tachyon;
  muSqWrongSign=s.muSqWrongSign;
  higgsUfb =s.higgsUfb;
  b=s.b;
  return *this;
}

const MssmSoftsusy & MssmSoftsusy::operator=(const MssmSoftsusy & s) {
  if (this == &s) return *this;
  mGaugino = s.mGaugino;
  physpars = s.physpars;
  problem = s.problem;
  ua = s.ua;
  da = s.da;
  ea = s.ea;
  mQLsq = s.mQLsq;
  mURsq = s.mURsq;
  mDRsq = s.mDRsq;
  mLLsq = s.mLLsq;
  mSEsq = s.mSEsq;
  m32 = s.m32;
  b = s.b;
  mH1sq = s.mH1sq;
  mH2sq = s.mH2sq;
  minV = s.minV;
  setSusy(s.displaySusy());
  higgsVevMs = s.higgsVevMs;
  dataSet = s.dataSet;
  setMu(s.displayMu());
  setLoops(s.displayLoops());
  setThresholds(s.displayThresholds());
  return *this;
}

DoubleMatrix MssmSoftsusy::displayTrilinear(trilinears k) const {
  switch(k) {
  case UA: return ua; break;
  case DA: return da; break;
  case EA: return ea; break;
  }
  DoubleMatrix temp(3, 3);
  return temp;
}

// Will display zero if that's what the A term is regardless of what the
// Yukawa coupling is (even if it's zero).
double MssmSoftsusy::displaySoftA(trilinears k, int i, int j) const {
  double am = displayTrilinear(k)(i, j);
  if (fabs(am) < EPS) return 0.0;
  
  if (fabs(displayYukawaElement(yukawa(k), i, j)) < 1.0e-10) {
    cout << "WARNING: asking for MssmSoftsusy::displaySoftA(" << k << "," 
	 << i << "," << j << "), where Yukawa coupling is " <<
      fabs(displayYukawaElement(yukawa(k), i, j)) << endl;
    exit(1);
  }
  double temp = displayTrilinear(k)(i, j) 
    / displayYukawaElement(yukawa(k), i, j); 
  return temp;
}

DoubleMatrix MssmSoftsusy::displaySoftMassSquared(softMasses k) const {
  switch(k) {
  case mQl: return mQLsq; break;
  case mUr: return mURsq; break;
  case mDr: return mDRsq; break;
  case mLl: return mLLsq; break;
  case mEr: return mSEsq; break;
  }
  DoubleMatrix temp(3, 3);
  return temp;
}

DoubleVector MssmSoftsusy::display() const {
  DoubleVector y(MssmSusy::display());
  y.setEnd(110);
  int i, j, k=32;
  for (i=1; i<=3; i++) {
    k++;
    y(k) = displayGaugino()(i);
  }
  
  for (i=1; i<=3; i++)    
    for (j=1; j<=3; j++) {
      k++;
      y(k) = displayTrilinear(UA)(i, j);
      y(k+9) = displayTrilinear(DA)(i, j);
      y(k+18) = displayTrilinear(EA)(i, j);
      y(k+27) = displaySoftMassSquared(mQl)(i, j);
      y(k+36) = displaySoftMassSquared(mUr)(i, j);
      y(k+45) = displaySoftMassSquared(mDr)(i, j);
      y(k+54) = displaySoftMassSquared(mLl)(i, j);
      y(k+63) = displaySoftMassSquared(mEr)(i, j);
    }
  y(108) = b;
  y(109) = mH1sq;
  y(110) = mH2sq;
  return y;
}

void MssmSoftsusy::setSoftMassElement(softMasses k, int i, int j, 
					  double f) { 
  switch(k) {
  case mQl: mQLsq(i, j) = f; break;
  case mUr: mURsq(i, j) = f; break;
  case mDr: mDRsq(i, j) = f; break;
  case mLl: mLLsq(i, j) = f; break;
  case mEr: mSEsq(i, j) = f; break;
  }
}

void MssmSoftsusy::setSoftMassMatrix(softMasses k, const DoubleMatrix & m) { 
  switch(k) {
  case mQl: mQLsq = m; break;
  case mUr: mURsq = m; break;
  case mDr: mDRsq = m; break;
  case mLl: mLLsq = m; break;
  case mEr: mSEsq = m; break;
  }
}

void MssmSoftsusy::setTrilinearMatrix(trilinears k, const DoubleMatrix & m) { 
  switch(k) {
  case UA: ua = m; break;
  case DA: da = m; break;
  case EA: ea = m; break;
  }
}

void MssmSoftsusy::setTrilinearElement(trilinears k, int i, int j, 
					  double m) { 
  switch(k) {
  case UA: ua(i, j) = m; break;
  case DA: da(i, j) = m; break;
  case EA: ea(i, j) = m; break;
  }
}

void MssmSoftsusy::setAllGauginos(const DoubleVector & v) { 
  if (v.displayStart() != 1 || v.displayEnd() !=3) {
    cout << "Initialising MssmSoftsusy::setAllGauginos with vector"
	 << v;
    exit(1);
  }
  mGaugino = v; 
}

// resets soft terms ONLY
void MssmSoftsusy::setSoft(const MssmSoftsusy & a) {
  setTrilinearMatrix(UA, a.displayTrilinear(UA));
  setTrilinearMatrix(DA, a.displayTrilinear(DA));
  setTrilinearMatrix(EA, a.displayTrilinear(EA));
  setSoftMassMatrix(mQl, a.displaySoftMassSquared(mQl));
  setSoftMassMatrix(mUr, a.displaySoftMassSquared(mUr));
  setSoftMassMatrix(mDr, a.displaySoftMassSquared(mDr));
  setSoftMassMatrix(mLl, a.displaySoftMassSquared(mLl));
  setSoftMassMatrix(mEr, a.displaySoftMassSquared(mEr));
  setB(a.displayB());
}

void MssmSoftsusy::setSusy(const MssmSusy & s) {
  setLoops(s.displayLoops());
  setThresholds(s.displayThresholds());
  setMu(s.displayMu());
  setYukawaMatrix(YU, s.displayYukawaMatrix(YU)); 
  setYukawaMatrix(YD, s.displayYukawaMatrix(YD)); 
  setYukawaMatrix(YE, s.displayYukawaMatrix(YE)); 
  setTanb(s.displayTanb());
  setSusyMu(s.displaySusyMu());
  setAllGauge(s.displayGauge());
}

void MssmSoftsusy::set(const DoubleVector & y) {
  MssmSusy::set(y);
  int i, j, k=32;
  for (i=1; i<=3; i++) {
    k++;
    mGaugino(i) = y.display(k);
  }
  
  for (i=1; i<=3; i++)
    for (j=1; j<=3; j++) {
      k++;
      ua(i, j) = y.display(k);
      da(i, j) = y.display(k+9);
      ea(i, j) = y.display(k+18);
      mQLsq(i, j) = y.display(k+27);
      mURsq(i, j) = y.display(k+36);
      mDRsq(i, j) = y.display(k+45);
      mLLsq(i, j) = y.display(k+54);
      mSEsq(i, j) = y.display(k+63);
    }
  b = y.display(108);
  mH1sq = y.display(109);
  mH2sq = y.display(110);
}


// Outputs derivatives (DRbar scheme) in the form of dsoft
// thresholds = 0 and NOTHING is decoupled.
// thresholds = 2 and SUSY params/gauge couplings are decoupled at sparticle
// thresholds.
MssmSoftsusy MssmSoftsusy::beta2() const {
  //  susypars beta functions are defined in the
  //  Allanach, Dedes, Dreiner hep-ph/9906209 paper notation 
  //  W=  LL Y^E H1 ER + QL Y^D H1 DR + QL Y^U H2 UR + smu H1 H2, 
  //  (implicit epsilonAb phi^a phi^b a,b=Su(2) indices present where
  //  epsilon12 = +1, epsilon21 = -1, other components zero
  //  The following equations are for Barger, Berger and Ohmann's conventions
  //  with the same W: hep-ph/9209232, 9311269
  //  VTri = UR ua QL H2 + DR da QL H1 + ER ea LL H1 + m3 H1 H2 +hc
  //  VBi  = mH1sq |H1|^2 + mH2sq |H2|^2 + Q^* mQLsq Q + L^* mLLsq L +
  //          UR MuR UR^* + DR MDR DR^* + ER MER ER^*
  // Note in particular that ua(3,3) is NOT AT. AT = ua(3, 3) / ht.
  
  // Constants for gauge running
  static DoubleVector bBeta(3), cuBeta(3), cdBeta(3), ceBeta(3);
  static DoubleMatrix babBeta(3, 3);
  
  if (bBeta(1) < 1.0e-5) // Constants not set yet
    setBetas(babBeta, cuBeta, cdBeta, ceBeta, bBeta);
  
  // For calculational brevity: 
  static sBrevity a;
  // convert to beta functions
  static MssmSusy dsb;
  
  // calculate derivatives for full SUSY spectrum. Brevity calculations come
  // out encoded in a
  dsb = MssmSusy::beta(a);
  
  static DoubleVector g1(3);
  g1 = displayGauge();
  
  // To keep this a const function: TIME SAVINGS
  DoubleMatrix &u1=a.u1, &d1=a.d1, &e1=a.e1;
  DoubleMatrix &u2=a.u2, &d2=a.d2, &e2=a.e2,
    &u2t=a.u2t, &d2t=a.d2t, &e2t=a.e2t, &dt=a.dt, &ut=a.ut, &et=a.et;      
  double &uuT = a.uuT, &ddT = a.ddT, &eeT = a.eeT;
  DoubleVector &gsq=a.gsq, &g3=a.g3, &g4=a.g4;
  
  static DoubleMatrix hu(3, 3), hd(3, 3), he(3, 3);
  static DoubleMatrix hut(3, 3), hdt(3, 3), het(3, 3);
  static DoubleMatrix hu2(3, 3), hd2(3, 3), he2(3, 3);
  static DoubleMatrix hu2t(3, 3), hd2t(3, 3), he2t(3, 3);
  static DoubleMatrix mq(3, 3), mu(3, 3), md(3, 3), ml(3, 3), me(3, 3);
  static DoubleVector mG(1, 3), msq(1, 3), gsqM(1, 3), gMsq(1, 3);
  
  hu = displayTrilinear(UA); hd = displayTrilinear(DA); 
  he = displayTrilinear(EA); 
  hut = hu.transpose(); hdt = hd.transpose(); het = he.transpose();
  hu2 = hu * hut; hd2 = hd * hdt; he2 = he * het;
  double huT = hu2.trace(), hdT = hd2.trace(), heT = he2.trace();
  hu2t = hut * hu; hd2t = hdt * hd; he2t = het * he;
  mq = displaySoftMassSquared(mQl); mu = displaySoftMassSquared(mUr);
  md = displaySoftMassSquared(mDr);
  ml = displaySoftMassSquared(mLl); me = displaySoftMassSquared(mEr); 
  double mqT = mq.trace(), muT = mu.trace(), mdT = md.trace(), meT =
    me.trace(), mlT = ml.trace();
  
  double huuT = (hu * ut).trace(), hddT = (hd * dt).trace(), 
    heeT = (he * et).trace(); 
  mG = mGaugino; msq = mG * mG; gsqM = gsq * mG; gMsq = gsq * msq;
  static const double oneO15 = 1.0 / 15.0;
  
  // derivatives of soft parameters
  static DoubleVector dmG(1, 3);
  static double dmH1sq, dmH2sq, dB;
  static DoubleMatrix dmq(3, 3), dmu(3, 3), dmd(3, 3), dme(3, 3), dml(3, 3);
  static DoubleMatrix dhu(3, 3), dhd(3, 3), dhe(3, 3);
  
  const double ONEO16Pisq = 1.0 / (16 * sqr(PI));
  if (displayLoops() > 0) {
    const static double sixteenO3 = 16.0 / 3.0, oneO15 = 1.0 /
      15.0;
    
    dmG = gsqM * 2.0 * bBeta;
    
    double curlyS = mH2sq - mH1sq + mqT - mlT - 2 * muT + mdT + meT;
    
    dB = 2.0 * (0.6 * gsqM(1) + 3 * gsqM(2) + 3 * (u1 * hu).trace()  + 
		3 * (d1 * hd).trace() + (e1 * he).trace());
    
    dmH1sq = 2.0 * 
      (-0.3 * gsq(1) * curlyS - 0.6 * gMsq(1) - 3.0 * gMsq(2) +
       3.0 * (mH1sq * ddT + (d2t * (mq + md)).trace() + hdT) +
       (mH1sq * eeT + (e2t * (ml + me)).trace() + heT));
    
    dmH2sq = 2.0 * 
      (0.3 * gsq(1) * curlyS - 0.6 * gMsq(1) - 3.0 * gMsq(2) +
       3.0 * (mH2sq * uuT + (u2t * (mq + mu)).trace() + huT));
    
    dmq = 2.0 *
      (0.1 * gsq(1) * curlyS - oneO15 * gMsq(1) - 3.0 * gMsq(2) -
       sixteenO3 * gMsq(3) +
       0.5 * (u2 * mq + mq * u2 + 2.0 * (u1 * mu * ut + mH2sq * u2 + hu2))
       + 0.5 * (d2 * mq + mq * d2 + 2.0 * (d1 * md * dt + mH1sq * d2 +
					   hd2)));
    
    dml = 2.0 *
      ( -0.3 * gsq(1) * curlyS - 0.6 * gMsq(1) - 3.0 * gMsq(2) + 
	0.5 * (e2 * ml + ml * e2 + 2.0 * (e1 * me * et + mH1sq * e2 + he2)));
    
    dmu = 2.0 *
      (-0.4 * gsq(1) * curlyS - 16 * oneO15 * gMsq(1) - sixteenO3 *
       gMsq(3) + 
       (u2t * mu + mu * u2t + 2.0 * (ut * mq * u1 + mH2sq * u2t + hu2t)));
    
    dmd = 2.0 *
      (0.2 * gsq(1) * curlyS - 4.0 * oneO15 * gMsq(1) - sixteenO3 *
       gMsq(3) + 
       (d2t * md + md * d2t + 2.0 * (dt * mq * d1 + mH1sq * d2t + hd2t)));
    
    dme = 2.0 *
      (0.6 * gsq(1) * curlyS - 36 * oneO15 * gMsq(1) +
       (e2t * me + me * e2t + 2.0 * (et * ml * e1 + mH1sq * e2t + he2t)));
    
    
    dhu = (-sixteenO3 * gsq(3) - 3 * gsq(2) - 13 * oneO15 * gsq(1))
      * hu
      + 2 * (13.0 * oneO15 * gsqM(1) + 3 * gsqM(2) + sixteenO3
	     * gsqM(3)) * u1 +
      4.0 * hu * u2t + 6.0 * huuT * u1 + 5.0 * u2 * hu + 3.0 *
      uuT * hu + 2.0 * hd * dt * u1 + d2 * hu;
    
    dhd = (-sixteenO3 * gsq(3) - 3 * gsq(2) - 7 * oneO15 * gsq(1)) *
      hd 
      + 2 * (7 * oneO15 * gsqM(1) + 3 * gsqM(2) + sixteenO3
	     * gsqM(3)) * d1 +
      4.0 * hd * d2t + 6.0 * hddT * d1 + 5.0 * d2 * hd + 3.0 *
      ddT * hd + 2.0 * hu * ut * d1 + u2 * hd + 2.0 * heeT * d1 + eeT
      * hd;
    
    dhe = (- 3 * gsq(2) - 1.8 * gsq(1)) * he
      + 2 * (1.8 * gsqM(1) + 3 * gsqM(2)) * e1 +
      4.0 * he * e2t + 2.0 * heeT * e1 + 5.0 * e2 * he + 
      eeT * he + 6.0 * hddT * e1 + 3 * ddT * he;
    
    // convert to proper derivatives: 
    dmG = dmG * ONEO16Pisq;
    dB = dB * ONEO16Pisq;
    dmH1sq = dmH1sq * ONEO16Pisq;
    dmH2sq = dmH2sq * ONEO16Pisq;
    dmq = dmq * ONEO16Pisq;
    dml = dml * ONEO16Pisq;
    dmu = dmu * ONEO16Pisq;
    dmd = dmd * ONEO16Pisq;
    dme = dme * ONEO16Pisq;
    dhu = dhu * ONEO16Pisq;
    dhd = dhd * ONEO16Pisq;
    dhe = dhe * ONEO16Pisq;
  }
  
  // two-loop contributions. I got these from hep-ph/9311340. WIth respect to
  // their notation, the Yukawas and h's are TRANSPOSED. Gaugino masses are
  // identical, as are soft masses. B(mV) = mu(BBO) B(BBO)
  if (displayLoops() > 1) {
    static DoubleVector dmG2(1, 3);
    /*      static double dmH1sq2, dmH2sq2, dB2;
	    static DoubleMatrix dmq2(3, 3), dMu2(3, 3), dMd2(3, 3), dme2(3, 3), 
	    dml2(3, 3);
	    static DoubleMatrix dHu2(3, 3), dHd2(3, 3), dHe2(3, 3);
	    */    
    const double oneO16Pif = sqr(ONEO16Pisq);
    
    dmG2 = 2.0 * gsq * 
      (babBeta * gsqM + mG * (babBeta * gsq) + 
       cuBeta * huuT - cuBeta * mG * uuT + 
       cdBeta * hddT - cdBeta * mG * ddT + 
       cdBeta * heeT - ceBeta * mG * eeT); // checked
    
    dmG = dmG + dmG2 * oneO16Pif;
    /*          dB = dB + dB2 * oneO16Pif;
	    dmH1sq = dmH1sq + dmH1sq2 * oneO16Pif;
	    dmH2sq = dmH2sq + dmH2sq2 * oneO16Pif;
	    dmq = dmq + dmq2 * oneO16Pif;
	    dml = dml + dml2 * oneO16Pif;
	    dmu = dmu + dmu2 * oneO16Pif;
	    dmd = dmd + dmd2 * oneO16Pif;
	    dmE = dmE + dme2 * oneO16Pif;
	    dHu = dHu + dHu2 * oneO16Pif;
	    dHd = dHd + dHd2 * oneO16Pif;
	    dHE = dHE + dHe2 * oneO16Pif;*/
  }
  
  static sPhysical dsph;
  
  MssmSoftsusy dsoft(dsb, dsph, dmG, dhu, dhd, dhe, dmq, dmu,
		      dmd, dml, dme, dB, dmH1sq, dmH2sq, displayMu(),
		      displayLoops(), displayThresholds(), 0, 0, 0.0);
  
  return dsoft;
}

// Outputs derivatives vector y[109] for SUSY parameters: interfaces to
// integration routines
DoubleVector MssmSoftsusy::beta() const {
  // calculate the derivatives
  static MssmSoftsusy dsoft; dsoft = beta2();
  
  return dsoft.display(); // convert to a long vector
}

/* 
   Give it a SUSY object and a value of M3/2, and it will return a soft
   object with AMSB soft breaking terms. Note that the sleptons will be
   tachyonic, ie nothing has been done to fix that problem.
   Note that in the following, we are neglecting all Yukawa couplings except
   that of the third family.
   
   THE CURRENT STATE OF PLAY:
   trilinear and gauge interactions will generalise to two loops OK
   trilinear interactions have full flavour structure
   soft scalar masses are ONE LOOP ONLY, with 3rd family approximation and no
   particular flavour structure. However, should you require full flavour
   structure (for example for FCNC constraints), this should be relatively
   easy to incorporate. Two loop additions are possible, but a pain.
   */
void MssmSoftsusy::addAmsb() {
  double m32 = displayGravitino();
  MssmSusy run(displaySusy());
  const double ONEO16pisq = 1.0 / (16. * sqr(PI));
    
  double 
    yt   = run.displayYukawaElement(YU, 3, 3), 
    yb   = run.displayYukawaElement(YD, 3, 3), 
    ytau = run.displayYukawaElement(YE, 3, 3),
    g1   = run.displayGauge()(1), 
    g2   = run.displayGauge()(2), 
    g3   = run.displayGauge()(3); 
  
  // gauge parts of beta functions
  double Xu = -13.0 / 15.0 * sqr(g1) - 3.0 * sqr(g2) - 16.0 / 3.0 * sqr(g3);
  double Xd = -7.0 / 15.0 * sqr(g1) - 3.0 * sqr(g2) - 16.0 / 3.0 * sqr(g3);
  double Xe = -9 / 5.0 * sqr(g1) - 3.0 * sqr(g2);
  
  // Yukawa parts
  double betayt   = yt *   (Xu + 6.0 * sqr(yt) + sqr(yb));
  double betayb   = yb *   (Xd + 6.0 * sqr(yb) + sqr(yt) + sqr(ytau));
  double betaytau = ytau * (Xe + 3.0 * sqr(yb) + 4.0 * sqr(ytau));
  
  const double ONEO16pif = sqr(ONEO16pisq);

  // Higgs
  double mhusq = ONEO16pif * sqr(m32) * 
    (-99. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)) + 3.0 * yt * betayt);
  double mhdsq = ONEO16pif * sqr(m32) * 
    (-99. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)) + 3.0 * yb * betayb + ytau
     * betaytau);
  
  // third generation
  double mstoprsq = ONEO16pif * sqr(m32) * 
    (-88. / 25. * sqr(sqr(g1)) + 8.0 * sqr(sqr(g3)) + 2.0 * yt * betayt);
  double msbottomrsq = ONEO16pif * sqr(m32) * 
    (-22. / 25. * sqr(sqr(g1)) + 8.0 * sqr(sqr(g3)) + 2.0 * yb * betayb);
  double mQl3sq = ONEO16pif * sqr(m32) * 
    (-11. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)) + 8.0 * sqr(sqr(g3)) + yb *
     betayb + yt * betayt);
  
  double mL3sq = ONEO16pif * sqr(m32) * 
    (-99. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)) + ytau
     * betaytau);
  double mstaursq = ONEO16pif * sqr(m32) * 
    (-198. / 25. * sqr(sqr(g1)) + 2.0 * ytau * betaytau);
  
  // other generations
  double mursq = ONEO16pif * sqr(m32) * 
    (-88. / 25. * sqr(sqr(g1)) + 8.0 * sqr(sqr(g3)));
  double mdrsq = ONEO16pif * sqr(m32) * 
    (-22. / 25. * sqr(sqr(g1)) + 8.0 * sqr(sqr(g3)));
  double mQlsq = ONEO16pif * sqr(m32) * 
    (-11. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)) + 8.0 * sqr(sqr(g3)));
  double mLsq = ONEO16pif * sqr(m32) * 
    (-99. / 50. * sqr(sqr(g1)) - 1.5 * sqr(sqr(g2)));
  double mersq = ONEO16pif * sqr(m32) * 
    (-198. / 25. * sqr(sqr(g1)));
  
  mQLsq(1, 1) = mQLsq(1, 1) + mQlsq;
  mQLsq(2, 2) = mQLsq(2, 2) + mQlsq;
  mQLsq(3, 3) = mQLsq(3, 3) + mQl3sq;
  mURsq(1, 1) = mURsq(1, 1) + mursq;
  mURsq(2, 2) = mURsq(2, 2) + mursq;
  mURsq(3, 3) = mURsq(3, 3) + mstoprsq;
  mDRsq(1, 1) = mDRsq(1, 1) + mdrsq;
  mDRsq(2, 2) = mDRsq(2, 2) + mdrsq;
  mDRsq(3, 3) = mDRsq(3, 3) + msbottomrsq;
  mLLsq(1, 1) = mLLsq(1, 1) + mLsq;
  mLLsq(2, 2) = mLLsq(2, 2) + mLsq;
  mLLsq(3, 3) = mLLsq(3, 3) + mL3sq;
  mSEsq(1, 1) = mSEsq(1, 1) + mersq;
  mSEsq(2, 2) = mSEsq(2, 2) + mersq;
  mSEsq(3, 3) = mSEsq(3, 3) + mstaursq;
  
  mH1sq = mH1sq + mhdsq;
  mH2sq = mH2sq + mhusq;
  
  // For calculational brevity: 
  static sBrevity a;
  static MssmSusy dsb;
  
  // calculate derivatives for full SUSY spectrum. Brevity calculations come
  // out encoded in a
  dsb = MssmSusy::beta(a);
  
  // AMSB spectrum
  DoubleVector amsbGaugino(3);
  DoubleMatrix temp(3, 3);
  
  int i; for (i=1; i<=3; i++)
    amsbGaugino(i) = dsb.displayGauge()(i) * m32 / run.displayGauge()(i);
  mGaugino = mGaugino + amsbGaugino;
  
  ua = ua - dsb.displayYukawaMatrix(YU) * m32;
  da = da - dsb.displayYukawaMatrix(YD) * m32;
  ea = ea - dsb.displayYukawaMatrix(YE) * m32;
  
  return;
}

// Reads in universal boundary conditions at the current scale:
// m0, M1/2, A0, B and sign of mu
void MssmSoftsusy::universal(double m0,  double m12,  double a0,  double mu,
			      double b) {
  standardSugra(m0, m12, a0);  
  setSusyMu(mu);
  setB(b);
}

void MssmSoftsusy::universalScalars(double m0) {
  // scalar masses
  DoubleMatrix ID(3, 3), mm0(3, 3);
  int i; for (i=1; i<=3; i++) ID(i, i) = 1.0;
  mm0 = ID * sqr(m0);
  setSoftMassMatrix(mQl, mm0); setSoftMassMatrix(mUr, mm0);
  setSoftMassMatrix(mDr, mm0); setSoftMassMatrix(mLl, mm0);
  setSoftMassMatrix(mEr, mm0);
  setMh1Squared(sqr(m0)); setMh2Squared(sqr(m0));
}

void MssmSoftsusy::universalGauginos(double m12) {  
  // gaugino masses
  int i; for (i=1; i<=3; i++) setGauginoMass(i, m12);
}

void MssmSoftsusy::universalTrilinears(double a0)  {  
  // trilinears
  setTrilinearMatrix(UA, a0 * displayYukawaMatrix(YU)); 
  setTrilinearMatrix(DA, a0 * displayYukawaMatrix(YD));
  setTrilinearMatrix(EA, a0 * displayYukawaMatrix(YE));
}

// Input m0, NOT m0 squared.
void MssmSoftsusy::standardSugra(double m0,  double m12, double a0) {
  if (m0 < 0.0) {
    cout << "m0^2=" << m0 << " passed to universal boundary" <<
      "conditions illegally negative.";
    exit(1);
  }
  universalScalars(m0);
  universalGauginos(m12);
  universalTrilinears(a0);
}

// Returns mu from rewsb requirement (TREE LEVEL is default, without deltaT2)
// returns 1 if there's a problem. Call at MSusy
int MssmSoftsusy::rewsbMu(int sgnMu, double & mu) const {
  int flag = 0;
  if (fabs(sgnMu) != 1.0) {
    cerr << "Error: sign mu = " << sgnMu << "\n";
    exit(1);
  }
  double mH1sq = displayMh1Squared(), mH2sq = displayMh2Squared(), tanb =
    displayTanb(), 
    tanb2 =  sqr(tanb), v = displayHiggsVevMs(), 
    cos2b = cos(2.0 * atan(tanb)); 
  
  // One-loop relation
  double musq = (mH1sq - mH2sq * tanb2) / (tanb2 - 1.0) - 0.5 * sqr(MZ);
  
  if (musq < 0.0) {
    mu = -sgnMu * sqrt(fabs(musq)); flag = 1; // mu has incorrect sign
  }
  else
    mu = sgnMu * sqrt(musq); 
  return flag;
}

// Returns B from rewsb requirement (TREE LEVEL is default if no deltaT2)
// returns 1 if mu < 1.0e-9
int MssmSoftsusy::rewsbB(double mu, double & b) const {
  int flag = 0;
  double v = displayHiggsVevMs();
  if (fabs(mu) < 1.0e-9) 
    { flag = 1; b = 0.0; }
  else
    b =  0.5 * 
	 (mH1sq + mH2sq - displayTadpole2Ms() - displayTadpole1Ms() +
		  2.0 * sqr(mu)) * 
	 sin(2 * atan(displayTanb())) /
      mu; 
  
  // Following means no good rewsb
  if (b * mu < 0.0) flag = 1;
  
  return flag;
}

// Predicts tan beta once mu and soft terms are predicted at low energy
// Useful for fine-tuning calculation - default is for mt = 0.0, ie
// tree-level. Call at MSusy only.
double MssmSoftsusy::predTanb() const  {
  double v = displayHiggsVevMs();
  double sin2t = 2.0 * displaySusyMu() * displayB() / 
    (mH1sq - displayTadpole1Ms() + mH2sq - displayTadpole2Ms() + 2.0 *
     sqr(displaySusyMu())); 
  
  // Note: we want to take inverse sine so that fundamental domain is greater
  // than pi/4. sin(pi - 2 beta)=sin 2 beta should achieve this.
  // we also use tan (pi/2 - theta) = 1/tan(theta)
  double theta = asin(sin2t) * 0.5;
  
  return 1.0 / tan(theta);
}

// Goes into mSUGRA
// From hep-ph/9606211's appendix. It should be done at MSusy to minimize the
// 1-loop contributions. Only call if you've calculated physpars
// inputs are running top/bottom masses
// Call at MSusy only
void MssmSoftsusy::setTadpole1Ms(double mt, double sinthDRbar) { // checked

  double g = displayGaugeCoupling(2), 
    costhDRbar = cos(asin(sinthDRbar)),
    sw2DRbar = 1.0 - sqr(costhDRbar), sw2 = 1.0 - sqr(MW / MZ), 
    tanb = displayTanb(), cosb = cos(atan(tanb)), sinb = sin(atan(tanb)), 
    ht = displayYukawaElement(YU, 3, 3),
    mu = -displaySusyMu(), q = displayMu(),
    hb = displayYukawaElement(YD, 3, 3);
  
  double guL, guR, gdL, geL, gdR, geR;
  
  guL = 0.5 - 2.0 * sw2 / 3.0; 
  gdL = -0.5 + sw2 / 3.0; 
  geL = -0.5 + sw2; 
  guR = 2.0 * sw2 / 3.0; 
  gdR = -sw2 / 3.0; 
  geR = -sw2; 
  
  // sneutrino coupling
  double lSnu = g * MZ / costhDRbar * 0.5 * cosb;
  
  // stop couplings
  DoubleMatrix lTS1Lr(2, 2), lTS112(2, 2), rotate(2, 2);
  lTS1Lr(1, 1) = g * MZ / costhDRbar * guL * cosb;
  lTS1Lr(1, 2) = ht * mu / sqrt(2.0);
  lTS1Lr(2, 1) = lTS1Lr(1, 2);
  lTS1Lr(2, 2) = g * MZ / costhDRbar * guR * cosb;
  rotate = rot2d(physpars.thetat);
  
  lTS112 = rotate * lTS1Lr * rotate.transpose();
  
  // sbottom couplings
  DoubleMatrix lBS1Lr(2, 2), lBS112(2, 2);
  double mb = displayDataSet().displayMass(mBottom),
    mA = physpars.mhiggs(2), mH0 = physpars.mhiggs(3), mHp =
    physpars.mhiggs(4);
  
  lBS1Lr(1, 1) = g * MZ / costhDRbar * gdL * cosb + sqrt(2.0) * mb * hb;
  lBS1Lr(1, 2) = displayTrilinear(DA)(3, 3) / sqrt(2.0);
  lBS1Lr(2, 1) = lBS1Lr(1, 2);
  lBS1Lr(2, 2) = g * MZ / costhDRbar * gdR * cosb + sqrt(2.0) * mb * hb;
  
  rotate = rot2d(physpars.thetab);
  
  lBS112 = rotate * lBS1Lr * rotate.transpose();
  
  // stau couplings
  DoubleMatrix lTauS1Lr(2, 2), lTauS112(2, 2);
  double mtau = displayDataSet().displayMass(mTau),
    htau = displayYukawaElement(YE, 3, 3);
  
  lTauS1Lr(1, 1) = g * MZ / costhDRbar * geL * cosb + sqrt(2.0) * mtau *
    htau;
  lTauS1Lr(1, 2) = displayTrilinear(EA)(3, 3) / sqrt(2.0);
  lTauS1Lr(2, 1) = lTauS1Lr(1, 2);
  lTauS1Lr(2, 2) = g * MZ / costhDRbar * geR * cosb + sqrt(2.0) * mtau *
    htau;
  
  rotate = rot2d(physpars.thetatau);
  
  lTauS112 = rotate * lTauS1Lr * rotate.transpose();
  
  double delta = 0.0;
  
  // bottom quark, ignore others - factor (10^-2)^3 down
  delta = delta - 6.0 * sqr(displayYukawaElement(YD, 3, 3)) *
    a0(mb, q);
  double gO2mwcosb = g / (2.0 * MW * cosb);
  // third generation squarks
  delta = delta + 3.0 * gO2mwcosb * lTS112(1, 1) *
    a0(physpars.mu(1, 3), q);
  delta = delta + 3.0 * gO2mwcosb* lTS112(2, 2) *
    a0(physpars.mu(2, 3), q);
  delta = delta + 3.0 * gO2mwcosb * lBS112(1, 1) *
    a0(physpars.md(1, 3), q);
  delta = delta + 3.0 * gO2mwcosb * lBS112(2, 2) *
    a0(physpars.md(2, 3), q);
  // third generation sleptons
  delta = delta + gO2mwcosb * lTauS112(1, 1) *
    a0(physpars.me(1, 3), q);
  delta = delta + gO2mwcosb * lTauS112(2, 2) *
    a0(physpars.me(2, 3), q);
  
  delta = delta + gO2mwcosb * lSnu * a0(physpars.msnu(3), q);
  
  int family; 
  double gsqMZO2mwcw = g * MZ * gO2mwcosb * cosb / costhDRbar;
  // first two families of squarks
  for (family = 1; family <=2; family++) {
    delta = delta + 3.0 * gsqMZO2mwcw * 
      ( guL * a0(physpars.mu(1, family), q) + 
	guR * a0(physpars.mu(2, family), q)); 
    delta = delta + 3.0 * gsqMZO2mwcw * 
      ( gdL * a0(physpars.md(1, family), q) +
	gdR * a0(physpars.md(2, family), q));
  }
  
  // sleptons
  for (family = 1; family <=2; family++) {
    delta = delta + gsqMZO2mwcw * 
      (geL * a0(physpars.me(1, family), q) +
       geR * a0(physpars.me(2, family), q));
    delta = delta + gO2mwcosb * lSnu * a0(physpars.msnu(family), q);
  }
  
  // Higgs
  double alpha = displayPhys().thetaH, sina2 = sqr(sin(alpha)), 
    cosa2 = 1.0 - sina2, cos2b = cos(2.0 * atan(tanb)), 
    costhDRbar2 = sqr(costhDRbar), 
    mh = physpars.mhiggs(1), sin2a = sin(2.0 * alpha);
  delta = delta - sqr(g) * cos2b / (8.0 * costhDRbar2) *
    (a0(mA, q) + 2.0 * a0(mHp, q)) +
    sqr(g) * a0(mHp, q) * 0.5 +
    sqr(g) / (8.0 * costhDRbar2) * a0(mh, q) *
    (3.0 * sina2 - cosa2 + sin2a * tanb) +
    sqr(g) / (8.0 * costhDRbar2) * a0(mH0, q) *
    (3.0 * cosa2 - sina2 - sin2a * tanb); 
  
  // Neutralinos
  ComplexMatrix n(4, 4);
  DoubleVector mneut(4);
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions

  double tanthDRbar = tan(acos(costhDRbar));
  for (family = 1; family <= 4; family++)
    delta = delta - sqr(g) * mneut(family) / (MW * cosb) *
      (n(family, 3) * (n(family, 2) - n(family, 1) * tanthDRbar)).real() * 
      a0(mneut(family), q);
  
  // Charginos
  ComplexMatrix u(2, 2), v(2, 2); DoubleVector mch(2); 
  mpzCharginos(u, v, mch);
  for (family=1; family<=2; family++)
    delta = delta - sqrt(2.0) * sqr(g) / (MW * cosb)
      * mch(family) * (v(family, 1) * u(family, 2)).real()
	 * a0(mch(family), q);
  
  // Weak bosons
  delta = delta + 3.0 * sqr(g) / 4.0 * 
    (2.0 * a0(MW, q) + a0(MZ, q) / costhDRbar2)
    + sqr(g) * cos2b / (8.0 * costhDRbar2) * (2.0 * a0(MW, q) + a0(MZ, q));
  
  physpars.t1OV1Ms = delta / (16.0 * sqr(PI));
}

// From hep-ph/9311269's appendix. It should be done at MSusy to minimize the
// 1-loop contributions. Only call if you've calculated physpars
// inputs are running top/bottom masses. Call at MSusy
void MssmSoftsusy::setTadpole2Ms(double mt, double sinthDRbar) {// CHECKED
  if (physpars.mu(1, 3) == 0.0 || physpars.mu(2, 3) == 0.0) {
    cerr << "Trying to calculate tadpole without having first calculated";
    cerr << " the physical masses.\n";
    exit(1);
  }
  
  double g = displayGaugeCoupling(2), 
    costhDRbar = cos(asin(sinthDRbar)), 
    sw2DRbar = 1.0 - sqr(costhDRbar), tanb = displayTanb(), 
    sw2 = 1.0 - sqr(MW/MZ),
    cosb = cos(atan(tanb)), sinb = sin(atan(tanb)), 
    ht = displayYukawaElement(YU, 3, 3),
    mu = -displaySusyMu(), q = displayMu(),
    hb = displayYukawaElement(YD, 3, 3);
  
  double guL, guR, gdL, geL, gdR, geR;
  
  guL = 0.5 - 2.0 * sw2 / 3.0; 
  gdL = -0.5 + sw2 / 3.0; 
  geL = -0.5 + sw2; 
  guR = 2.0 * sw2 / 3.0; 
  gdR = -sw2 / 3.0; 
  geR = -sw2; 
  
  // Stop couplings
  DoubleMatrix lTS2Lr(2, 2), lTS212(2, 2), rotate(2, 2);
  
  lTS2Lr(1, 1) = - g * MZ / costhDRbar * guL * sinb + sqrt(2.0) * ht * mt;
  lTS2Lr(1, 2) = displayTrilinear(UA)(3, 3) / sqrt(2.0);
  lTS2Lr(2, 1) = lTS2Lr(1, 2);
  lTS2Lr(2, 2) = - g * MZ / costhDRbar * guR * sinb + sqrt(2.0) * ht * mt;
  
  rotate = rot2d(physpars.thetat);
  
  lTS212 = rotate * lTS2Lr * rotate.transpose();
  
  // sneutrino coupling
  double lSnu = - g * MZ / costhDRbar * 0.5 * sinb;
  
  // sbottom couplings
  DoubleMatrix lBS2Lr(2, 2), lBS212(2, 2);
  double mb = displayDataSet().displayMass(mBottom),
    mA = physpars.mhiggs(2), mH0 = physpars.mhiggs(3), mHp =
    physpars.mhiggs(4);
  
  lBS2Lr(1, 1) = - g * MZ / costhDRbar * gdL * sinb;
  lBS2Lr(1, 2) = hb * mu / sqrt(2.0);
  lBS2Lr(2, 1) = lBS2Lr(1, 2);
  lBS2Lr(2, 2) = - g * MZ / costhDRbar * gdR * sinb;
  
  rotate = rot2d(physpars.thetab);
  
  lBS212 = rotate * lBS2Lr * rotate.transpose();
  
  // stau couplings
  DoubleMatrix lTauS2Lr(2, 2), lTauS212(2, 2);
  double mtau = displayDataSet().displayMass(mTau),
    htau = displayYukawaElement(YE, 3, 3);
  
  lTauS2Lr(1, 1) = - g * MZ / costhDRbar * geL * sinb;
  lTauS2Lr(1, 2) = htau * mu / sqrt(2.0);
  lTauS2Lr(2, 1) = lTauS2Lr(1, 2);
  lTauS2Lr(2, 2) = - g * MZ / costhDRbar * geR * sinb;
  
  rotate = rot2d(physpars.thetatau);
  
  lTauS212 = rotate * lTauS2Lr * rotate.transpose();
  
  double delta = 0.0;
  
  // top quark, ignore others - factor (10^-2)^3 down
  delta = delta - 6.0 * sqr(displayYukawaElement(YU, 3, 3)) *
    a0(mt, displayMu());
  // third generation squarks
  delta = delta + 3.0 * g * lTS212(1, 1) / (2.0 * MW * sinb) *
    a0(physpars.mu(1, 3), q);
  delta = delta + 3.0 * g * lTS212(2, 2) / (2.0 * MW * sinb) *
    a0(physpars.mu(2, 3), q);
  delta = delta + 3.0 * g * lBS212(1, 1) / (2.0 * MW * sinb) *
    a0(physpars.md(1, 3), q);
  delta = delta + 3.0 * g * lBS212(2, 2) / (2.0 * MW * sinb) *
    a0(physpars.md(2, 3), q);
  // third generation sleptons
  delta = delta + g * lTauS212(1, 1) / (2.0 * MW * sinb) *
    a0(physpars.me(1, 3), q);
  delta = delta + g * lTauS212(2, 2) / (2.0 * MW * sinb) *
    a0(physpars.me(2, 3), q);
  delta = delta + g * lSnu / (2.0 * MW * sinb) * a0(physpars.msnu(3), q);
  
  int family; 
  // first two families of squarks
  for (family = 1; family <=2; family++)
    {
      delta = delta + 3.0 * g * 
	(- g * MZ / costhDRbar * guL * sinb * a0(physpars.mu(1, family), q) 
	 - g * MZ / costhDRbar * guR * sinb * a0(physpars.mu(2, family), q)) 
	/ (2.0 * MW * sinb);
      delta = delta + 3.0 * g * 
	(- g * MZ / costhDRbar * gdL * sinb * a0(physpars.md(1, family), q) 
	 - g * MZ / costhDRbar * gdR * sinb * a0(physpars.md(2, family), q)) 
	/ (2.0 * MW * sinb);	
    }
  
  // sleptons
  for (family = 1; family <=2; family++)
    {
      delta = delta + g * 
	(- g * MZ / costhDRbar * geL * sinb * a0(physpars.me(1, family), q) 
	 - g * MZ / costhDRbar * geR * sinb * a0(physpars.me(2, family), q)) 
	/ (2.0 * MW * sinb);
      delta = delta + g * lSnu * a0(physpars.msnu(family), q)
	/ (2.0 * MW * sinb);
    }
  
  // Higgs
  double alpha = displayPhys().thetaH, sina2 = sqr(sin(alpha)), cosa2 = 1.0 -
    sina2, cos2b = cos(2.0 * atan(tanb)), costhDRbar2 = sqr(costhDRbar), 
    mh = physpars.mhiggs(1), sin2a = sin(2.0 * alpha);
  delta = delta + sqr(g) * cos2b / (8.0 * costhDRbar2) *
    (a0(mA, displayMu()) + 2.0 * a0(mHp, q)) +
    sqr(g) * a0(mHp, q) * 0.5 +
    sqr(g) / (8.0 * costhDRbar2) * a0(mh, q) *
    (3.0 * cosa2 - sina2 + sin2a / tanb) +
    sqr(g) / (8.0 * costhDRbar2) * a0(mH0, q) *
    (3.0 * sina2 - cosa2 - sin2a / tanb);
  
  // Neutralinos
  ComplexMatrix n(4, 4); DoubleVector mneut(4); 
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions
  double tanthDRbar = tan(acos(costhDRbar));
  for (family = 1; family <= 4; family++)
    delta = delta + sqr(g) * mneut(family) / (MW * sinb) *
      (n(family, 4) * (n(family, 2) - n(family, 1) * tanthDRbar)).real() * 
      a0(mneut(family), q); 
  
  // Charginos
  ComplexMatrix u(2, 2), v(2, 2); DoubleVector mch(2); 
  mpzCharginos(u, v, mch);
  for (family = 1; family <= 2; family++)
    delta = delta - sqrt(2.0) * sqr(g) * mch(family) / (MW * sinb)
      * (v(family, 2) * u(family, 1)).real() * a0(mch(family), q);
  
  // Weak bosons
  delta = delta + 3.0 * sqr(g) / 4.0 * 
    (2.0 * a0(MW, q) + a0(MZ, q) / costhDRbar2)
    - sqr(g) * cos2b / (8.0 * costhDRbar2) * (2.0 * a0(MW, q) + a0(MZ, q));
  
  physpars.t2OV2Ms = delta / (16.0 * sqr(PI));
}

// Apply at scale MSusy: checked 19.12.2000
// Displays PHYSICAL MZ, ie MZ(q) + piZz^T(q)
double MssmSoftsusy::predMzsq(double & tanb) const {
  tanb = predTanb(); 
  double v = displayHiggsVevMs();
  
  double MZsq = 2.0 *
    ((mH1sq - displayTadpole1Ms() - (mH2sq - displayTadpole2Ms()) *
      sqr(tanb)) / 
     (sqr(tanb) - 1.0) - sqr(displaySusyMu())) - piZZT(MZ, displayMu());
  return MZsq;
}

// Used to get useful information into ftCalc
static MssmSoftsusy tempSoft1;
static int ftFunctionality;
static DoubleVector ftPars(3); 
void (*ftBoundaryCondition)(MssmSoftsusy &, const DoubleVector &);

double ftCalc(double x) {
  static MssmSoftsusy temp;
  temp = tempSoft1;
  double ms = temp.calcMs();
  
  if (PRINTOUT > 1) cout << "#";
  
  if (ftFunctionality <= ftPars.displayEnd()) {
    ftPars(ftFunctionality) = x;
    ftBoundaryCondition(temp, ftPars);
    if (PRINTOUT > 1) cout << "p" << ftFunctionality << "=";
  }
  else if (ftFunctionality == ftPars.displayEnd() + 1) { 
    temp.setSusyMu(x); if (PRINTOUT > 1) cout << "mu= "; 
  }
  else if (ftFunctionality == ftPars.displayEnd() + 2) { 
    temp.setB(x); if (PRINTOUT > 1) cout << "B= "; 
  } 
  else if (ftFunctionality == ftPars.displayEnd() + 3) {
    temp.setYukawaElement(YU, 3, 3, x); if (PRINTOUT > 1) cout << "ht= ";
  }
  else {
    cout << "MssmSoftsusy:ftCalc called with incorrect functionality=" <<
      ftFunctionality << endl;
    exit(1);
  }
  
  double referenceMzsq, predTanb;
  
  temp.runto(temp.calcMs());
  temp.physical(3);
  
  // Strictly speaking, we are using a top mass that is NOT consistent with
  // the new set of sparticle masses. To use the correct one is however quite
  // a pain. We take it to suffice...
  temp.setHiggsVevMs(temp.getVev());
  double mt = temp.calcRunningMt();
  double sinthDRbar = temp.calcSinthdrbar();
  temp.setTadpole2Ms(mt, sinthDRbar); temp.setTadpole1Ms(mt, sinthDRbar);
  
  referenceMzsq = temp.predMzsq(predTanb);  
  
  if (PRINTOUT > 1) cout << x << " MZ=" << sqrt(fabs(referenceMzsq)) 
			 << " tanb=" << predTanb << "\n";
  return referenceMzsq;
}

// Give it a GUT scale object consistent with rewsb
// and it'll return the fine tuning by varying m32, mu and B at the high scale
double MssmSoftsusy::it1par(int numPar, const DoubleVector & bcPars) const {
  
  double ftParameter = 0.0, err, h = 0.01;
  
  tempSoft1 = *this;
  
  ftFunctionality = numPar;
  double x;
  
  // Defines starting value to calculate derivative from
  if (numPar > 0 && numPar <= bcPars.displayEnd()) {
    x = bcPars.display(numPar); h = 0.01 * x; 
  }
  else if (numPar == bcPars.displayEnd() + 1) {//mu
    x = displaySusyMu(); h = 0.01 * x; 
  }
  else if (numPar == bcPars.displayEnd() + 2) {//B
    x = displayB(); h = 0.01 * x; 
  }
  else if (numPar == bcPars.displayEnd() + 3) {//ht  
    x = displayYukawaMatrix(YU)(3, 3); h = x * 0.0005; 
  }
  else {
    cout << "it1par called with functionality " << ftFunctionality << 
      " out of range.\n";
    exit(1);
  }
  
  ftPars.setEnd(bcPars.displayEnd()); ftPars = bcPars;
  
  // Fine tuning is a / MZ^2 d MZ^2 / d a for any parameter a
  double derivative;
  if (fabs(x) < 1.0e-10) {
    ftParameter = 0.0; derivative = 0.0; err = 0.0;
  }
  else {
    derivative = calcDerivative(ftCalc, x, h, &err);
    ftParameter = x * derivative / sqr(MZ);
  }
  
  if (PRINTOUT > 1)
    cout << "derivative=" << derivative << " error=" << err << "\n";
  
  // High error: if can't find a derivative, error comes back with 1.0e30
  if (ftParameter > EPS && fabs(err / derivative) > 1.0) 
    return 6.66e66;
  return fabs(ftParameter);
}

// Pass it an object and it'll return the fine tuning parameter for
// dilaton domination (or NaN in the case of difficulties)
DoubleVector MssmSoftsusy::fineTune
(void (*boundaryCondition)(MssmSoftsusy &, const DoubleVector &),
 const DoubleVector  & bcPars, double mx) const {
  MssmSoftsusy tempFtSoft(*this);
  tempFtSoft.runto(mx, EPS);
  ftBoundaryCondition = boundaryCondition;
  
  int numPars = bcPars.displayEnd() + 3;
  
  DoubleVector tempFineTuning(numPars);
  
  int i; for (i = 1; i<= numPars; i++) {
    tempFineTuning(i) = tempFtSoft.it1par(i, bcPars);
    // flag problem FT calculation with NaN...too inaccurate
    if (tempFineTuning(i) > 1.0e66) tempFineTuning(i) = asin(2.0);
  }
  
  return tempFineTuning;
}

// Obtains solution of one-loop effective potential minimisation via iteration
// technique
// err is 1 if no iteration reached
// 2 if incorrect rewsb
void MssmSoftsusy::iterateMu(double & muold, double & munew, int sgnMu,
			     double mt, int maxTries, double pizzMS,
			     double sinthDRbar, double tol, int & err) {
  static int numTries = 0;
  
  if (numTries - 1 > maxTries) { 
    if (PRINTOUT) cout << "iterateMu reached maxtries\n"; 
    err = 1; return;
  }
  // How close to convergence are we?
  double c = 1.0 - minimum(fabs(muold), fabs(munew)) / maximum(fabs(muold),
							 fabs(munew));
  
  if (c < tol) { 
    // update out to be latest iteration
    munew = muold;
    numTries = 0;
    if (PRINTOUT > 2) cout << " mu converged\n";
    return; 
  }
  
  numTries = numTries + 1;
  
  munew = muold;
  
  double mH1sq = displayMh1Squared(), mH2sq = displayMh2Squared(), 
    tanb = displayTanb(),
    tanb2 = sqr(tanb), cos2b = cos(2.0 * atan(tanb)); 
  
  double treeLevelMusq = (mH1sq - mH2sq * tanb2) / (tanb2 - 1.0) - 0.5 *
    sqr(MZ);
  
  setSusyMu(muold);
  
  // calculate the new one-loop tadpoles with old value of mu
  setTadpole2Ms(mt, sinthDRbar);
  setTadpole1Ms(mt, sinthDRbar);   
  
  double oneLoopMusq = treeLevelMusq - 0.5 * pizzMS + 
    (displayTadpole2Ms() * sqr(tanb) - displayTadpole1Ms()) /
    (sqr(tanb) - 1.0); 
  
  // Error in rewsb
  if (oneLoopMusq < 0.0) err = 2; 
  
  munew = sgnMu * sqrt(fabs(oneLoopMusq));

  if (PRINTOUT > 2) cout << " mu=" << munew;
  
  iterateMu(munew, muold, sgnMu, mt, maxTries, pizzMS, sinthDRbar, tol, err);
}

void MssmSoftsusy::rewsbTreeLevel(int sgnMu) {
  double mu, b;
  if (rewsbMu(sgnMu, mu)) flagMusqwrongsign(true);
  else flagMusqwrongsign(false);
  setSusyMu(mu);
  if (rewsbB(mu, b)) flagB(true);
  else flagB(false); 
  
  setB(b);
  
  if ((displayMh1Squared() + 2.0 * sqr(displaySusyMu()) +
       displayMh2Squared() - 2.0 * fabs(displaySusyMu() *
					  displayB())) < 0.0 )
    flagHiggsufb(true);
  else 
    flagHiggsufb(false);
  
  return;
}

// Organises rewsb: call it at the low scale MS^2 = sqrt(0.5 * (mT1^2 +
// mT2^2)) is best, or below if it's decoupled from there. 
// Call with zero, or no mt if you want tree level
void MssmSoftsusy::rewsb(int sgnMu, double mt) {
  double munew, bnew, muold;
  
  double sinthDRbarMS = calcSinthdrbar();

  setTadpole1Ms(mt, sinthDRbarMS);  
  setTadpole2Ms(mt, sinthDRbarMS); 
  
  muold = displaySusyMu();
  
  // Iterate to get a self-consistent mu solution
  int maxTries = 20, err = 0;
  double tol = EPS * 1.0e-4;
  
  setHiggsVevMs(getVev()); 
  
  float pizztMS = piZZT(MZ, displayMu());
  iterateMu(muold, munew, sgnMu, mt, maxTries, pizztMS, sinthDRbarMS,
	    tol, err); 
  
  if (err!=0) flagMusqwrongsign(true);
  else flagMusqwrongsign(false); 
  
  setSusyMu(munew);
  
  if (rewsbB(munew, bnew) == 0) flagB(false);
  else flagB(true);
  
  setB(bnew);
  
  if ((displayMh1Squared() + 2.0 * sqr(displaySusyMu()) +
       displayMh2Squared() - 2.0 * fabs(displaySusyMu() *
					  displayB())) < 0.0 )
    flagHiggsufb(true);
  else 
    flagHiggsufb(false);
}

#define HR "---------------------------------------------------------------\n"

ostream & operator <<(ostream &left, const MssmSoftsusy &s) {
  left << HR;
  left << "SUSY breaking MSSM parameters\n";
  left << " UA" << s.displayTrilinear(UA) 
       << " UD" << s.displayTrilinear(DA) 
       << " UE" << s.displayTrilinear(EA); 
  left << " mQLsq" << s.displaySoftMassSquared(mQl) 
       << " mURsq" << s.displaySoftMassSquared(mUr) 
       << " mDRsq" << s.displaySoftMassSquared(mDr) 
       << " mLLsq" << s.displaySoftMassSquared(mLl) 
       << " mSEsq" << s.displaySoftMassSquared(mEr);
  left << "B: " << s.displayB() << " mH1sq: " << s.displayMh1Squared() << 
    " mH2sq: " << s.displayMh2Squared() << '\n';
  left << "Gaugino masses" << s.displayGaugino();
  left << "Gravitino mass M3/2: " << s.displayGravitino() << endl;
  left << s.displayPhys();
  left << "Higgs VEV: " << s.displayHiggsVevMs() << endl;  
  left << "Data set:\n" << s.displayDataSet();
  double mass; int posi, posj, id;
  id = s.lsp(mass, posi, posj);
  left << "lsp is ";
  recogLsp(id, posj);
  left << " of mass " << mass << " GeV\n";
  left << s.displaySusy();
  left << s.displayProblem();
  return left;
}

istream & operator >>(istream &left, MssmSoftsusy &s) {
  char c[70];
  left >> c >> c >> c >> c >> c;
  DoubleMatrix ua(3, 3), da(3, 3), ea(3, 3);
  left >> c >> ua
       >> c >> da
       >> c >> ea;
  s.setTrilinearMatrix(UA, ua);
  s.setTrilinearMatrix(DA, da);
  s.setTrilinearMatrix(EA, ea);
  DoubleMatrix mqlsq(3, 3), mursq(3, 3), mdrsq(3, 3), mllsq(3, 3), mersq(3, 3);
  left >> c >> mqlsq
       >> c >> mursq
       >> c >> mdrsq
       >> c >> mllsq
       >> c >> mersq;
  s.setSoftMassMatrix(mQl, mqlsq); 
  s.setSoftMassMatrix(mUr, mursq); 
  s.setSoftMassMatrix(mDr, mdrsq); 
  s.setSoftMassMatrix(mLl, mllsq); 
  s.setSoftMassMatrix(mEr, mersq); 
  float B, mh1sq, mh2sq;
  left >> c >> B >> c >> mh1sq >> c >> mh2sq;
  s.setB(B); s.setMh1Squared(mh1sq); s.setMh2Squared(mh2sq);
  DoubleVector mg(3);
  left >> c >> mg; 
  s.setAllGauginos(mg);
  double m32;
  left >> c >> c >> c >> m32; // m32 not supported at present
  sPhysical sp; float vev;
  left >> sp;
  s.setPhys(sp);
  left >> c >> c >> vev;  
  s.setHiggsVevMs(vev);
  QedQcd qq;
  left >> c >> c >> qq;
  s.setData(qq);
  left >> c >> c >> c >> c >> c >> c >> c; 
  MssmSusy ss;
  left >> ss;   s.setSusy(ss);
  return left;
}

// Gives a summary of important properties of a SUSY object: mu, B, mH0,
// mChi0, lightest stau, lightest mGluino, lightest stop, lightest chargino,
// lightest tau sneutrino, lightest sbottom, down squark, up squark and
// selectron masses, minimum of potential (if calculated) and fine-tuning
// parameter (if passed)
void printShortInitialise() {
  cout <<
    "     mu     " << "     B      " << 
    "   mstau1   " << "   msbott   " << "  mstop1    " <<
    " mSquark   " << "   mSlep   " << "  msnu1     " <<
    "    mhl0    " << "   mchi10   " << " mchargino1 " <<
    "  mGluino  " << "   VMin    " ;
  
  cout.flush();
}

void MssmSoftsusy::printShort(const DoubleVector & ft) const {
  double mu, b;
  mu = displaySusyMu(); b = displayB(); 
  int pos;
  sPhysical s(this->displayPhys());
  
  if (displayProblem().muSqWrongSign || displayProblem().b ||
      displayProblem().higgsUfb) 
    mu = -1.0 *  mu;
  if (displayProblem().tachyon) b = -1.0 * b;
  
  if (displayProblem().nonperturbative) {
    int i; for (i=1; i<=13+ft.displayEnd(); i++) cout << asin(2.0) << " ";
  }
  else {
    cout << " " << mu << " " << b << " "
	 << minimum(s.me(1, 3), s.me(2, 3)) << " " 
	 << minimum(s.md(1, 3), s.md(2, 3)) << " " 
	 << minimum(s.mu(1, 3), s.mu(2, 3)) << " " 
	 << minimum(minimum(s.md(1, 1), s.md(2, 1)), 
		    minimum(s.mu(1, 1), s.mu(2, 1)))
	 << " " << minimum (s.me(1, 1), s.me(2, 1)) << " "
	 << s.msnu.min(pos) << " " 
	 << s.mhiggs(1) << " " 
	 << (s.mneut.apply(fabs)).min(pos) << " "
	 << (s.mch.apply(fabs)).min(pos) << " "
	 << s.mGluino << " " << this->displayMinpot() << " ";
    
    int i; for (i=1; i<=ft.displayEnd(); i++) cout << ft.display(i) << " "; 
  }
  
  if (displayProblem().test()) cout << "%" << displayProblem();
  
  cout << endl;
  
  cout.flush();
}

void MssmSoftsusy::printLong() {
  // output:
  //  1  2  3      4   5   6   7    8 9  10 11 12    13    14     
  // mu  B mH1sq mH2sq g1 g2 mt(mt) V mh mA mH mH+ alphaH msnu3
  //  15     16     17    18     19    20     21   
  // msnu1 mstopL mstopR msupL msupR msbotL msbotR
  //  22   23   24     25     26     27    28     29      30    
  // msdL msdR mstauL mstauR mselL mselR thetat thetab thetatau
  // 31   32   33   34      35     36    37     38     39      
  // mgl mch1 mch2 thetaL thetaR mneut1 mneut2 mneut3 mneut4
  //   40     41    42  
  // sinthW t1ov1 t2ov2 
  double mu = displaySusyMu();
  if (displayProblem().muSqWrongSign || displayProblem().b ||
      displayProblem().higgsUfb) 
    mu = -1.0 *  mu;
  //  if (displayProblem().noConvergence) 
  // mu = asin(-2.0);
  
  if (displayProblem().tachyon) {
    sPhysical s(displayPhys());
    s.me = -1.0 * s.me;
    s.md = -1.0 * s.md;
    s.mu = -1.0 * s.mu;
    s.msnu = -1.0 * s.msnu;	
    s.mhiggs = -1.0 * s.mhiggs;
    setPhys(s);
  }
  
  cout <<" " << mu << " " 
       << displayB() << " " 
       << displayMh1Squared() << " " <<
    displayMh2Squared() << " " << 
    displayGaugeCoupling(1) << " " <<
    displayGaugeCoupling(2) << " " <<
    calcRunningMt() << " " <<
    displayHiggsVevMs() << " " <<
    displayPhys().mhiggs(1) << " " <<
    displayPhys().mhiggs(2) << " " <<
    displayPhys().mhiggs(3) << " " <<
    displayPhys().mhiggs(4) << " " <<
    displayPhys().thetaH << " " <<
    displayPhys().msnu(3) << " " <<
    displayPhys().msnu(1) << " " <<
    displayPhys().mu(1, 3) << " " <<
    displayPhys().mu(2, 3) << " " <<
    displayPhys().mu(1, 1) << " " <<
    displayPhys().mu(2, 1) << " " <<
    displayPhys().md(1, 3) << " " <<
    displayPhys().md(2, 3) << " " <<
    displayPhys().md(1, 1) << " " <<
    displayPhys().md(2, 1) << " " <<
    displayPhys().me(1, 3) << " " <<
    displayPhys().me(2, 3) << " " <<
    displayPhys().me(1, 1) << " " <<
    displayPhys().me(2, 1) << " " <<
    displayPhys().thetat << " " <<
    displayPhys().thetab << " " <<
    displayPhys().thetatau << " " <<
    displayPhys().mGluino << " " <<
    displayPhys().mch(1) << " " <<
    displayPhys().mch(2) << " " <<
    displayPhys().thetaL << " " <<
    displayPhys().thetaR << " " <<
    displayPhys().mneut(1) << " " <<
    displayPhys().mneut(2) << " " <<
    displayPhys().mneut(3) << " " <<
    displayPhys().mneut(4) << " " <<
    calcSinthdrbar() << " " <<
    displayTadpole1Ms() << " " <<
    displayTadpole2Ms() << " ";

  if (displayProblem().test()) cout << "%" << displayProblem();
  cout << endl;
  cout.flush();
}


ostream & operator <<(ostream & left, const sPhysical &s) {
  left << HR;
  left << "Physical MSSM parameters";
  left << "\nmh^0: " << s.mhiggs.display(1) << " mA^0: " << s.mhiggs.display(2)
       << " mH^0: " << 
    s.mhiggs.display(3) << " mH^+-: " << s.mhiggs.display(4) << "\n";
  left << "alpha: " << s.thetaH << "\n";
  left << "sneutrinos" << s.msnu; 
  left << "mU~" << s.mu << "mD~" << s.md << "mE~" << s.me;
  left << "thetat: " << s.thetat << " thetab: " << s.thetab << 
    " thetatau: " << s.thetatau << "\n";
  left << "mGluino:  " << s.mGluino << "\n";
  left << "charginos" << s.mch;
  left << "thetaL: " << s.thetaL << " thetaR: " << s.thetaR << "\n";
  left << "neutralinos" << s.mneut;
  left << "neutralino mixing matrix " << s.mixNeut;
  return left;
}

istream & operator >>(istream & left, sPhysical &s) {
  char c[70];
  left >> c >> c >> c >> c;
  DoubleVector mh(4);
  left >> c >> s.mhiggs(1) >> c >> s.mhiggs(2)
       >> c >> s.mhiggs(3) >> c >> s.mhiggs(4);
  left >> c >> s.thetaH;
  left >> s.msnu; 
  left >> c >> s.mu >> c >> s.md >> c >> s.me;
  left >> c >> s.thetat >> c >> s.thetab >> 
    c >> s.thetatau;
  left >> c >> s.mGluino;
  left >> s.mch;
  left >> c >> s.thetaL >> c >> s.thetaR;
  left >> s.mneut;
  left >> c >> c >> c >> c >> s.mixNeut;
  return left;
}

#undef HR

DoubleMatrix MssmSoftsusy::treeSpartDoubleMatrix(double mSm, softMasses rsm,
				     int family, double pizztMS, double
				     sinth) const {
  DoubleMatrix mass(2,2);
  
  const double cu = 2.0 / 3.0, cd = -1.0 / 3.0;
  double mz2 = sqr(MZ) + pizztMS, msm2 = sqr(mSm);
  double beta = atan(displayTanb()), mu = -displaySusyMu(),
    c2b = cos(2 * beta), tanb = displayTanb(), sinth2 = sqr(sinth);

  // Decide which left handed mass to use in mass matrix
  switch(rsm) {
  case mUr: // checked
    mass(1, 1) = displaySoftMassSquared(mQl)(family, family) + msm2 +
      mz2 * (0.5 - cu * sinth2) * c2b;
    mass(2, 2) = displaySoftMassSquared(mUr)(family, family) + msm2 +
      mz2 * cu * sinth2 * c2b;
    if (family == 3) 
      mass(1, 2) = mSm * (displayTrilinear(UA)(3, 3) /
			   displayYukawaMatrix(YU)(3, 3) + mu / tanb); 
    else
      mass(1, 2) = 0.0;   
    break;
  case mDr: // checked
    mass(1, 1) = displaySoftMassSquared(mQl)(family, family) + msm2 +
      mz2 * (0.5 + cd * sinth2) * c2b;
    mass(2, 2) = displaySoftMassSquared(mDr)(family, family) + msm2 +
      mz2 * cd * sinth2 * c2b;
    if (family == 3) 
      mass(1, 2) = mSm * (displayTrilinear(DA)(3, 3) /
			   displayYukawaMatrix(YD)(3, 3) + mu * tanb);
    else
      mass(1, 2) = 0.0;
    break;
  case mEr: // checked
    mass(1, 1) = displaySoftMassSquared(mLl)(family, family) + msm2 -
      mz2 * (0.5 - sinth2) * c2b;
    mass(2, 2) = displaySoftMassSquared(mEr)(family, family) + msm2 -
      mz2 * sinth2 * c2b;
    if (family == 3) 
      mass(1, 2) = mSm * (displayTrilinear(EA)(3, 3) /
			   displayYukawaMatrix(YE)(3, 3) + mu * tanb);
    else
      mass(1, 2) = 0.0;
    break;
  case mLl:
    mass(1, 1) = displaySoftMassSquared(mLl)(family, family) + 0.5 * mz2
      * c2b;
    break;
  default:
    cerr << "Error: invalid switch " << rsm << 
      "in MSSMSosftsusy::getSpart3\n";
    exit(1);
  }
  mass(2, 1) = mass(1, 2);
  
  return mass;
}

// These two functions help calculate one-loop stop corrections
double MssmSoftsusy::lambda(double theta, double beta) const {
  return 
    sqr(2.0 * dataSet.displayPoleMt() * cos(beta) *
	cos(theta) - (-displaySusyMu() * sin(beta) - 
		      displaySoftA(UA, 3, 3) * cos(beta)) 
	* sin(theta)) +
    sqr(-displaySusyMu() * sin(beta) - displaySoftA(UA, 3, 3) *
	cos(beta)) * sqr(sin(theta));
}

double MssmSoftsusy::omega(double theta, double beta) const {
  double mt = dataSet.displayPoleMt();
  return 2.0 * sqr(mt) * sqr(cos(beta)) * sin(2.0 * theta) -
    2.0 * mt * cos(beta) * (-displaySusyMu() * sin(beta) - 
			    displaySoftA(UA, 3, 3) *
			    cos(beta));
}

// These two functions help calculate one-loop sbottom corrections
double MssmSoftsusy::lambdab(double theta, double beta) const {
  return 
    sqr(2.0 * dataSet.displayMass(mBottom) * sin(beta) *
	cos(theta) - (-displaySusyMu() * cos(beta) - 
		      displaySoftA(DA, 3, 3) * sin(beta)) 
	* sin(theta)) +
    sqr(-displaySusyMu() * cos(beta) - displaySoftA(DA, 3, 3) *
	sin(beta)) * sqr(sin(theta));
}

double MssmSoftsusy::omegab(double theta, double beta) const {
  if (displayMu() != MZ)     {
    cout << "MssmSoftsusy::omegab called with mu=" <<
      displayMu() << endl; 
    exit(1);
  }
  
  double mb = dataSet.displayMass(mBottom);
  return 2.0 * sqr(mb) * sqr(sin(beta)) * sin(2.0 * theta) -
    2.0 * mb * sin(beta) * (-displaySusyMu() * cos(beta) - 
			    displaySoftA(DA, 3, 3) *
			    sin(beta));
}

// These are written in the notation of hep-ph/9606211, ie mstop1 is the
// HEAVIEST!! They are SUSY loops corrections to the scalar sparticles.
DoubleMatrix MssmSoftsusy::addSpartLoop(DoubleMatrix mass, double mSm,
				  softMasses rsm, int family) const {
  DoubleVector x(2);
  
  if (rsm == mQl || rsm == mUr || rsm == mDr)
    {
      // one-loop corrections to pole mass. See hep-ph/9606211, approx (34)
      if (family != 3) {
	DoubleVector x(2), delta(2);
	int i; for (i=1; i<=2; i++)  
	  { 
	    x(i)= sqr(displayPhys().mGluino) / mass(i, i);
	    delta(i) = sqr(displayGaugeCoupling(3)) / (6.0 * sqr(PI)) * 
	      (1.0 + 3.0 * x(i) + sqr(x(i) - 1.0) * log(fabs(x(i) - 1.0))
	       - sqr(x(i)) * log(x(i)) + 2.0 * x(i) * 
	       log(sqr(displayMu()) / mass(i, i)));
	  }  
	mass(1, 1) = mass(1, 1) * (1.0 + delta(1));
	mass(2, 2) = mass(2, 2) * (1.0 + delta(2));
      } 
      else { // stop corrections
	// one-loop correction matrix
	DoubleMatrix delta(2, 2);
	
	// brevity
	double    mb   =  displayDataSet().displayMass(mBottom) ;
	double    beta    = atan(displaySusy().displayTanb());
	double    mstop2  = displayPhys().mu(2,3);
	double    thetat = displayPhys().thetat ;
	double    ct      = cos(thetat) ;
	double    st      = sin(thetat) ;
	double    thetab = displayPhys().thetab;
	double    cb      = cos(thetab) ;
	double    sb      = sin(thetab) ;
	double    mstop1  = displayPhys().mu(1,3);
	double    mg      = displayPhys().mGluino;
	double    msbot1  = displayPhys().md(1,3);
	double    msbot2  = displayPhys().md(2,3);
	double     mA     = displayPhys().mhiggs(2);
	double    smu     = -displaySusyMu();
	double    Ab      = displaySoftA(DA, 3, 3);
	double    At      = displaySoftA(UA, 3, 3);
	double q = displayMu(), g3sq = sqr(displayGaugeCoupling(3)), 
	  htsq = sqr(displayYukawaElement(YU, 3, 3)), 
	  sinb = sin(beta), cosb = cos(beta), 
	  hbsq = sqr(displayYukawaElement(YD, 3, 3)),
	  ONEO16Pisq = 1.0 / sqr(PI),
	  mt = displayDataSet().displayPoleMt();
	
	if (rsm = mUr) {
	  // corrections themselves in (L, R) basis
	  delta(1, 1) = g3sq * 8.0 * ONEO16Pisq / 3.0 * 
	    (2.0 * sqr(mstop2) * (sqr(ct) * b1(mstop2, mstop1, 0.0, q) +
				  sqr(st) * b1(mstop2, mstop2, 0.0, q))
	     + a0(mg, q) + a0(mt, q) - (sqr(mstop2) - sqr(mg) - sqr(mt)) *
	     b0(0.0, mg, mt, q))
	    
	    - ONEO16Pisq * 
	    (htsq * sqr(st) * a0(mstop1, q) + hbsq * a0(msbot1, q) - 
	     2.0 * (htsq + hbsq) * a0(smu, q) + 
	     (htsq * sqr(cosb) + hbsq * sqr(sinb)) * a0(mA, q)) -
	    
	    0.5 * htsq * ONEO16Pisq * 
	    (lambda(thetat, beta) * b0(0.0, mstop1, mA, q)  +
	     lambda(thetat - PI * 0.5, beta) * b0(0.0, 0.0, mA, q) +
	     lambda(thetat, beta - PI * 0.5) * b0(0.0, mstop1, 0.0, q) +
	     lambda(thetat - PI * 0.5, beta - PI * 0.5) 
	     * b0(mstop2, mstop2, MZ, q))
	    
	    - ONEO16Pisq * 
	    ((htsq * sqr(mt) * sqr(cosb) + hbsq * sqr(smu * cosb - Ab * sinb)) *
	     b0(0.0, msbot1, mA, q) +
	     (htsq * sqr(mt) * sqr(sinb) + hbsq * sqr(smu * sinb + Ab * cosb))
	     * b0(0.0, msbot1, 0.0, q));
	  
	  delta(1, 2) = 
	    -g3sq * 8.0 / 3.0 * ONEO16Pisq * ct * st * 
	    ((sqr(mstop1) + sqr(mstop2)) * b0(mstop2, mstop1, 0.0, q) +
	     2.0 * sqr(mstop2) * b0(mstop2, mstop2, 0.0, q))
	    - g3sq / (3.0 * sqr(PI)) * mt * mg * b0(0.0, mt, mg, q) -
	    3.0 * htsq * ONEO16Pisq * ct * st * a0(mstop1, q) -
	    
	    htsq * 0.5 * ONEO16Pisq *
	    (omega(thetat, beta) * b0(0.0, mstop1, mA, q) + 
	     omega(-thetat, beta) * b0(0.0, 0.0, mA, q) +
	     omega(thetat, PI * 0.5 + beta) * b0(0.0, mstop1, 0.0, q) +
	     omega(-thetat, PI * 0.5 + beta) * b0(mstop2, mstop2, MZ, q)) -
	    
	    ONEO16Pisq * 
	    (-(htsq * mt * cosb * (smu * sinb - At * cosb) + hbsq * mt * sinb *
	       (smu * cosb - Ab * sinb)) * b0(0.0, msbot1, mA, q) +
	     htsq * mt * sinb * (smu * cosb + At * sinb) 
	     * b0(0.0, msbot1, 0.0, q));
	  
	  delta(2, 1) = delta(1, 2);
	  
	  delta(2, 2) = 
	    g3sq * 8.0 / 3.0 * ONEO16Pisq *
	    (2.0 * sqr(mstop2) * 
	     (sqr(st) * b1(mstop2, mstop1, 0.0, q) + 
	      sqr(ct) * b1(mstop2, mstop2, 0.0, q))
	     + a0(mg, q) + a0(mt, q) - (sqr(mstop2) - sqr(mg) - sqr(mt)) *
	     b0(0.0, mg, mt, q)) -
	    
	    htsq * ONEO16Pisq * 
	    (sqr(ct) * a0(mstop1, q) + a0(msbot1, q) -
	     4.0 * a0(smu, q) + 2.0 * sqr(cosb) * a0(mA, q)) -
	    
	    htsq * 0.5 * ONEO16Pisq *
	    (lambda(PI * 0.5 - thetat, beta) * b0(0.0, mstop1, mA, q) +
	     lambda(-thetat, beta) * b0(0.0, 0.0, mA, q) +
	     lambda(PI * 0.5 - thetat, beta - PI * 0.5) * 
	     b0(0.0, mstop1, 0.0, q) + 
	     lambda(-thetat, beta - PI * 0.5) * b0(mstop2, mstop2, MZ, q)) -
	    
	    ONEO16Pisq * 
	    ((hbsq * sqr(mt) * sqr(sinb) + htsq * sqr(smu * sinb - At * cosb)) *
	     b0(0.0, msbot1, mA, q) + htsq * sqr(smu * cosb + At * sinb) * 
	     b0(0.0, msbot1, 0.0, q));
	}
	else if (rsm = mDr) {
	  // corrections themselves in (L, R) basis
	  delta(1, 1) = g3sq * 8.0 * ONEO16Pisq / 3.0 * 
	    (2.0 * sqr(msbot2) * (sqr(cb) * b1(msbot2, msbot1, 0.0, q) +
				  sqr(sb) * b1(msbot2, msbot2, 0.0, q))
	     + a0(mg, q) + a0(mb, q) - (sqr(msbot2) - sqr(mg) - sqr(mb)) *
	     b0(0.0, mg, mb, q))
	    
	    - ONEO16Pisq * 
	    (hbsq * sqr(sb) * a0(msbot1, q) + htsq * a0(mstop1, q) - 	
	     2.0 * (hbsq + htsq) * a0(smu, q) + 
	     (hbsq * sqr(sinb) + htsq * sqr(cosb)) * a0(mA, q)) -
	    
	    0.5 * hbsq * ONEO16Pisq * 
	    (lambdab(thetab, beta) * b0(0.0, msbot1, mA, q)  +
	     lambdab(thetab - PI * 0.5, beta) * b0(0.0, 0.0, mA, q) +
	     lambdab(thetab, beta - PI * 0.5) * b0(0.0, msbot1, 0.0, q) +
	     lambdab(thetab - PI * 0.5, beta - PI * 0.5) 
	     * b0(msbot2, msbot2, MZ, q))
	    
	    - ONEO16Pisq * 
	    ((hbsq * sqr(mb) * sqr(sinb) + htsq * sqr(smu * sinb - At * cosb)) *
	     b0(0.0, mstop1, mA, q) +
	     (hbsq * sqr(mb) * sqr(cosb) + htsq * sqr(smu * cosb + At * sinb))
	     * b0(0.0, mstop1, 0.0, q));
	  
	  delta(1, 2) = 
	    -g3sq * 8.0 / 3.0 * ONEO16Pisq * cb * sb * 
	    ((sqr(msbot1) + sqr(msbot2)) * b0(msbot2, msbot1, 0.0, q) +
	     2.0 * sqr(msbot2) * b0(msbot2, msbot2, 0.0, q))
	    - g3sq / (3.0 * sqr(PI)) * mb * mg * b0(0.0, mb, mg, q) -
	    3.0 * hbsq * ONEO16Pisq * cb * sb * a0(msbot1, q) -
	    
	    hbsq * 0.5 * ONEO16Pisq *
	    (omegab(thetab, beta) * b0(0.0, msbot1, mA, q) + 
	     omegab(-thetab, beta) * b0(0.0, 0.0, mA, q) +
	     omegab(thetab, PI * 0.5 + beta) * b0(0.0, msbot1, 0.0, q) +
	     omegab(-thetab, PI * 0.5 + beta) * b0(msbot2, msbot2, MZ, q)) -
	    
	    ONEO16Pisq * 
	    (-(hbsq * mb * sinb * (smu * cosb - Ab * sinb) + htsq * mb * cosb *
	       (smu * sinb - At * cosb)) * b0(0.0, mstop1, mA, q) +
	     hbsq * mb * cosb * (smu * sinb + Ab * cosb) 
	     * b0(0.0, mstop1, 0.0, q));
	  
	  delta(2, 1) = delta(1, 2);
	  
	  delta(2, 2) = 
	    g3sq * 8.0 / 3.0 * ONEO16Pisq *
	    (2.0 * sqr(msbot2) * 
	     (sqr(sb) * b1(msbot2, msbot1, 0.0, q) + 
	      sqr(cb) * b1(msbot2, msbot2, 0.0, q))
	     + a0(mg, q) + a0(mb, q) - (sqr(msbot2) - sqr(mg) - sqr(mb)) *
	     b0(0.0, mg, mb, q)) -
	    
	    hbsq * ONEO16Pisq * 
	    (sqr(cb) * a0(msbot1, q) + a0(mstop1, q) -
	     4.0 * a0(smu, q) + 2.0 * sqr(sinb) * a0(mA, q)) -
	    
	    hbsq * 0.5 * ONEO16Pisq *
	    (lambdab(PI * 0.5 - thetab, beta) * b0(0.0, msbot1, mA, q) +
	     lambdab(-thetab, beta) * b0(0.0, 0.0, mA, q) +
	     lambdab(PI * 0.5 - thetab, beta - PI * 0.5) * 
	     b0(0.0, msbot1, 0.0, q) + 
	     lambdab(-thetab, beta - PI * 0.5) * b0(msbot2, msbot2, MZ, q)) -
	    
	    ONEO16Pisq * 
	    ((htsq * sqr(mb) * sqr(cosb) + hbsq * sqr(smu * cosb - Ab * sinb)) *
	     b0(0.0, mstop1, mA, q) + hbsq * sqr(smu * sinb + Ab * cosb) * 
	     b0(0.0, mstop1, 0.0, q));
	}
	
	mass = mass + delta;	  
      } 
    } 
  
  return mass;
}


DoubleMatrix MssmSoftsusy::getSpartDoubleMatrix(double mSm, softMasses rsm,
				    int family, int accuracy, double
				    pizztMS, double sinthMS) const { 
  DoubleMatrix mass(treeSpartDoubleMatrix(mSm, rsm, family, pizztMS, sinthMS));
  if (accuracy > 1) addSpartLoop(mass, mSm, rsm, family);
  return mass;
}

// DO NOT CALL the following until mu is calculated!!!
// Gets third family sparticle mass parameters: mSm is the standard model
// partner's mass, top, bottom or tau. sinth=sin^2 thetaW, 
// Sparticle:           rsm
// stop                 mUr
// stau                 mEr
// sbottom              mDr
// sneutrino            mLl
// in this last case, the sneutrino mass is outputted in element (1) of the
// vector, the second is just zero.
// theta is the sparticle mixing angle, defined by
// [ cos theta   -sin theta ]   m^2   [cos theta   sin theta ]  = diag
// [ sin theta    cos theta ]         [-sin theta  cos theta ]
// mass matrices follow notation in hep-ph/9306207
// in order: heaviest then lightest
DoubleVector MssmSoftsusy::getSpart(double mSm, softMasses rsm, double &
			      theta, int family, int accuracy, double
			      pizztMS, double sinthMS) {
  if (family < 1 || family > 3) {
    cerr << "In MssmSoftsusy::getSpart, called with " << family << 
      "families.\n";
    exit(1);
  }
  
  DoubleMatrix mass(getSpartDoubleMatrix(mSm, rsm, family, accuracy, pizztMS, sinthMS));
  
  static DoubleVector temp(2);
  if (family !=3 && rsm != mLl) {
    temp(1) = mass(1, 1);
    temp(2) = mass(2, 2);
    theta = 0.0;
  }
  else if (rsm == mLl) {
    temp(1) = mass(1, 1);
    theta = 0.0;
  }
  else if (rsm != mLl && family == 3) temp = mass.sym2by2(theta);   
  
  int dummy;
  
  // if you've got a tachyonic particle, store - sqrt(|mass^2|)
  if (temp.min(dummy) < 0.0) {
    if (PRINTOUT > 1) cout << "TACHYON:(" << rsm << ")(" << dummy << ","
			   << family << ")";
    if (PRINTOUT > 2) {
      cout << *this;
      cout << "From:" << mass << " evals " << temp;
    }
    flagTachyon(true);
  }
  return temp;
}

// returns sqrt(f) for f>0 or -sqrt(|f|) for f<0
inline double ccbSqrt(double f){ return sqrt(fabs(f)); }

// checked: thetaH is defined to be the 'alpha' from Haber.
// following reproduces FeynHiggsFast.f results for the same inputs
// accuracy: 0=tree, 1=1 loop top corrections, 2=all one loop corrections,
// 3=up to two loop corrections
// mt inputted should be the POLE MASS, alphas should prob be at top scale
void MssmSoftsusy::higgs(int accuracy, double piwwtMS, double pizztMS) {
  double mt = displayDataSet().displayPoleMt(), 
    mb = displayDataSet().displayMass(mBottom), 
    alphas = displayDataSet().displayAlpha(ALPHAS); 
  const static double root2 = sqrt(2.0), pisq = sqr(PI);
  
  double tanb = displayTanb();
  double beta = atan(tanb), sinb = sin(beta), cosb = cos(beta);
  double sinb2 = sqr(sinb), cosb2 = sqr(cosb), mz2 = sqr(MZ), mt2 = sqr(mt),
    mt4 = sqr(mt2);
  double mu = -displaySusyMu();
  
  // tree level: there'll be trouble if B is the same sign as mu
  double mAsq = -b * mu / (sinb * cosb); 
  if (mAsq < 0.0) flagB(true);
  
  double mHpmsq = sqr(MW) + mAsq;
  double costh = sqr(MW / MZ), sinth = 1 - costh; 
  static DoubleMatrix mH(2, 2);
  mH(1, 1) = mAsq * sinb2 + mz2 * cosb2;
  mH(1, 2) = - sinb * cosb * (mAsq + mz2); 
  mH(2, 2) = mAsq * cosb2 + mz2 * sinb2; 
  mH(2, 1) = mH(1 ,2); 
  
  /*       one loop contributions:       */
  if (accuracy > 0) {
    // brevity: been checked
    double ms = 
      pow(mQLsq(3, 3) * mURsq(3, 3) + mt2 * (mQLsq(3,3) + mURsq(3, 3)) +
	  sqr(mt2), 0.25), 
      ms2 = sqr(ms), ms4 = sqr(ms2), ms6 = ms4 * ms2, ms8 = sqr(ms4);
    double mtOMs2 = sqr(mt / ms), mtOMs4 = sqr(mtOMs2), mtOMs6 =
      mtOMs2 * mtOMs4, mtOMs8 = sqr(mtOMs4);
    double mzOMt2 = mz2 / mt2, mzOMt4 = sqr(mzOMt2);
    double logMtOMssq = log(mtOMs2);
    double mLR = displaySoftA(UA, 3, 3) + mu / tanb, mLR2 = sqr(mLR), mLR4
      = sqr(mLR2), mLR6 = mLR2 * mLR4, mLR8 = sqr(mLR4);
    const static double lambda = 1.0 / 8.0 - sinth / 3.0 + 4.0 / 9.0 *
      sqr(sinth);
    
    // Following are t,stop corrections from hep-ph/9903404: checked, but
    // note that mu and B have opposite signs to my notation from that paper
    DoubleMatrix sigma(2, 2);
    sigma(1, 1) = GMU * root2 * sqr(mz2) * lambda * cosb2 * logMtOMssq 
      / pisq;
    sigma(1, 2) = -GMU * root2 * mz2 / (pisq * tanb) * 
      (-3.0 / 8.0 * mt2 + mz2 * lambda * sinb2) * logMtOMssq;
    sigma(2, 2) = GMU * root2 / (8.0 * pisq * sinb2) * mt4 * 
      (-2.0 * mzOMt2 + 1.1 * mzOMt4 +
       (12.0 - 6.0 * mzOMt2 * sinb2 + 8.0 * mzOMt4 * lambda *
	sqr(sinb2)) * logMtOMssq + mLR2 / ms2 * 
       (-12.0 + 4.0 * mzOMt2 + 6.0 * mtOMs2) + mLR4 / ms4 * 
       (1.0 - 4.0 * mtOMs2 + 3.0 * mtOMs4) + mLR6 / ms6 * 
       (0.6 * mtOMs2 - 2.4 * mtOMs4 + 2.0 * mtOMs6) + mLR8 / ms8 * 
       (3.0 / 7.0 * mtOMs4 - 12.0 / 7.0 * mtOMs6 + 1.5 * mtOMs8)); 
    
    if (accuracy > 1) {
      // Following are non-t/stop corrections from hep-ph/9609331: checked
      double Pb, Pu, Pd, Pl, Pg, Pgp, P2h, P2hp, P1h, Pf;
      double sinth2 = sqr(sinth);
      Pb = 3.0 * (1.0 - 4.0 * sinth / 3.0 + 8.0 / 9.0 * sinth2);
      Pu = 3.0 * (2.0 - 4.0 * sinth  + 64.0 / 9.0 * sinth2);
      Pd = 3.0 * (2.0 - 4.0 * sinth  + 16.0 / 9.0 * sinth2);
      Pl = 3.0 * (2.0 - 4.0 * sinth + 8.0 * sinth2);
      Pf = Pu + Pd + Pl;
      Pg = -44.0 + 106.0 * sinth - 62.0 * sinth2;
      Pgp = 10.0 + 34.0 * sinth - 26.0 * sinth2;
      P2h = -10.0 + 2.0 * sinth - 2.0 * sinth2;
      P2hp = 8.0 - 22.0 * sinth + 10.0 * sinth2;
      double cos2b2 = sqr(cos(2.0 * beta)), cos2b4 = sqr(cos2b2);
      P1h = -9.0 * cos2b4 + (1.0 - 2.0 * sinth + 2.0 * sinth2) * cos2b2;
      
      // non bottom-mixing corrections: checked
      // Following was obtained from FeynHiggsFast.f
      double msusy2 = ms2 - mt2;
      double logMsScale = log(msusy2 / mz2);
      // Note if B undefined or zero, will have a problem!
      double logA0Scale = log(fabs(mAsq) / mz2);
      double mz4 = sqr(mz2), cosb4 = sqr(cosb2), mb2 = sqr(mb), mb4 =
	sqr(mb2);
      double howie11 = root2 * GMU * cosb2 * mz4 / (24.0 * pisq);
      double howie12 = howie11 * tanb, howie22 = howie12 * tanb;
      
      sigma(1, 1) = sigma(1, 1) - howie11 * 
	(
	 (36.0 * mb4 / (mz4 * cosb4) - 18.0 * mb2 / (mz2 * cosb2) 
	  + Pb + Pf + Pg + P2h) * logMsScale 
	 + (P1h - P2h) * logA0Scale
	 );
      sigma(1, 2) = sigma(1, 2) + howie12 * 
	(
	 (- 9.0 * mb2 / (mz2 * cosb2) + Pb + Pf + Pgp + P2hp) 
	 * logMsScale - (P1h + P2hp) * logA0Scale
	 );
      sigma(2, 2) = sigma(2, 2) - howie22 * 
	(
	 (Pb + Pf + Pg + P2h) * logMsScale + (P1h - P2h) * logA0Scale
	 ); 
      
      // sbottom mixing corrections: checked
      double mblr = displaySoftA(DA, 3, 3) + mu * tanb, 
	mblr2 = sqr(mblr);
      double mu2 = sqr(mu);
      
      sigma(1, 1) = sigma(1, 1) -
	(root2 * GMU / PI * 3.0 * 
	 (-(mb2 / msusy2 * mz2 * (mLR - mu / tanb) * 
	    (mblr + (mLR - mu / tanb) / 3.0)) + 4.0 / cosb2 *
	  mb4 * mblr / msusy2 * (mLR - mu / tanb) * 
	  (1.0 - (mblr / msusy2 * (mLR - mu / tanb)) / 12.0))) / 
	(8.0 * PI);
      sigma(1, 2) = sigma(1, 2)
	+ ((root2 * GMU / PI * 3.0 * 
	    (4.0 / cosb2 * mb4 * mblr / msusy2
	     * mu * (1.0 - (mblr / msusy2 * (mLR - mu / tanb)) / 6.0) -
	     mb2 / msusy2 * mz2 * (mblr * (mLR - 2.0 * mu / tanb ) + 
				   (mu2 + sqr(mLR - mu / tanb)) / 3.0) *
	     tanb)) / (16.0 * PI));
      sigma(2, 2) = sigma(2, 2) -
	(root2 * GMU / (8.0 * pisq) * 3.0 * 
	 (- ((1.0 / cosb2 * mb4 * mblr2 / sqr(msusy2) * mu2) / 3.0)+ mb2
	  / msusy2
	  * mu * mz2 * tanb * (mblr - (mu * tanb) / 3.0))); 
      
      /*         two loop contributions: checked  from hep-ph/9903404   */
      if (accuracy > 2) {
	sigma(2, 2) = sigma(2, 2) - 
	  (root2 * GMU / (PI * pisq) * alphas * mt4 / sinb2 * 
	   ((6.0 * mLR) / ms - (12.0 * mLR4) / (17.0 * ms4) + 
	    (2.0 - (3.0 * mLR2) / ms2) * log(ms2 / mt2) - 
	    3.0 * sqr(log(ms2 / mt2))
	    - 4.0 + 8.0 * mLR2 / ms2));
      }      
    }
    sigma(2, 1) = sigma(1, 2);
    
    mH = mH - sigma;
  }
  
  static DoubleVector temp(2);  
  double theta;
  
  temp = mH.sym2by2(theta);
  
  // Definitions are such that theta should diagonalise the matrix like
  // O = [ cos  sin ]
  //     [-sin  cos ] 
  // and
  // O m O^T = [ m2^2      ]
  //           [      m1^2 ]
  // where m1 < m2, therefore if they come out in the wrong order, 
  // add pi/2 onto theta.
  if (temp(2) > temp(1)) { theta = theta + PI * 0.5; }
  
  physpars.mhiggs(1) = ccbSqrt(minimum(temp(2), temp(1)));
  physpars.mhiggs(3) = ccbSqrt(maximum(temp(1), temp(2))); 
  
  double mA = displayPhys().mhiggs(2);
  double poleMasq = (displayMh2Squared() - displayMh1Squared() )
    / cos(2.0 * beta) - sqr(MZ);
  
  double piaa = 0.0;
  if (accuracy > 1)
    {
      piaa = piAA(mA, displayMu());
      poleMasq = 
	(displayMh2Squared() - displayTadpole2Ms() - displayMh1Squared() +
	 displayTadpole1Ms()) / cos(2.0 * beta) 
	- sqr(MZ) - pizztMS - piaa +
	sqr(sin(beta)) * displayTadpole1Ms() + sqr(cos(beta)) *
	displayTadpole2Ms();
    }

  // FUTURE WORK: could incorporate more accurate calculations on charged
  // Higgs from   hep-ph/9606211: include piH+H-
  double poleMhc = 
    poleMasq + sqr(MW) + piaa + piwwtMS;
  
  physpars.mhiggs(4) = ccbSqrt(poleMhc);
  physpars.mhiggs(2) = ccbSqrt(poleMasq);
  
  // two-loop Yukawa correction to mh^2: checked
  if (accuracy > 2) {
    double mstop1 = physpars.mu(1, 3);
    double mstop2 = physpars.mu(2, 3);
    double mstop1sq = sqr(mstop1), mstop2sq = sqr(mstop2);
    double t = 0.5 * log(mstop1sq * mstop2sq / mt4);
    double X = ( sqr( (mstop2sq - mstop1sq) / (4.0 * mt2) * 
		      sqr(sin(2.0 * physpars.thetat)) ) * 
		 (2.0 - (mstop2sq + mstop1sq) / (mstop2sq - mstop1sq) *
		  log(mstop2sq / mstop1sq)) +
		 (mstop2sq - mstop1sq) / (2.0 * mt2) * 
		 sqr(sin(2.0 * physpars.thetat)) * log(mstop2sq / mstop1sq)
		 );
    physpars.mhiggs(1) = sqrt(sqr(physpars.mhiggs(1)) + 9.0 / 
			      (16.0 * sqr(pisq)) *
			      sqr(GMU) * mt2 * mt4 * (X * t + sqr(t)));
  } 
  physpars.thetaH = theta;
}

void MssmSoftsusy::addCharginoLoop(DoubleMatrix & mass) {
  double g2 = displayGaugeCoupling(2), 
    ht = displayYukawaElement(YU, 3, 3),
    hb = displayYukawaElement(YD, 3, 3),
    q = displayMu(), mu = -displaySusyMu(), M2 = mGaugino(2), 
    MA = physpars.mhiggs(2), tanb = displayTanb(); // brevity 
  
  // From hep-ph/9606211, approx formulae only, both checked! Results are a
  // bit inaccurate....
  double deltaM2 = - sqr(g2) / (16.0 * sqr(PI)) *
    (9.0 * b1(M2, 0.0, sqrt(displaySoftMassSquared(mQl)(1, 1)), q) +
     3.0 * b1(M2, 0.0, sqrt(displaySoftMassSquared(mLl)(1, 1)), q) +
     mu / M2 * sin(2.0 * atan(tanb)) *
     (b0(M2, mu, MA, q) -
      b0(M2, mu, MZ, q)) +
     b1(M2, mu, MA, q) +
     b1(M2, mu, MZ, q)
     + 4.0 * b1(M2, M2, MW, q) -
     8.0 * b0(M2, M2, MW, q));
  
  double deltaMu = - 3.0 / (32.0 * sqr(PI)) *
    ((sqr(hb) + sqr(ht)) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mQl)(3, 3)), q) + 
     sqr(ht) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mUr)(3, 3)), q) + sqr(hb) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mDr)(3, 3)), q)) 
    - 3.0 * sqr(g2) / (64.0 * sqr(PI)) * 
    (b1(mu, M2, MA, q) + b1(mu, M2, MZ, q) + 2.0 * b1(mu, mu, MZ, q) - 4.0 *
     b0(mu, mu, MZ, q));
  
  mass(1, 1) = mass(1, 1) * (1.0 + deltaM2);
  mass(2, 2) = mass(2, 2) * (1.0 + deltaMu);
  
  // These are the proper corrections:
  /*
    double p = 100;
    DoubleMatrix sigmaL(2, 2);
    
    DoubleMatrix aPsicUp(2, 2), aPsicDown(2, 2), aPsicLep(2, 2);
    DoubleVector aPsicTop(2), aPsicBot(2), aPsicTau(2);
    DoubleVector aPsicTopm(2), aPsicBotm(2), aPsicTaum(2);
    aPsicTop(2) = -ht; aPsicBot(2) = -hb; aPsicTau(2) = -htau;
    int fam; for (fam=1; fam<=2; fam++)
    {
    aPsicDown(fam, 1) = g2;       aPsicLep(fam, 1) = g2; 
    }
    aPsicBot = g2; aPsicTau = g2;
    aPsicTopm = rot2d(thetat) * aPsicTop;
    aPsicBotm = rot2d(thetab) * aPsicBot;
    aPsicTaum = rot2d(thetatau) * aPsicTau;
    
    int i; for (i=1; i<=2; i++)
    {
    sigmaL = sigmaL + 
    1.5 * outerProduct(aPsicTopm, aPsicTopm) * 
    b1(p, mtop, physpars.mu(i, 3), q) + 
    1.5 * outerProduct(aPsicBotm, aPsicBotm) * 
    b1(p, mbot, physpars.md(i, 3), q) + 
    1.5 * outerProduct(aPsicTaum, aPsicTaum) * 
    b1(p, mtau, physpars.msnu(i, 3), q);
    }
    sigmaL(1, 1) = sigmaL(1, 1) + 
    1.5 * sqr(g) * 
    (b1(p, md, physpars.mu(1, 1), q) + b1(p, me, physpars.msnu(1), q) +
    b1(p, ms, physpars.mu(1, 2), q) + b1(p, mmu, physpars.msnu(2), q) +
    b1(p, mtau
    */
  
  
  
}

// checked
void MssmSoftsusy::charginos(int accuracy, double piwwtMS) {
  double tanb = displayTanb(), smu = -displaySusyMu();
  DoubleMatrix mCh(2, 2);
  
  // tree level mass matrix
  mCh(1, 1) = mGaugino(2);
  mCh(2, 1) = sqrt(2.0) * sqrt(sqr(MW) + piwwtMS) * cos(atan(tanb)); 
  mCh(2, 1) = sqrt(2.0) * sqrt(sqr(MW)) * cos(atan(tanb));
  mCh(1, 2) = mCh(2, 1) * tanb;
  mCh(2, 2) = -smu;
  
  if (accuracy > 0) addCharginoLoop(mCh);  
  
  physpars.mch = mCh.asy2by2(physpars.thetaL, physpars.thetaR);
}

double MssmSoftsusy::thet(double a, double b, double c = 0.0) {
  double yy = maximum(sqr(a), sqr(b));
  yy = maximum(yy, sqr(c));
  return log(yy / sqr(displayMu()));
}

void MssmSoftsusy::addNeutralinoLoop(DoubleMatrix & mass) {
  double gp = displayGaugeCoupling(1) * sqrt(0.6), 
    g2 = displayGaugeCoupling(2), ht = displayYukawaElement(YU, 3, 3), 
    hb = displayYukawaElement(YD, 3, 3),
    q = displayMu(), mu = -displaySusyMu(), M2 = mGaugino(2), M1 =
    mGaugino(1), MA = physpars.mhiggs(2), tanb = displayTanb(); // brevity 
  
  double msq1 = sqrt(mQLsq(1, 1)), mslep1 = sqrt(mLLsq(1, 1));
  
  // From hep-ph/9606211, approx formulae only, both checked!
  double deltaM1 = sqr(gp) / (16.0 * sqr(PI)) * 
    (11.0 * b1(M1, 0.0, msq1, q) + 9.0 * b1(M1, 0.0, mslep1, q) + mu / M1 * sin
     (2.0 * atan(tanb)) * (b0(M1, mu, MA, q) - b0(M1, mu, MZ, q)) 
     + b1(M1, mu, MA, q) + b1(M1, mu, MZ, q));
  
  double deltaM2 = - sqr(g2) / (16.0 * sqr(PI)) *
    (9.0 * b1(M2, 0.0, sqrt(displaySoftMassSquared(mQl)(1, 1)), q) +
     3.0 * b1(M2, 0.0, sqrt(displaySoftMassSquared(mLl)(1, 1)), q) +
     mu / M2 * sin(2.0 * atan(tanb)) *
     (b0(M2, mu, MA, q) - b0(M2, mu, MZ, q)) +
     b1(M2, mu, MA, q) + b1(M2, mu, MZ, q)
     + 4.0 * b1(M2, M2, MW, q) - 8.0 * b0(M2, M2, MW, q));
  
  double deltaMu = - 3.0 / (32.0 * sqr(PI)) *
    ((sqr(hb) + sqr(ht)) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mQl)(3, 3)), q) + 
     sqr(ht) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mUr)(3, 3)), q) + sqr(hb) * 
     b1(mu, 0.0, sqrt(displaySoftMassSquared(mDr)(3, 3)), q)) 
    - 3.0 * sqr(g2) / (64.0 * sqr(PI)) * 
    (b1(mu, M2, MA, q) + b1(mu, M2, MZ, q) + 2.0 * b1(mu, mu, MZ, q) - 4.0 *
     b0(mu, mu, MZ, q));
  
  
  mass(1, 1) = mass(1, 1) * (1.0 + deltaM1);
  mass(2, 2) = mass(2, 2) * (1.0 + deltaM2);
  mass(3, 4) = mass(3, 4) * (1.0 + deltaMu);
}

// mixNeut set to diagonal = mixNeut^T mNeutralino mixNeut: checked
void MssmSoftsusy::neutralinos(int accuracy, double piwwtMS, double pizztMS) {
  double tanb = displayTanb();
  double cosb = cos(atan(tanb));
  DoubleMatrix mNeut(4, 4);
  
  // tree level
  mNeut(1, 1) = mGaugino(1);
  mNeut(2, 2) = mGaugino(2);
  mNeut(1, 3) = - sqrt(fabs(sqr(MZ) + pizztMS)) * cosb * 
    calcSinthdrbar();
  mNeut(1, 4) = - mNeut(1, 3) * tanb;
  mNeut(2, 3) = sqrt(fabs(sqr(MW) + piwwtMS)) * cosb;

  mNeut(2, 4) = - mNeut(2, 3) * tanb;
  mNeut(3, 4) = -displaySusyMu();
  if (accuracy > 0) addNeutralinoLoop(mNeut);
  
  mNeut.symmetrise();
  if (mNeut.diagonaliseSym(physpars.mixNeut, physpars.mneut) > EPS *
      1.0e-3) 
    { cout << "accuracy bad in neutralino diagonalisation"; cout.flush();
    exit(1); }

}

// One loop corrections to gluino pole mass: hep-ph/9606211
// BUG fixed to use g3 at current scale 8/1/2001
void MssmSoftsusy::gluino() {
  /*  double alphas = sqr(displayGaugeCoupling(3)) / (4.0 * PI);
  double delta1 = 0.75 * alphas / PI * 
    (6.0 * log(displayMu() / fabs(mGaugino(3))) + 5.0);
  
  double delta2 = - 3.0 * alphas / PI * 
    b1(mGaugino(3), 0.0, physpars.mu(1, 1), displayMu());
  physpars.mGluino = fabs(mGaugino(3) / (1.0 - delta1 - delta2)); */
  double delta = 0.0, p = physpars.mGluino, Q = displayMu();
  if (physpars.mGluino == 0.0) physpars.mGluino = displayGaugino()(3);
  delta = delta - physpars.mGluino * 
    (15.0 + 9.0 * log(sqr(Q / physpars.mGluino)));

  int i; for (i=1; i<=2; i++)
    delta = delta + physpars.mGluino * 
      (b1(p, dataSet.displayMass(mUp), physpars.mu(i, 1), Q) +
       b1(p, dataSet.displayMass(mCharm), physpars.mu(i, 2), Q) +
       b1(p, dataSet.displayMass(mTop), physpars.mu(i, 3), Q) +
       b1(p, dataSet.displayMass(mDown), physpars.md(i, 1), Q) +
       b1(p, dataSet.displayMass(mStrange), physpars.md(i, 2), Q) +
       b1(p, dataSet.displayMass(mBottom), physpars.md(i, 3), Q));
  
  // Third family mixing contribution:
  delta = delta + dataSet.displayMass(mTop) * sin(2.0 * physpars.thetat) *
    (b0(p, dataSet.displayMass(mTop), physpars.mu(1, 3), Q) - 
     b0(p, dataSet.displayMass(mTop), physpars.mu(2, 3), Q));
  delta = delta + dataSet.displayMass(mBottom) * sin(2.0 * physpars.thetab) *
    (b0(p, dataSet.displayMass(mBottom), physpars.md(1, 3), Q) - 
     b0(p, dataSet.displayMass(mBottom), physpars.md(2, 3), Q));

  delta = delta * sqr(displayGaugeCoupling(3)) / (16.0 * sqr(PI));
     
  physpars.mGluino = displayGaugino()(3) - delta;
}

// Formulae from hep-ph/9801365: checked but should be checked again!
// Implicitly calculates at the current scale.

double MssmSoftsusy::calcRunningMt() const {

  // For brevity
  double    thetaWDRbar = asin(calcSinthdrbar());
  double    cw2DRbar    = sqr(cos(thetaWDRbar));
  double    mtpole      = displayDataSet().displayPoleMt();
  const double  costh   = (MW / MZ);
  const double    cw2   = sqr(costh) ;
  const double    sw2   = (1.0 - cw2);

  double    sinth   = sqrt(1.0 - sqr(costh))  ;
  double    ht      = displayYukawaMatrix(YU)(3, 3);
  double    hb      = displayYukawaMatrix(YD)(3, 3);
  double    mstop1  = displayPhys().mu(1,3);
  double    mstop2  = displayPhys().mu(2,3);
  double    mg      = displayPhys().mGluino;
  double    thetat  = displayPhys().thetat ;
  double    st      = sin(thetat) ;
  double    ct      = cos(thetat) ;
  double    mH      = displayPhys().mhiggs(3); 
  double    alpha   = displayPhys().thetaH ;
  double    g       = displaySusy().displayGauge()(2);
  double    mh0     = displayPhys().mhiggs(1);
  double    mA      = displayPhys().mhiggs(2);
  double    beta    = atan(displaySusy().displayTanb());
  double    mb      =  displayDataSet().displayMass(mBottom) ;
  double    mHc     = displayPhys().mhiggs(4);
  double    gp      = displayGaugeCoupling(1) * sqrt(0.6);
  double    thetab  = displayPhys().thetab;

  double resigmat = 0.0; 
  
  // 1 loop QCD only -- DRbar 10% correction
  resigmat = resigmat - (5.0 + 6.0 * log(displayMu() / mtpole)) * 4.0 *
    sqr(displayGaugeCoupling(3)) / 3.0;
  
  // stop/gluino correction 6% correction
  resigmat = resigmat + 4.0 * sqr(displayGaugeCoupling(3)) / 3.0 *
    (b1(mtpole, mg, mstop1, displayMu()) + 
     b1(mtpole, mg, mstop2, displayMu()) -
     sin(2.0 * thetat) * mg / mtpole *  
     (b0(mtpole, mg, mstop1, displayMu()) - 
      b0(mtpole, mg, mstop2, displayMu()))); 
  
  // 2 loop QCD --> MSbar only...bit dodgey!
  resigmat = resigmat - 1.11 * sqr(sqr(displayGaugeCoupling(3)));
  
  // rest are extra bits from Matchev et al: 2% corrections
  double alphaMZ = displayDataSet().displayAlpha(ALPHA),
    q = displayMu();
  double gtL = 0.5 - 2 * sw2 / 3.0, gtR = 2 * sw2 / 3.0;
  
  resigmat = resigmat + sqr(ht) / 2.0 * 
    (sqr(sin(alpha)) * (b1(mtpole, mtpole, mH, q) + b0(mtpole, mtpole, mH, q))
     + sqr(cos(alpha)) * (b1(mtpole, mtpole, mh0, q) + 
			  b0(mtpole, mtpole, mh0, q))
     + sqr(cos(beta)) * (b1(mtpole, mtpole, mA, q) - 
			 b0(mtpole, mtpole, mA, q)) 
     + sqr(sin(beta)) * (b1(mtpole, mtpole, MZ, q) - 
			 b0(mtpole, mtpole, MZ, q))) + 
    0.5 * ( (sqr(hb) * sqr(sin(beta)) + sqr(ht) * sqr(cos(beta))) * 
	    b1(mtpole, mb, mHc, q) +
	    (sqr(g) + sqr(hb) * sqr(cos(beta)) + sqr(ht) * sqr(sin(beta))) * 
	    b1(mtpole, mb, MW, q)) +
    sqr(hb) * sqr(cos(beta)) * (b0(mtpole, mb, mHc, q) 
				- b0(mtpole, mb, MW, q)) -
    (alphaMZ * 16.0 * PI) / 9.0 * (5.0 + 6.0 * log(q / mtpole)) +
    sqr(g) / cw2DRbar * ( (sqr(gtL) + sqr(gtR)) * b1(mtpole, mtpole, MZ, q) +
			  4.0 * gtL * gtR * b0(mtpole, mtpole, MZ, q) );
  
  DoubleMatrix neutralinoContribution(4, 2);
  // Neutralino contribution
  static DoubleVector aPsi0TStopr(4), bPsi0TStopr(4), aPsi0TStopl(4),
    bPsi0TStopl(4); 
  aPsi0TStopr(1) = - 4 * gp / (3.0 * sqrt(2.0));
  bPsi0TStopl(1) = gp / (3.0 * sqrt(2.0));
  bPsi0TStopl(2) = g / sqrt(2.0);
  aPsi0TStopl(4) = ht;
  bPsi0TStopr(4) = ht;

  static ComplexVector aChi0TStopl(4), bChi0TStopl(4), aChi0TStopr(4),
    bChi0TStopr(4);

  static ComplexMatrix n(4, 4); static DoubleVector mneut(4);
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions  

  aChi0TStopl = n.complexConjugate() * aPsi0TStopl;
  bChi0TStopl = n * bPsi0TStopl;
  aChi0TStopr = n.complexConjugate() * aPsi0TStopr;
  bChi0TStopr = n * bPsi0TStopr;

  static ComplexMatrix aNeutTStop(4, 2), bNeutTStop(4, 2);
  static DoubleMatrix fNeutTStop(4, 2), gNeutTStop(4, 2);

  int i, j;
  static DoubleMatrix O(2, 2);
  ComplexVector tt(2), t1(2), t2(2);
  O = rot2d(thetat);
  for (i=1; i<=4; i++) {
    tt(1) = aChi0TStopl(i); tt(2) = aChi0TStopr(i);      
    t1 = O * tt;

    tt(1) = bChi0TStopl(i); tt(2) = bChi0TStopr(i);      
    t2 = O * tt;    
    for (j=1; j<=2; j++) {
      aNeutTStop(i, j) = t1(j);
      bNeutTStop(i, j) = t2(j);
      // functions of couplings needed for loops
      fNeutTStop(i, j) = sqr(aNeutTStop(i, j).mod()) + 
	sqr(bNeutTStop(i, j).mod());

      gNeutTStop(i, j) = 2.0 * 
	(aNeutTStop(i, j) * bNeutTStop(i, j).conj()).real(); 
      
      neutralinoContribution(i, j) = (fNeutTStop(i, j) * 
	 b1(mtpole, mneut(i), displayPhys().mu(j, 3), q) + 
	 gNeutTStop(i, j) * mneut(i) /  mtpole *  
	 b0(mtpole, mneut(i), displayPhys().mu(j, 3), q)) * 0.5;

      resigmat = resigmat + 
	(fNeutTStop(i, j) * 
	 b1(mtpole, mneut(i), displayPhys().mu(j, 3), q) + 
	 gNeutTStop(i, j) * mneut(i) /  mtpole *  
	 b0(mtpole, mneut(i), displayPhys().mu(j, 3), q)) * 0.5;
    }
  }

  // Chargino contribution  
  static DoubleVector bPsicTSbotl(2), bPsicTSbotr(2), aPsicTSbotl(2); 

  bPsicTSbotl(1) = g;
  bPsicTSbotr(2) = - hb;
  aPsicTSbotl(2) = -ht;
  
  static DoubleVector aPsicTSbotr(2), aPsicCSbotl(2);
  static ComplexVector aChicTSbotr(2), aChicTSbotl(2), bChicTSbotl(2),
      bChicTSbotr(2);
  static ComplexMatrix aChTSbot(2, 2), bChTSbot(2, 2);
  DoubleMatrix fChTSbot(2, 2), gChTSbot(2, 2); 

  static ComplexMatrix u(2, 2), v(2, 2); static DoubleVector mch(2);
  mpzCharginos(u, v, mch);

  aChicTSbotl = v.complexConjugate() * aPsicTSbotl;
  bChicTSbotl = u * bPsicTSbotl;
  aChicTSbotr = v.complexConjugate() * aPsicTSbotr;
  bChicTSbotr = u * bPsicTSbotr;
       
  float charginoContribution = 0.0;

  for(i=1; i<=2; i++) {  
    O = rot2d(thetab);      
    tt(1) = aChicTSbotl(i); tt(2) = aChicTSbotr(i);
    t1 = O * tt;
    tt(1) = bChicTSbotl(i); tt(2) = bChicTSbotr(i);      
    t2 = O * tt;
    for (j=1; j<=2; j++) {
	aChTSbot(i, j) = t1(j);
	bChTSbot(i, j) = t2(j);

      	fChTSbot(i, j) = sqr(aChTSbot(i, j).mod()) + 
	  sqr(bChTSbot(i, j).mod());
	gChTSbot(i, j) = 2.0 * (aChTSbot(i, j) * 
				bChTSbot(i, j).conj()).real(); 
      
      	charginoContribution = charginoContribution + 
	  (fChTSbot(i, j) * 
	   b1(mtpole, mch(i), fabs(displayPhys().md(j, 3)),
	      q) +
	   gChTSbot(i, j) * mch(i) / mtpole * 
	   b0(mtpole, mch(i), displayPhys().md(j, 3), q)) * 0.5;
    }            
  }

  resigmat = resigmat + charginoContribution;
  
  resigmat = resigmat * mtpole / (16.0 * sqr(PI));  

  return mtpole + resigmat;

}

// Using approximation of Matchev+Pierce - include contributions proportional
// to g and enhanced by tan beta or mu
double MssmSoftsusy::calcRunningMtau() const {
  double delta = sqr(displayGauge()(2)) / (16 * sqr(PI)) *
    (-displaySusyMu()) * displayGaugino()(2) * displayTanb() /
    (sqr(displaySusyMu()) - sqr(displayGaugino()(2))) *
    (b0(0.0, displayGaugino()(2), displayPhys().msnu(3), displayMu()) -
     b0(0.0, -displaySusyMu(), displayPhys().msnu(3), displayMu()));
  
  return displayDataSet().displayMass(mTau) * (1.0 - delta);
}

double MssmSoftsusy::calcRunningMb() const {
  if (displayMu() != MZ) {
    cout << "MssmSoftsusy::calcRunningMb called with mu=" <<
      displayMu() << endl; 
    exit(1);
  }
  
  double mbMZ = displayDataSet().displayMass(mBottom), mtpole =
    displayDataSet().displayPoleMt(), alphasMZ =
    sqr(displayGaugeCoupling(3)) / (4.0 * PI); 
  
  double    msbot1  = displayPhys().md(1,3);
  double    msbot2  = displayPhys().md(2,3);
  double    mstop1  = displayPhys().mu(1,3);
  double    mstop2  = displayPhys().mu(2,3);
  double    smu     = -displaySusyMu() ;
  double    tanb    = displayTanb() ;
  double    mg      = displayPhys().mGluino;
  double    thetab = displayPhys().thetab;
  double    thetat = displayPhys().thetat ;
  double    ht      = displayYukawaMatrix(YU)(3, 3);
  double    M2      = displayGaugino()(2);
  double    g       = displaySusy().displayGauge()(2);

  double p = mtpole;
  p = 0.0;
  
  double deltaSquarkGluino = - alphasMZ / (3.0 * PI) *
    (b1(p, mg, msbot1, displayMu()) + 
     b1(p, mg, msbot2, displayMu()) - 
     sin(2.0 * thetab) * mg / PMBOTTOM *  
     (b0(p, mg, msbot1, displayMu()) - 
      b0(p, mg, msbot2, displayMu())));
  
  double deltaSquarkChargino = sqr(ht) / (16 * sqr(PI)) * smu *
    (displaySoftA(UA, 3, 3) * tanb + smu) / (sqr(mstop2) - sqr(mstop1)) *
    (b0(p, smu, mstop2, displayMu()) - 
     b0(p, smu, mstop1, displayMu())) 
    + sqr(g) / (16 * sqr(PI)) * 
    (smu * M2 * tanb / (sqr(smu) - sqr(M2)) *
     (sqr(cos(thetat)) * b0(p, M2, mstop2, displayMu()) +
      sqr(sin(thetat)) * b0(p, M2, mstop1, displayMu()) - 
      sqr(cos(thetat)) * b0(p, smu, mstop2, displayMu()) -
      sqr(sin(thetat)) * b0(p, smu, mstop1, displayMu())));
  
  return mbMZ * (1 - deltaSquarkGluino - deltaSquarkChargino);
}

// Organises calculation of physical quantities such as sparticle masses etc
// Call AT MSusy
void MssmSoftsusy::physical(int accuracy) {
  double sinthDRbarMS, piwwtMS, pizztMS;

  if (accuracy == 0) {
    sinthDRbarMS = 0.0;
    piwwtMS = 0.0;
    pizztMS = 0.0;
  }

  sinthDRbarMS = calcSinthdrbar();

  piwwtMS = piWWT(MW, displayMu());
  pizztMS = piZZT(MZ, displayMu());

  double mt = dataSet.displayMass(mTop), 
    mb = dataSet.displayMass(mBottom), 
    mtau = dataSet.displayMass(mTau);
  // Include sparticle mixing in third family:
  // Stops
  DoubleVector  temp(2);
  temp = getSpart(mt, mUr, physpars.thetat, 3, accuracy,
		  pizztMS, sinthDRbarMS).apply(ccbSqrt);
  
  physpars.mu(1, 3) = temp(1); physpars.mu(2, 3) = temp(2); 
  // Sbottoms
  temp = getSpart(mb, mDr, physpars.thetab, 3, accuracy,
		  pizztMS, sinthDRbarMS).apply(ccbSqrt);
  physpars.md(1, 3) = temp(1); physpars.md(2, 3) = temp(2); 
  
  // Staus
  temp = 
    getSpart(mtau, mEr, physpars.thetatau, 3, accuracy,
	     pizztMS, sinthDRbarMS).apply(ccbSqrt);
  physpars.me(1, 3) = temp(1); physpars.me(2, 3) = temp(2); 
  // Stau sneutrino
  double theta;
  physpars.msnu(3) = ccbSqrt(getSpart(0.0, mLl, theta, 3, accuracy,
				      pizztMS, sinthDRbarMS)(1));
  
  // Same again, but now for other two families
  int i;
  for (i=1; i<=2; i++) {
    temp = getSpart(0.0, mUr, theta, i, accuracy, pizztMS, 
		    sinthDRbarMS).apply(ccbSqrt);
    physpars.mu(1, i) = temp(1);   physpars.mu(2, i) = temp(2); 
    temp = getSpart(0.0, mDr, theta, i, accuracy, pizztMS, 
		    sinthDRbarMS).apply(ccbSqrt);
    physpars.md(1, i) = temp(1);   physpars.md(2, i) = temp(2); 
    temp = getSpart(0.0, mEr, theta, i, accuracy, pizztMS, 
		    sinthDRbarMS).apply(ccbSqrt);
    physpars.me(1, i) = temp(1);   physpars.me(2, i) = temp(2); 
    physpars.msnu(i) = ccbSqrt(getSpart(0.0, mLl, theta, i, accuracy,
					pizztMS, sinthDRbarMS)(1));
  }
  
  // Charginos/neutralinos/higgs
  higgs(accuracy, piwwtMS, pizztMS);   
  gluino(); 
  charginos(accuracy, piwwtMS); 
  neutralinos(accuracy, piwwtMS, pizztMS);
}

// For a given trial value of the log of field H2, gives the value of the
// potential at the minimum. The following global variables must be set before
// it is called:
static double unificationScale, minTol;
extern double minimufb3(double lnH2) {
  MssmSoftsusy temp(tempSoft1);
  double mx = unificationScale; 
  double mu = -temp.displaySusyMu();
  
  int family = 1; // family could be 2 as well if they're very different
  
  // field VEVS
  double htau = temp.displayYukawaMatrix(YE)(3, 3);
  double h2 =  - exp(lnH2), 
    eR = sqrt(fabs(mu * h2 / htau)),
    Lisq = -4.0 * temp.displaySoftMassSquared(mLl)(family, family) / 
    (0.6 * sqr(temp.displayGauge()(1)) +
     sqr(temp.displayGauge()(2))) + sqr(h2) + sqr(eR);
  
  // qhat is scale at which one-loop potential corrections are smallest:
  // iterate
  double qhat = getQhat(minTol,eR, h2, Lisq, mx, temp);
  if (qhat < 0.0) {
    cout << "Error: qhat returned negative in ufb3min" << endl;
    exit(1);
  }
  
  double vufb3 = ufb3fn(mu, htau, h2, family, temp);
  if (PRINTOUT > 1) cout << vufb3 << endl;
  return vufb3;  
};

double ufb3fn(double mu,double htau,double h2,int family,MssmSoftsusy temp) {
  double vufb3 = 0.0;
  // potential value for these VEVs
  if (fabs(h2) > 
      sqrt(sqr(mu) / (4.0 * sqr(htau)) + 
	   4.0 * temp.displaySoftMassSquared(mLl)(family, family) /  
	   (0.6 * sqr(temp.displayGauge()(1)) +
	    sqr(temp.displayGauge()(2)))) - fabs(mu) / 
      (0.6 * sqr(temp.displayGauge()(1)) +
       sqr(temp.displayGauge()(2))))
    vufb3 = 
      sqr(h2) * (temp.displayMh2Squared() +
		 temp.displaySoftMassSquared(mLl)(family, family)) + 
      fabs(mu * h2) / htau * 
      (temp.displaySoftMassSquared(mLl)(3, 3) +
       temp.displaySoftMassSquared(mEr)(3, 3) 
       + temp.displaySoftMassSquared(mLl)(family, family)) -
      2.0 * sqr(temp.displaySoftMassSquared(mLl)(family, family)) / 
      (0.6 * sqr(temp.displayGauge()(1)) +
       sqr(temp.displayGauge()(2)));
  else
    vufb3 = 
      sqr(h2) * temp.displayMh2Squared() + 
      fabs(mu * h2) / htau * 
      (temp.displaySoftMassSquared(mLl)(3, 3) +
       temp.displaySoftMassSquared(mEr)(3, 3)) +  
      1.0 / 8.0 * (0.6 * sqr(temp.displayGauge()(1)) +
		   sqr(temp.displayGauge()(2))) * 
      sqr(sqr(h2) + fabs(mu * h2) / htau);
  
  if (PRINTOUT > 1) cout << vufb3 << endl;
  return vufb3;
}

// For ufb3direction, returns scale at which one-loop corrections are smallest
double getQhat(double inminTol,double eR, double h2, double Lisq, double mx,
		MssmSoftsusy & temp) {
  double oldQhat = -1.0e16;
  int maxNum = 40;
  
  int d; for (d = 1; d <= maxNum; d++)     {
    double qhat = 
      maximum(maximum(maximum(temp.displayGauge()(2) * eR, 
		     temp.displayGauge()(2) * fabs(h2)), 
		temp.displayGauge()(2) * sqrt(fabs(Lisq))),
	   temp.displayYukawaMatrix(YU)(3, 3) * fabs(h2));
    // Run all paramaters to that scale
    if (qhat < mx) temp.runto(qhat);
    else temp.runto(mx); 
    if (PRINTOUT > 1) cout << qhat << " ";
    
    if (fabs((qhat - oldQhat) / qhat) < inminTol) return qhat;
    oldQhat = qhat;
  }
  // Return NOB if no convergence on qhat
  return -6.66e66;
}

// Input mx the scale up to which you search for minima
// Returns minimum value of potential along that direction
// Does ufbs truly properly but takes ages.
double MssmSoftsusy::ufb3sl(double mx) const {
  // Set external variables
  tempSoft1 = *this; 
  unificationScale = mx;
  // Running should be faster from high scales on the whole
  tempSoft1.runto(mx);
  
  double ax = log(1.0e3), bx = 0.5*(log(mx) + log(1.0e3)), cx = log(mx);
  
  double tol = 1.0e-3, lnx; minTol = tol * 10.0;
  // Numerical recipes routine to determine minimum of potential specified in
  // minimufb3
  double Vmin = findMinimum(ax, bx, cx, minimufb3, tol, &lnx);
  
  return Vmin;
}

// Does SUSY (and other) threshold corrections to alphaS
// Input alphas in MSbar and it returns it in DRbar scheme. From hep-ph/9606211
double MssmSoftsusy::qcdSusythresh(double alphasMSbar, double q) const {
  double mt = displayDataSet().displayPoleMt();
  double deltaAlphas = alphasMSbar / (2.0 * PI) *
    (0.5 - 2.0 / 3.0 * log(mt / q) - 2.0 * log(displayPhys().mGluino / q));
  
  int i,j;
  for (i=1; i<=2; i++)
    for (j=1; j<=3; j++)
      deltaAlphas = deltaAlphas - alphasMSbar / (12.0 * PI) * 
	(log(displayPhys().mu(i, j) / q) + log(displayPhys().md(i, j) /
						q));
  return alphasMSbar / (1.0 - deltaAlphas); 
}

// Does SUSY (and other) threshold corrections to alphaEm - returns alpha in
// DRbar scheme at scale Q. From hep-ph/9606211. Input empirical value of
// alpha at 0 momentum....
double MssmSoftsusy::qedSusythresh(double alphaEm, double q) const {

  if (displayPhys().mhiggs(4) < EPS) return 0.0;

  double mtpole = displayDataSet().displayPoleMt();
  double deltaAlpha = 0.0682 -  alphaEm / (2 * PI) * 
    (-7.0 * log(MW / q) + 16.0 / 9.0 * log(mtpole / q)
     + log(displayPhys().mhiggs(4) / q) / 3.0 + 4.0 / 9.0 * 
     (log(displayPhys().mu(1,1) / q) + log(displayPhys().mu(2,1) / q) + 
      log(displayPhys().mu(1,2) / q) + log(displayPhys().mu(2,2) / q) + 
      log(displayPhys().mu(1,3) / q) + log(displayPhys().mu(2,3) / q)) + 
     (log(displayPhys().md(1,1) / q) + log(displayPhys().md(2,1) / q) + 
      log(displayPhys().md(1,2) / q) + log(displayPhys().md(2,2) / q) + 
      log(displayPhys().md(1,3) / q) + log(displayPhys().md(2,3) / q)) 
     / 9.0 +
     (log(displayPhys().me(1,1) / q) + log(displayPhys().me(2,1) / q) + 
      log(displayPhys().me(1,2) / q) + log(displayPhys().me(2,2) / q) + 
      log(displayPhys().me(1,3) / q) + log(displayPhys().me(2,3) / q)) 
     / 3.0 
     + (log(fabs(displayPhys().mch(1)) / q) 
	+ log(fabs(displayPhys().mch(2)) / q)) 
     * 4.0 / 3.0);

  return alphaEm / (1.0 - deltaAlpha);
}


// Prints out what the lsp is
void recogLsp(int temp, int posj) {
  switch(temp) {
  case 0: cout << "neutralino"; break;
  case 1: 
    switch(posj)
      {
      case 3: cout << "stop"; break;
      case 2: cout << "scharm"; break;
      case 1: cout << "sup"; break;
      } break;
  case 2:
    switch(posj)
      {
      case 3: cout << "sbottom"; break;
      case 2: cout << "sstange"; break;
      case 1: cout << "sdown"; break;
      } break;
  case 3:
    switch(posj)
      {
      case 3: cout << "stau"; break;
      case 2: cout << "smu"; break;
      case 1: cout << "selectron"; break;
      } break;
  case 4: cout << "chargino"; break;
  case 5: cout << "sneutrino"; break;
  case 6: cout << "gluino"; break;
  default:
    cout << "Wrong input to lsp printing routine\n";
    exit(1); break;
  }
  
}

// Returns lsp mass in mass and function return labels which particle is lsp:
// 0 is neutralino posi = #, posj = 0
int MssmSoftsusy::lsp(double & mass, int & posi, int & posj) const {
  int temp = 0, pos1, pos2;
  sPhysical s(displayPhys());
  
  double minmass = s.mneut.apply(fabs).min(pos1); posi = pos1; posj = 0;
  
  // up squarks 1
  double lightest = s.mu.apply(fabs).min(pos1, pos2);
  if (lightest < minmass) { 
    minmass = lightest; posi = pos1; posj = pos2; temp = 1; }
  
  // down squarks 2
  lightest = s.md.apply(fabs).min(pos1, pos2);
  if (lightest < minmass) { 
    minmass = lightest; posi = pos1; posj = pos2; temp = 2; }
  
  // sleptons 3
  lightest = s.me.apply(fabs).min(pos1, pos2);
  if (lightest < minmass) { 
    minmass = lightest; posi = pos1; posj = pos2; temp = 3; }
  
  // charginos 4
  lightest = s.mch.apply(fabs).min(pos1);
  if (lightest < minmass) { 
    minmass = lightest; posi = pos1; posj = 0; temp = 4; }
  
  // sneutrinos 5
  lightest = s.msnu.apply(fabs).min(pos1);
  if (lightest < minmass) { 
    minmass = lightest; posi = pos1; posj = 0; temp = 5; }
  
  // gluino 6
  lightest = s.mGluino;
  if (lightest < minmass) { 
    minmass = lightest; posi = 0; posj = 0; temp = 6; }
  
  mass = minmass;
  return temp;
}

// physpars should be defined already for this
double MssmSoftsusy::calcMs() const {
  if (displayPhys().mu(2, 3) != 0.0 &&  displayPhys().mu(1, 3) != 0)
    return sqrt(displayPhys().mu(2, 3) * displayPhys().mu(1, 3));
  else
    return MZ;  // DEFAULT
}

// Provides the first guess at a SUSY object at mt, inputting tanb and oneset
// (should be at MZ) - it's very crude, doesn't take radiative corrections
// into account etc. 
MssmSusy guessAtSusyMt(double tanb, const QedQcd & oneset) {
  if (oneset.displayMu() != MZ) {
    cout << 
      "WARNING:guessAtSusymt in softsusy.cc called with oneset at scale" <<
      oneset.displayMu() << "\ninstead of " << MZ << endl;
  }
  
  // This bit gives a guess at a SUSY object
  QedQcd leAtMt(oneset);

  DoubleVector a(3), g(3);
  double sinth2 = 1.0 - sqr(MW / MZ);
  // Gauge couplings at mt
  a = leAtMt.getGaugeMu(oneset.displayPoleMt(), sinth2);
  
  MssmSusy t; 
  t.setTanb(tanb);
  double beta = atan(tanb);
  
  // Yukawa couplings
  double vev = 246.22;
  double ht = leAtMt.displayMass(mTop) * sqrt(2.0) / (vev * sin(beta));
  double hb =  ht * tanb * leAtMt.displayMass(mBottom) /
    leAtMt.displayMass(mTop);
  double htau =  hb * leAtMt.displayMass(mTau) /
    leAtMt.displayMass(mBottom); 
  
  const double pi = 3.141592653589793;
  int i; for(i=1; i<=3; i++) g(i) = sqrt(4.0 * pi * a(i));
  t.setAllGauge(g);
  
  t.setYukawaElement(YU, 3, 3, ht);
  t.setYukawaElement(YD, 3, 3, hb);
  t.setYukawaElement(YE, 3, 3, htau);
  
  t.setMu(oneset.displayPoleMt());   
  
  return t;
}


// Returns low energy softsusy object consistent with BC's m0 etc at MGUT.
// This version iterates from the GUT scale.
// If minV < 0 there's a problem with the ufb constraints on return
// epsilon is accuracy
// susyAtMt is just for initialisation, but it should be at the top mass
// oneset should be at MZ and contains the SM data to fit the model to
// if the running runs into difficulty, eg if a Landau pole is reached, it
// returns a ZERO object: no result is possible!
// Boundary condition is the theoretical condition on parameters at the high
// energy scale mx: the parameters themselves are contained within the vector.
// The parameters should be ordered in a manner in which its reasonable for
// the first to be an initial guess for mu(mx), eg m0 in mSUGRA
MssmSoftsusy lowOrg
(void (*boundaryCondition)(MssmSoftsusy &, const DoubleVector &),
 double mx, const DoubleVector & pars, int sgnMu, double tanb, const QedQcd &
 oneset, int thresholds, double epsilon) {

  if (oneset.displayMu() != MZ) {
    cout << "WARNING: lowOrg in softsusy.cc called with oneset at scale" <<
      oneset.displayMu() << "\ninstead of " << MZ << endl;
  }
  
  const int maxtries = 50; 
  double tol = epsilon;
  
  MssmSusy t(guessAtSusyMt(tanb, oneset));
  t.setLoops(2); t.runto(mx); 
  
  MssmSoftsusy in, out; 
  
  in.setSusy(t); out.setSusy(t); 
  in.setData(oneset); out.setData(oneset);
  
  // Initial guess: B=0, mu=1st parameter, need better guesses
  boundaryCondition(in, pars);
  //  in.setSusyMu(sgnMu * pars.display(1));
  in.setSusyMu(sgnMu * 1.0);
  in.setB(0.0);
  
  in.run(mx, MZ);
  
  in.rewsbTreeLevel(sgnMu); 
  
  in.physical(0); 
  
  in.setThresholds(thresholds); in.setLoops(2);
  out.setThresholds(thresholds); out.setLoops(2);
  
  // Following returns the most accurate iteration at MZ: in=out
  itLowsoft(in, out, maxtries, mx, sgnMu, tol, tanb,
	     boundaryCondition, pars);
  
  if (out.displayProblem().nonperturbative) {
    MssmSoftsusy temp;
    temp.flagNonperturbative(true);
    return temp;
  }
  
  if (PRINTOUT) cout << " end of iteration" << endl;
  
  in.runto(in.calcMs());
  
  if (PRINTOUT > 0) {
    double tb, MZp = sqrt(fabs(in.predMzsq(tb))); 
    cout << "MZ is calculated to be " <<  MZp <<
      " and tan beta(MS)=" << tb << endl;
  }
    
  // check to see if there are any negative mass squared scalars: if there
  // are, flag scalarMinimum
  int posi, posj, lspCode; double minmass;
  lspCode = out.lsp(minmass, posi, posj); 
  if (lspCode > 0 && lspCode < 6 && lspCode !=4 && minmass < 0.0)
    { out.flagTachyon(true); }
  
  return out;
}


// You should evaluate this at a scale MSusy average of stops.
// Depth of electroweak minimum:
double MssmSoftsusy::realMinMs() const {
  MssmSusy temp(displaySusy());
  temp.runto(calcMs(), EPS);
  
  double beta = atan(temp.displayTanb());
  return - 1.0 / 16.0 * 
    (0.6 * sqr(temp.displayGauge()(1)) + 
     sqr(temp.displayGauge()(2))) * 
    sqr(displayHiggsVevMs() * cos(2.0 * beta));
}

// Difference between two SOFTSUSY objects in and out: EWSB terms only
double sumTol(const MssmSoftsusy & in, const MssmSoftsusy & out) {
  double sumTol = 0.0; 
  
  double muin = fabs(in.displaySusyMu()), 
    muout = fabs(out.displaySusyMu()),
    bin = fabs(in.displayB()), 
    bout = fabs(out.displayB()), 
    mH1sqin = fabs(in.displayMh1Squared()),
    mH1sqout = fabs(out.displayMh1Squared()),
    mH2sqin = fabs(in.displayMh2Squared()),
    mH2sqout = fabs(out.displayMh2Squared());
  
  DoubleVector sT(4);
  sT(1) = fabs(1.0 - minimum(muin, muout) / maximum(muin, muout));
  sT(2) = fabs(1.0 - minimum(bin, bout) / maximum(bin, bout));
  sT(3) = fabs(1.0 - minimum(mH1sqin, mH1sqout) / maximum(mH1sqin, mH1sqout));
  sT(4) = fabs(1.0 - minimum(mH2sqin, mH2sqout) / maximum(mH2sqin, mH2sqout));
  
  return sT.max();
}

// Yukawa coupling at any scale - should give it vev at correct scale
double MssmSoftsusy::calcHt(double vev) const {
  double mtrun = calcRunningMt();
  double beta = atan(displayTanb());
  double ht = mtrun * sqrt(2.0) / (vev * sin(beta));
  return ht;
}

double MssmSoftsusy::calcHb(double vev) const {
  double mbrun = calcRunningMb();
  double beta = atan(displayTanb());
  double hb = mbrun * sqrt(2.0) / (vev * cos(beta));
  return hb;
}

double MssmSoftsusy::calcHtau(double vev) const {
  double mtaurun = calcRunningMtau();
  double beta = atan(displayTanb());
  double htau = mtaurun * sqrt(2.0) / (vev * cos(beta));
  return htau;
}

// Calculates sin theta at the current scale
double MssmSoftsusy::calcSinthdrbar() const {
  double alphaDrbar = qedSusythresh(ALPHAEM0, displayMu());
  double eDrbar = sqrt(4.0 * PI * alphaDrbar);
  
  return eDrbar / displayGaugeCoupling(2); // from hep-ph/9501277
}

//VEV at current scale
double MssmSoftsusy::getVev() const {
  double piZzT = piZZT(MZ, displayMu());
  
  double vsquared = 4.0 * (sqr(MZ) + piZzT) /
    (sqr(displayGaugeCoupling(2)) +
     sqr(displayGaugeCoupling(1)) * 0.6); 
  
  return sqrt(vsquared);
}

// It'll set the important SUSY couplings: supposed to be applied at MZ
// You should set up an iteration here since Yuk's depend on top mass which
// depends on Yuk's etc. 
void MssmSoftsusy::sparticleThresholdCorrections(double tb) {
  if (displayMu() != MZ) {
    cout << "Called MssmSoftsusy::sparticleThresholdCorrections "
	 << "with scale" << displayMu() << endl;
    exit(1);
  }
  
  setTanb(tb);
  
  double alphaDrbar = qedSusythresh(ALPHAEM0, displayMu());
  double alphasMZDRbar =
    qcdSusythresh(displayDataSet().displayAlpha(ALPHAS), displayMu());
  
  // Do gauge couplings
  double outrho = 0.0, inrho = 1.0, insin = 0.5, outsin = 0.6, tol = EPS *
    1.0e-2; 
  int maxTries = 20;
  rhohat(inrho, insin, outrho, outsin, alphaDrbar, tol, maxTries);
  
  double eDR = sqrt(4.0 * PI * alphaDrbar), costhDR = cos(asin(outsin));

  DoubleVector newGauge(3);
  newGauge(1) = eDR / costhDR * sqrt(5.0 / 3.0);
  newGauge(2) = eDR / outsin;
  newGauge(3) = sqrt(4.0 * PI * alphasMZDRbar);

  setGaugeCoupling(1, newGauge(1));
  setGaugeCoupling(2, newGauge(2));
  setGaugeCoupling(3, newGauge(3));

  double ht, hb, htau;
  double vev = getVev();
  ht = calcHt(vev); hb = calcHb(vev); htau = calcHtau(vev);
  
  setYukawaElement(YU, 3, 3, ht);
  setYukawaElement(YD, 3, 3, hb);
  setYukawaElement(YE, 3, 3, htau);
    
}

// Pass low-scale objects in, out and oneset (MSbar, at MZ)
// it will try to acheive tol fractional difference in mu and B from the
// iteration.
// returns 1 if cannot converge, 2 for no rewsb
// in and out are the latest iterations on return
void itLowsoft(MssmSoftsusy & in, MssmSoftsusy & out, int maxTries, double
		mx, int sgnMu, double tol, double tanb, 
		void (*boundaryCondition)(MssmSoftsusy &, const DoubleVector &),
		const DoubleVector & pars) {
  static int numTries = 0;
  
  double difference = sqr(in.displayMu() / MZ - 1.0) + sqr(out.displayMu() /
							    MZ - 1.0);
  
  if (numTries != 0 && difference > EPS) {
    cout << "WARNING: itLowsoft called with in, out at inappropriate";
    cout << " scales - \n" << in.displayMu() << " and " << out.displayMu()
	 << 	endl; 
    cout << "whereas they should be " << MZ << endl; 
  }
  
  if (numTries - 1 > maxTries) {// Iterating too long: bail out
    in.flagNoconvergence(true);
    out.flagNoconvergence(true);
    if (PRINTOUT) cout << "itLowsoft reached maxtries\n"; 
    numTries = 0;
    return;
  }
  double c = sumTol(in, out);    
  
  if (c < tol) {// Accuracy achieved: bail out
    // update out to be latest iteration
    out = in;
    numTries = 0; // Reset the number of iterations for the next time
    if (PRINTOUT > 0) cout << " sT=" << c << " "; 
    if (out.displayProblem().test() && PRINTOUT > 0) 
      cout << " ***problem point***: " << out.displayProblem() << ".";
    return; 
  }
  
  // All problems should be reset since only the ones of the final iteration
  // should count (sometimes problems disappear)
  in.flagAllProblems(false);
  
  static double mtpole, mtrun;
  
  mtpole = in.displayDataSet().displayPoleMt();
  // On first iteration, don't bother with finite corrections
  
  numTries = numTries + 1;
  
  // Old iteration is 'in', current one is 'out'
  out = in; 
  
  out.sparticleThresholdCorrections(tanb); 
  
  // precision of running/RGE integration: start off low and increase
  double eps = maximum(exp(double(-1 - numTries) * log(10.0)), tol * 0.01); 
  
  // if we're having trouble converging, increase accuracy of the running
  if (numTries > 9) eps = eps / double(numTries);
  
  double ms = out.calcMs();
  
  out.run(MZ, ms, eps);
  
  if (numTries != 1) 
    mtrun = out.calcRunningMt();
  else
    mtrun = mtpole;
  
  double MZp;
  if (PRINTOUT > 0) {
    double tb; MZp = sqrt(fabs(out.predMzsq(tb)));
  }

  out.rewsb(sgnMu, mtrun); 

  if (PRINTOUT > 0) {
    cout << "sT=" << c << " mu=" <<
      out.displaySusyMu() <<  " B=" <<
      out.displayB() 
	 << " MZp=" << MZp << endl;
    cout.flush();
  }
  
  int err = out.run(ms, mx, eps);
  if (err > 0) {// problem with running: bail out
    in.flagNonperturbative(true);
    out.flagNonperturbative(true);
    if (PRINTOUT) cout << "itLowsoft gone non-perturbative\n"; 
    numTries = 0;
    return;
  }
  
  boundaryCondition(out, pars); 
  
  out.run(mx, ms, eps);

  out.physical(3);      

  out.runto(MZ, eps);
  
  itLowsoft(out, in, maxTries, mx, sgnMu, tol, tanb, boundaryCondition,
	     pars);
}

// Integration routine needs these variables
static double mtInt, pInt, m1Int, m2Int;
static int nInt;

Complex fnfn(double x) {
  const static Complex iEpsilon(0.0, EPS * 1.0e-20);
  
  double xn = 1.0;
  int i; for (i=1; i<=nInt; i++) xn = xn * x;
  return xn * 
    log( ((1 - x) * sqr(m1Int) + x * sqr(m2Int) - x * (1 - x) *
	  sqr(pInt) - iEpsilon)
	 / sqr(mtInt));
}

DoubleVector dd(double x, const DoubleVector & y) {
  DoubleVector dydx(1);
  dydx(1) = -integrandThreshbnr(x);
  return dydx;
}

double integrandThreshbnr(double x) {
  return fnfn(x).real();
}

// Returns real part of integral
double bIntegral(int n1, double p, double m1, double m2, double mt) {
  // Set global variables so that integration function can access them
  nInt = n1; pInt = p; m1Int = m1; m2Int = m2; mtInt = mt;
  double from = 0.0, to = 1.0, guess = 0.1, hmin = EPS * 1.0e-5;
  
  DoubleVector v(1); double eps = EPS * 1.0e-3;
  v(1) = 1.0; 

  // Runge-Kutta, f(b) = int^b0 I(x) dx, I is integrand => d f / db = I(b)
  // odeint has a problem at f(0): therefore, define f'(b)=f(b)+1
  integrateOdes(v, from, to, eps, guess, hmin, dd, odeStepper); 
  
  return v(1) - 1.0;
}

/*
  Analytic expressions follow for above integrals: sometimes useful!
  From hep-ph/9606211
  Note it returns the REAL PART ONLY. 
  */
double b0(double p, double m1, double m2, double q) {
  if (p > EPSTOL) {
    const static Complex iEpsilon(0.0, EPS * p);
    double s = sqr(p) - sqr(m2) + sqr(m1); 
    
    Complex 
      xPlus = (s + sqrt(sqr(s) - 4.0 * sqr(p) * (sqr(m1) - iEpsilon))) /
      (2.0 * sqr(p));
    Complex 
      xMinus = (s - sqrt(sqr(s) - 4.0 * sqr(p) * (sqr(m1) - iEpsilon))) /
      (2.0 * sqr(p));
    
    return -log(sqr(p) / sqr(q)) - fB(xPlus) - fB(xMinus);
  }
  else {
    if (close(m1, m2, EPSTOL))
      return - log(sqr(m1 / q));
    else {
      double Mmax2 = maximum(sqr(m1), sqr(m2)), 
	Mmin2 = minimum(sqr(m1), sqr(m2)); 
      if (Mmin2 < sqr(EPS)) return 1.0 - log(Mmax2 / sqr(q));
      return 
	1.0 - log(Mmax2 / sqr(q)) + Mmin2 * log(Mmax2 / Mmin2) 
	/ (Mmin2 - Mmax2);
    }
  }   
}

double b1(double p, double m1, double m2, double q) {
  if (p > EPSTOL) {// checked
    return (a0(m2, q) - a0(m1, q) + (sqr(p) + sqr(m1) - sqr(m2)) 
	    * b0(p, m1, m2, q)) / (2.0 * sqr(p)); 
  }
  else if (fabs(m1) > EPSTOL && !close(m1, m2, EPSTOL)) {// checked
    double Mmax2 = maximum(sqr(m1), sqr(m2)), 
      mmin2 = minimum(sqr(m1), sqr(m2)), x = sqr(m2 / m1);
    return 0.5 * (-log(Mmax2 / sqr(q)) + 0.5 + 1.0 / (1.0 - x) + log(x) /
		  sqr(1.0 - x) - theta(1.0 - x) * log(x)); // checked
  }
  
  return bIntegral(1, p, m1, m2, q);
}

double b22(double p,  double m1, double m2, double q) {
  double answer;
  
  // This is Doug's calculation -- checked
  if (fabs(p) < EPSTOL) {
    // m1 == m2 with good accuracy
    if (close(m1, m2, EPSTOL)) 
      answer = -sqr(m1) * log(sqr(m1 / q)) * 0.5 + sqr(m1) * 0.5;
    else
      if (fabs(m1) > EPSTOL && fabs(m2) > EPSTOL)
	answer = 0.375 * (sqr(m1) + sqr(m2)) - 0.25 * 
	  (sqr(sqr(m2)) * log(sqr(m2 / q)) - sqr(sqr(m1)) * 
	   log(sqr(m1 / q))) / (sqr(m2) - sqr(m1)); 
      else
	if (fabs(m1) < EPSTOL)
	  answer = 0.375 * sqr(m2) - 0.25 * sqr(m2) * log(sqr(m2 / q));
	else 
	  answer = 0.375 * sqr(m1) - 0.25 * sqr(m1) * log(sqr(m1 / q));
  }
  else {// checked
    double b0Save = b0(p, m1, m2, q);
    
    answer = 1.0 / 6.0 * 
      (0.5 * (a0(m1, q) + a0(m2, q)) + (sqr(m1) + sqr(m2) - 0.5 * sqr(p))
       * b0Save + (sqr(m2) - sqr(m1)) / (2 * sqr(p)) *
       (a0(m2, q) - a0(m1, q) - (sqr(m2) - sqr(m1)) * b0Save) +
       sqr(m1) + sqr(m2) - sqr(p) / 3.0);
  }
  
  return answer;
}

// Transverse part of Z self-energy: has been checked
double MssmSoftsusy::piZZT(double p, double q) const {

  // fermions: these are valid at MZ
  double    mtop =  displayDataSet().displayPoleMt() ;
  double    mb   =  displayDataSet().displayMass(mBottom) ;
  double    mtau =  displayDataSet().displayMass(mTau) ;
  double    ms   =  displayDataSet().displayMass(mStrange) ;
  double    mc   =  displayDataSet().displayMass(mCharm) ;
  double    mmu  =  displayDataSet().displayMass(mMuon) ;
  double    mE  =  displayDataSet().displayMass(mElectron) ;
  double    mD  =  displayDataSet().displayMass(mDown) ;
  double    mU  =  displayDataSet().displayMass(mUp);
  double    costh  = (MW / MZ);
  double    thetaW = acos(costh);
  double    sinth  = sqrt(1.0 - sqr(costh))  ;
  double    cw2    = sqr(costh) ;
  double    sw2    = (1.0 - cw2);
  double    thetaWDRbar = asin(calcSinthdrbar());
  double    cw2DRbar    = sqr(cos(thetaWDRbar));
  double    sw2DRbar    = 1.0 - cw2DRbar;
  double    g       = displaySusy().displayGauge()(2);
  double    alpha   = displayPhys().thetaH ;
  double    beta    = atan(displaySusy().displayTanb());
  double    thetat = displayPhys().thetat ;
  double    thetab = displayPhys().thetab;
  double    thetatau= displayPhys().thetatau ;
  double    st      = sin(thetat) ;
  double    sb      = sin(thetab) ;
  double    stau    = sin(thetatau) ;
  double    ct      = cos(thetat) ;
  double    cb      = cos(thetab) ;
  double    ctau    = cos(thetatau);
  double    ct2     = sqr(ct) ;
  double    cb2     = sqr(cb) ;
  double    ctau2   = sqr(ctau) ;
  double    st2     = (1.0 - ct2);
  double    sb2     = (1.0 - cb2);
  double    stau2   = (1.0 - ctau2);

  double rhs = 0.0;
  
  rhs = rhs 
    - sqr(sin(alpha - beta)) *
    (b22bar(p, displayPhys().mhiggs(2), displayPhys().mhiggs(3), q) +
     b22bar(p, MZ, displayPhys().mhiggs(1), q) - 
     sqr(MZ) * b0(p, MZ, displayPhys().mhiggs(1), q));
  
  rhs = rhs
    - sqr(cos(alpha - beta)) * 
    (b22bar(p, MZ, displayPhys().mhiggs(3), q) +
     b22bar(p, displayPhys().mhiggs(2), displayPhys().mhiggs(1), q) -
     sqr(MZ) * b0(p, MZ, displayPhys().mhiggs(3), q));
  
  rhs = rhs
    - 2.0 * sqr(cw2DRbar) * (2 * sqr(p) + sqr(MW) - sqr(MZ) *
			     sqr(sw2DRbar) / cw2DRbar)
    * b0(p, MW, MW, q)
    - (8.0 * sqr(cw2DRbar) + sqr(cos(2.0 * thetaWDRbar))) * 
    b22bar(p, MW, MW, q) - 
    sqr(cos(2.0 * thetaWDRbar)) * b22bar(p, displayPhys().mhiggs(4),
					 displayPhys().mhiggs(4), q);
  
  //static 
  double guL, guR, gdL, gdR, geL, geR;
  //static 
  DoubleVector vu(2), vd(2), ve(2);
  //static 
  DoubleMatrix vt(2, 2), vb(2, 2), vtau(2, 2);
  
  guL = 0.5 - 2.0 * sw2 / 3.0; 
  gdL = -0.5 + sw2 / 3.0; 
  geL = -0.5 + sw2; 
  guR = 2.0 * sw2 / 3.0; 
  gdR = -sw2 / 3.0; 
  geR = -sw2; 
  
  vu(1) = guL;
  vu(2) = guR;
  
  vt(1, 1) = guL * ct2 - guR * st2;
  vt(1, 2) = (guL + guR) * ct * st;
  vt(2, 2) = guR * ct2 - guL * st2;
  vt(2, 1) = vt(1, 2);
  
  vd(1) = gdL;
  vd(2) = gdR;
  
  vb(1, 1) = gdL * cb2 - gdR * sb2;
  vb(1, 2) = (gdL + gdR) * cb * sb;
  vb(2, 2) = gdR * cb2 - gdL * sb2;
  vb(2, 1) = vb(1, 2);
  
  ve(1) = geL;
  ve(2) = geR;
  
  vtau(1, 1) = geL * ctau2 - geR * stau2;
  vtau(1, 2) = (geL + geR) * ctau * stau;
  vtau(2, 2) = geR * ctau2 - geL * stau2;
  vtau(2, 1) = vtau(1, 2);
  
  int i, j, family;
  for (family = 1; family<=2; family++) {      
    // sneutrinos
    rhs = rhs - 3.0 * 0.25 * b22bar(p, displayPhys().msnu(family),
				    displayPhys().msnu(family), q);
    for (i=1; i<=2; i++) {
      // up squarks
      rhs = rhs - 12.0 * sqr(vu(i)) * 
	b22bar(p, displayPhys().mu(i, family), 
	       displayPhys().mu(i, family), q); 
      // down squarks
      rhs = rhs - 12.0 * sqr(vd(i)) * 
	b22bar(p, displayPhys().md(i, family), 
	       displayPhys().md(i, family), q);
      // selectrons
      rhs = rhs - 4.0 * sqr(ve(i)) * 
	b22bar(p, displayPhys().me(i, family), 
	       displayPhys().me(i, family), q); 
    }
  }
  family = 3;
  
  // THIRD FAMILY
  // sneutrinos
  rhs = rhs - 3.0 * 0.25 * b22bar(p, displayPhys().msnu(family),
				  displayPhys().msnu(family), q);
  for (i=1; i<=2; i++)
    for (j=1; j<=2; j++) {
      // up squarks
      rhs = rhs - 12.0 * sqr(vt(i, j)) * 
	b22bar(p, displayPhys().mu(i, family), 
	       displayPhys().mu(j, family), q); 
      
      // down squarks
      rhs = rhs - 12.0 * sqr(vb(i, j)) * 
	b22bar(p, displayPhys().md(i, family), 
	       displayPhys().md(j, family), q);
      // selectrons
      rhs = rhs - 4.0 * sqr(vtau(i, j)) * 
	b22bar(p, displayPhys().me(i, family), 
	       displayPhys().me(j, family), q); 
    }
  
  rhs = rhs + 3.0 * hfn(p, mU, mU, q) * (sqr(guL) + sqr(guR)); 
  rhs = rhs + 3.0 * hfn(p, mc, mc, q) * (sqr(guL) + sqr(guR)); 
  rhs = rhs + 3.0 * (hfn(p, mtop, mtop, q) * 
		     (sqr(guL) + sqr(guR)) - 4.0 * guL * guR * sqr(mtop) * 
		     b0(p, mtop, mtop, q)); 
  
  rhs = rhs + 3.0 * hfn(p, mD, mD, q) * (sqr(gdL) + sqr(gdR)); 
  rhs = rhs + 3.0 * hfn(p, ms, ms, q) * (sqr(gdL) + sqr(gdR)); 
  rhs = rhs + 3.0 * (hfn(p, mb, mb, q) * (sqr(gdL) + sqr(gdR)) - 4.0 * gdL * gdR
		     * sqr(mb) * b0(p, mb, mb, q)); 
  
  rhs = rhs + hfn(p, mE, mE, q) * (sqr(geL) + sqr(geR)); 
  rhs = rhs + hfn(p, mmu, mmu, q) * (sqr(geL) + sqr(geR)); 
  rhs = rhs + hfn(p, mtau, mtau, q) * (sqr(geL) + sqr(geR)) - 4.0 * geL * geR
    * sqr(mtau) * b0(p, mtau, mtau, q) ; 
  
  // Neutralinos
  //static 
  ComplexMatrix aPsi(4, 4), bPsi(4, 4), aChi(4, 4), bChi(4, 4);
  static ComplexMatrix n(4, 4); static DoubleVector mneut(4);
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions  
   
  aPsi(3, 3) = g / (2 * cos(thetaWDRbar)); aPsi(4, 4) = 0. - aPsi(3, 3);
  bPsi = 0. - aPsi;
  
  aChi = n.complexConjugate() * aPsi * n.transpose();
  bChi = n * bPsi * n.hermitianConjugate();
  
  for (i=1; i<=4; i++)
    for (j=1; j<=4; j++) {
      rhs = rhs + cw2DRbar / (2.0 * sqr(g)) * 
	((sqr(aChi(i, j).mod()) + sqr(bChi(i, j).mod())) * 
	 hfn(p, mneut(i), mneut(j), q)
	 + 4.0 * (bChi(i, j).conj() * aChi(i, j)).real() *
	 mneut(i) * mneut(j) * b0(p, mneut(i), mneut(j), q)); 
    }
  
  // Charginos
  //  static 
  ComplexMatrix aPsiCh(2, 2), aCh(2, 2), bCh(2, 2);
  aPsiCh(1, 1) = g * cos(thetaWDRbar);
  aPsiCh(2, 2) = g * cos(2 * thetaWDRbar) / (2 * cos(thetaWDRbar));
  
  static ComplexMatrix u(2, 2), v(2, 2); static DoubleVector mch(2);
  mpzCharginos(u, v, mch);

  aCh = v.complexConjugate() * aPsiCh * v.transpose();
  bCh = u * aPsiCh * u.hermitianConjugate();
  
  for (i=1; i<=2; i++)
    for(j=1; j<=2; j++) {	
      rhs = rhs + cw2DRbar / sqr(g) * 
	((sqr(aCh(i, j).mod()) + sqr(bCh(i, j).mod())) * 
	 hfn(p, mch(i), mch(j), q) 
	 + 4.0 * (bCh(i, j) * aCh(i, j)).real() * mch(i) *
	 mch(j) * b0(p, mch(i), mch(j), q));
    }
  
  return rhs * sqr(g) / (cw2DRbar * 16 * sqr(PI));
}

//W propagator to 1 loop in MSSM 
// It's all been checked
double MssmSoftsusy::piWWT(double p, double q) const {

  double    beta    = atan(displaySusy().displayTanb());
  double    alpha   = displayPhys().thetaH ;
  double    mH = displayPhys().mhiggs(3); 
  double    mh0 = displayPhys().mhiggs(1);
  double    mHc = displayPhys().mhiggs(4);
  double    mA = displayPhys().mhiggs(2);
  // fermions: these are valid at MZ
  double    mtop =  displayDataSet().displayPoleMt() ;
  double    mb   =  displayDataSet().displayMass(mBottom) ;
  double    mtau =  displayDataSet().displayMass(mTau) ;
  double    ms   =  displayDataSet().displayMass(mStrange) ;
  double    mc   =  displayDataSet().displayMass(mCharm) ;
  double    mmu  =  displayDataSet().displayMass(mMuon) ;
  double    mE  =  displayDataSet().displayMass(mElectron) ;
  double    mD  =  displayDataSet().displayMass(mDown) ;
  double    mU  =  displayDataSet().displayMass(mUp);
  double    thetat = displayPhys().thetat ;
  double    thetab = displayPhys().thetab;
  double    thetatau= displayPhys().thetatau ;
  double    st      = sin(thetat) ;
  double    sb      = sin(thetab) ;
  double    stau    = sin(thetatau) ;
  double    ct      = cos(thetat) ;
  double    cb      = cos(thetab) ;
  double    ctau    = cos(thetatau);
  double    ct2     = sqr(ct) ;
  double    cb2     = sqr(cb) ;
  double    ctau2   = sqr(ctau) ;
  double    st2     = (1.0 - ct2);
  double    sb2     = (1.0 - cb2);
  double    stau2   = (1.0 - ctau2);
  double    thetaWDRbar = asin(calcSinthdrbar());
  double    cw2DRbar    = sqr(cos(thetaWDRbar));
  double    sw2DRbar    = 1.0 - cw2DRbar;
  double    g       = displaySusy().displayGauge()(2);

  double ans = 0.0;
  
  ans = ans -
    sqr(sin(alpha - beta)) * 
    (b22bar(p, mH, mHc, q) + b22bar(p, mh0, MW, q) 
     - sqr(MW) * b0(p, mh0, MW, q));
  
  ans = ans -
    sqr(cos(alpha - beta)) *
    (b22bar(p, mh0, mHc, q) + b22bar(p, mH, MW, q) 
     - sqr(MW) * b0(p, mH, MW, q));

  ans = ans -
    b22bar(p, mA, mHc, q) - (1.0 + 8.0 * cw2DRbar) * b22bar(p, MZ, MW, q)
    - sw2DRbar * (8.0 * b22bar(p, MW, 0.0, q) + 4.0 * sqr(p) * 
		  b0(p, MW, 0.0, q))  
    - ((4.0 * sqr(p) + sqr(MZ) + sqr(MW)) * cw2DRbar - sqr(MZ)  *
       sqr(sw2DRbar)) * b0(p, MZ, MW, q);
  
  // fermions
  ans = ans + 1.5 * 
    (hfn(p, mU, mD, q) + hfn(p, mc, ms, q) + hfn(p, mtop, mb, q)) + 0.5 *
    (hfn(p, 0.0, mE, q) + hfn(p, 0.0, mmu, q) + hfn(p, 0.0, mtau, q));     
  
  // sfermions
  ans = ans - 6.0 *
    (b22bar(p, displayPhys().mu(1, 1), displayPhys().md(1, 1), q) +
     b22bar(p, displayPhys().mu(1, 2), displayPhys().md(1, 2), q)) -
    2.0 * (b22bar(p, displayPhys().msnu(1), displayPhys().me(1, 1), q) +
	   b22bar(p, displayPhys().msnu(2), displayPhys().me(1, 2), q));
  
  // stop/sbottom
  DoubleMatrix w(2, 2);
  w(1, 1) = ct * cb; w(1, 2) = ct * sb; w(2, 1) = st * cb; w(2, 2) = st * sb;
  int i,j; 
  for(i=1; i<=2; i++)
    for(j=1; j<=2; j++)
      ans = ans - 6.0 * sqr(w(i, j)) * 
	b22bar(p, displayPhys().mu(i, 3), displayPhys().md(j, 3), q);
  
  // LH slepton
  ans = ans - 2.0 * 
    (sqr(ctau) * 
     b22bar(p, displayPhys().msnu(3), displayPhys().me(1, 3), q)
     + sqr(stau) * b22bar(p, displayPhys().msnu(3), displayPhys().me(2, 3),
			  q));
  
  ComplexMatrix aPsi0PsicW(4, 2), bPsi0PsicW(4, 2), aChi0ChicW(4, 2),
    bChi0ChicW(4, 2);
  DoubleMatrix fW(4, 2), gW(4, 2);
  
  aPsi0PsicW(2, 1) = - g;
  bPsi0PsicW(2, 1) = - g;
  aPsi0PsicW(4, 2) = g / sqrt(2.0);		     
  bPsi0PsicW(3, 2) = -g / sqrt(2.0);		     
  
  ComplexMatrix aPsi(4, 4), bPsi(4, 4), aChi(4, 4), bChi(4, 4);
  static ComplexMatrix n(4, 4); static DoubleVector mneut(4);
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions 
  static ComplexMatrix u(2, 2), v(2, 2); static DoubleVector mch(2);
  mpzCharginos(u, v, mch);    

  // These ought to be in physpars
  aChi0ChicW = n.complexConjugate() * aPsi0PsicW * v.transpose();
  bChi0ChicW = n * bPsi0PsicW * u.hermitianConjugate();

  for(i=1;i<=4;i++)
    for(j=1;j<=2;j++) {
      fW(i, j) = sqr(aChi0ChicW(i, j).mod()) + sqr(bChi0ChicW(i, j).mod());
      gW(i, j) = 2.0 * (bChi0ChicW(i, j).conj() * aChi0ChicW(i, j)).real(); 
      ans = ans + 
	(fW(i, j) * hfn(p, mneut(i), mch(j), q)
	 + 2.0 * gW(i, j) * mneut(i) * mch(j) * b0(p, mneut(i), mch(j), q)) 
	/ sqr(g);
    }
  
  return ans * sqr(g) / (16.0 * sqr(PI));
}

double MssmSoftsusy::piAA(double p, double q) const {// checked 19.01.2001

  double    mtop =  displayDataSet().displayPoleMt() ;
  double    mb   =  displayDataSet().displayMass(mBottom) ;
  double    ms   =  displayDataSet().displayMass(mStrange) ;
  double    mc   =  displayDataSet().displayMass(mCharm) ;
  double    mD  =  displayDataSet().displayMass(mDown) ;
  double    mU  =  displayDataSet().displayMass(mUp);
  double    costh  = (MW / MZ);
  double    thetaW = acos(costh);
  double    sinth  = sqrt(1.0 - sqr(costh))  ;
  double    cw2    = sqr(costh) ;
  double    sw2    = (1.0 - cw2);
  double    thetaWDRbar = asin(calcSinthdrbar());
  double    cw2DRbar    = sqr(cos(thetaWDRbar));
  double    sw2DRbar    = 1.0 - cw2DRbar;
  double    thetat  = displayPhys().thetat ;
  double    thetab  = displayPhys().thetab;
  double    st      = sin(thetat) ;
  double    sb      = sin(thetab) ;
  double    ct      = cos(thetat) ;
  double    cb      = cos(thetab) ;
  double    ct2     = sqr(ct) ;
  double    cb2     = sqr(cb) ;
  double    st2     = (1.0 - ct2);
  double    sb2     = (1.0 - cb2);
  double    beta    = atan(displaySusy().displayTanb());
  double    alpha   = displayPhys().thetaH ;
  double    g       = displaySusy().displayGauge()(2);
  double    mh0     = displayPhys().mhiggs(1);
  double    mHc     = displayPhys().mhiggs(4);
  double    mH     = displayPhys().mhiggs(3);
  double    mA      = displayPhys().mhiggs(2);
  double    gp      = displaySusy().displayGaugeCoupling(1) * sqrt(0.6);
  double cosb = cos(beta), cosb2 = sqr(cosb), cos2b = cos(2.0 * beta),
    sinb = sin(beta), sinb2 = sqr(sinb), sin2b = sin(2.0 * beta);

  double ans = 0.0;
  
  // Up fermions
  ans = ans + cosb2 * 
    (3.0 * sqr(displayYukawaElement(YU, 3, 3)) * 
     (sqr(p) * b0(p, mtop, mtop, q) - 2.0 * a0(mtop, q)) +
     3.0 * sqr(displayYukawaElement(YU, 2, 2)) * 
     (sqr(p) * b0(p, mc, mc, q) - 2.0 * a0(mc, q)) +
     3.0 * sqr(displayYukawaElement(YU, 1, 1)) * 
     (sqr(p) * b0(p, mU, mU, q) - 2.0 * a0(mU, q)));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YU, 1, 1)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (0.5 - 2.0 / 3.0 * sw2)) *
    (a0(displayPhys().mu(1, 1), q)) +
    3.0 * (sqr(displayYukawaElement(YU, 2, 2)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (0.5 - 2.0 / 3.0 * sw2)) *
    (a0(displayPhys().mu(1, 2), q)) +
    3.0 * (sqr(displayYukawaElement(YU, 3, 3)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (0.5 - 2.0 / 3.0 * sw2)) *
    (sqr(ct) * a0(displayPhys().mu(1, 3), q) + 
     sqr(st) * a0(displayPhys().mu(2, 3), q));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YU, 1, 1)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 2.0 / 3.0 * sw2) *
    (a0(displayPhys().mu(2, 1), q)) +
    3.0 * (sqr(displayYukawaElement(YU, 2, 2)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 2.0 / 3.0 * sw2) *
    (a0(displayPhys().mu(2, 2), q)) +
    3.0 * (sqr(displayYukawaElement(YU, 3, 3)) * cosb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 2.0 / 3.0 * sw2) *
    (sqr(st) * a0(displayPhys().mu(1, 3), q) + 
     sqr(ct) * a0(displayPhys().mu(2, 3), q));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YU, 1, 1) * 
	       (-displaySusyMu() * sinb - 
		displaySoftA(UA, 1, 1) * cosb))) * 0.5 * 
    (b0(p, displayPhys().mu(1, 1), displayPhys().mu(2, 1), q) +
     b0(p, displayPhys().mu(2, 1), displayPhys().mu(1, 1), q)) + 
    3.0 * (sqr(displayYukawaElement(YU, 2, 2) * 
	       (-displaySusyMu() * sinb - 
		displaySoftA(UA, 2, 2) * cosb))) * 0.5 * 
    (b0(p, displayPhys().mu(1, 2), displayPhys().mu(2, 2), q) +
     b0(p, displayPhys().mu(2, 2), displayPhys().mu(1, 2), q)) + 
    3.0 * (sqr(displayYukawaElement(YU, 3, 3) * 
	       (-displaySusyMu() * sinb - 
		displaySoftA(UA, 3, 3) * cosb))) * 0.5 * 
    (b0(p, displayPhys().mu(1, 3), displayPhys().mu(2, 3), q) +
     b0(p, displayPhys().mu(2, 3), displayPhys().mu(1, 3), q));
  
  // Other Higgs'
  ans = ans +
    sqr(g) * 0.25 * 
    (2.0 * ffn(p, displayPhys().mhiggs(4), MW, q) + 
     sqr(sin(displayPhys().thetaH - beta)) / cw2DRbar *
     ffn(p, displayPhys().mhiggs(3), MZ, q) + 
     sqr(cos(displayPhys().thetaH - beta)) / cw2DRbar * 
     ffn(p, displayPhys().mhiggs(1), MZ, q));
  
  // trilinear Higgs coupling Feynman rules
  DoubleVector lAas(2), lAah(2);
  lAas(1) = -cos2b * cosb; lAas(2) = cos2b * sinb;
  lAas = lAas * (g * MZ / (2.0 * cos(thetaWDRbar)));
  lAah = rot2d(displayPhys().thetaH) * lAas;
  
  // quartic Higgs coupling Ferynman rules: check
  DoubleMatrix lAa12(2, 2), lAahh(2, 2);
  lAa12(1, 1) = -cos(2.0 * beta);
  lAa12(2, 2) = cos(2.0 * beta);
  lAahh = rot2d(displayPhys().thetaH) * lAa12 *
    rot2d(-displayPhys().thetaH);
  lAahh = lAahh * sqr(g) / (4.0 * cw2DRbar);
  double lAaaa = sqr(g) / (4.0 * cw2DRbar) * 3.0 * sqr(cos2b),
    lAagg = (3.0 * sqr(sin2b) - 1.0) * sqr(g) / (4.0 * cw2DRbar);
  
  ans = ans +
    0.5 * (sqr(lAah(2)) * b0(p, mA, mh0, q) + 
	   sqr(lAah(1)) * b0(p, mA, mH, q) + 
	   lAahh(1, 1) * a0(mH, q) + lAahh(2, 2) * a0(mh0, q) + 
	   lAaaa * a0(mA, q) + lAagg * a0(MZ, q)) +             
    sqr(g) * sqr(MW) * 0.5 * b0(p, MW, mHc, q) + 
    sqr(g) / (4.0 * cw2DRbar)
    * ((cw2DRbar * (1.0 + sqr(sin2b)) - sw2DRbar * sqr(cos2b)) * a0(MW, q) +
       sqr(cos2b) * a0(mHc, q));    
  
  ans = ans + sqr(g) * (2.0 * a0(MW, q) + a0(MZ, q) / cw2DRbar);
  
  DoubleMatrix aPsiP1(4, 4), aPsiP2(4, 4), bPsiP1(4, 4), 
    bPsiP2(4, 4);
  aPsiP1(1, 3) = - gp * 0.5;   aPsiP1(3, 1) = - gp * 0.5; 
  aPsiP1(2, 3) = g * 0.5;      aPsiP1(3, 2) = g * 0.5; 
  aPsiP2(1, 4) = - gp * 0.5;   aPsiP2(4, 1) = - gp * 0.5; 
  aPsiP2(2, 4) = g * 0.5;      aPsiP2(4, 2) = g * 0.5; 
  
  bPsiP1 = -1.0 * aPsiP1; bPsiP2 = -1.0 * aPsiP2;

  ComplexMatrix aPsi(4, 4), bPsi(4, 4), aChi(4, 4), bChi(4, 4);
  static ComplexMatrix n(4, 4); static DoubleVector mneut(4);
  mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions 
  static ComplexMatrix u(2, 2), v(2, 2); static DoubleVector mch(2);
  mpzCharginos(u, v, mch);      
  
  // Rotate to A neutralino basis
  ComplexMatrix aChiChiA(4, 4), bChiChiA(4, 4);
  aChiChiA = -sinb * n.complexConjugate() * aPsiP1 * n.hermitianConjugate() +
    cosb * n.complexConjugate() * aPsiP2 * n.hermitianConjugate();
  bChiChiA = -sinb * n * bPsiP1 * n.transpose() + cosb * n * bPsiP2 *
    n.transpose();
  
  DoubleMatrix fChiChiA(4, 4), gChiChiA(4, 4);
  int i, j;
  for (i=1; i<=4; i++)
    for (j=1; j<=4; j++) {
      fChiChiA(i, j) = sqr(aChiChiA(i, j).mod()) + sqr(bChiChiA(i, j).mod());
      gChiChiA(i, j) = 2.0 * (bChiChiA(i, j).conj() * aChiChiA(i, j)).real();
      ans = ans + 
	0.5 * fChiChiA(i, j) * 
	gfn(p, mneut(i), mneut(j), q) -
	gChiChiA(i, j) * mneut(i) * mneut(j ) * 
	b0(p, mneut(i), mneut(j), q);
    }
  
  ComplexMatrix aChPsiP1(2, 2), aChPsiP2(2, 2), bChPsiP1(2, 2),
    bChPsiP2(2, 2), aChPsiA(2, 2), bChPsiA(2, 2); 
  aChPsiP1(1, 2) = g / sqrt(2.0);   aChPsiP2(2, 1) = - g / sqrt(2.0);
  bChPsiP1 = - 1.0 * aChPsiP1.transpose(); 
  bChPsiP2 = - 1.0 * aChPsiP2.transpose();
  
  // To A-mass basis
  aChPsiA = -sinb * aChPsiP1 + cosb * aChPsiP2;
  bChPsiA = -sinb * bChPsiP1 + cosb * bChPsiP2;
  
  ComplexMatrix aChChiA(2, 2), bChChiA(2, 2);
  DoubleMatrix  fChChiA(2, 2), gChChiA(2, 2);
  aChChiA = v.complexConjugate() * aChPsiA * u.hermitianConjugate();
  bChChiA = u * bChPsiA * v.transpose();
  
  for (i=1; i<=2; i++)
    for (j=1; j<=2; j++) {
      fChChiA(i, j) = sqr(aChChiA(i, j).mod()) + sqr(bChChiA(i, j).mod());
      gChChiA(i, j) = 2.0 * (bChChiA(i, j).conj() * aChChiA(i, j)).real();
      ans = ans +
	fChChiA(i, j) * 
	gfn(p, mch(i), mch(j), q) -
	2.0 * gChChiA(i, j) * mch(i) * mch(j) * b0(p, mch(i), mch(j), q);
    }
  
  // Down fermions			
  ans = ans + sinb2 * 
    (3.0 * sqr(displayYukawaElement(YD, 3, 3)) * 
     (sqr(p) * b0(p, mb, mb, q) - 2.0 * a0(mb, q)) +
     3.0 * sqr(displayYukawaElement(YD, 2, 2)) * 
     (sqr(p) * b0(p, ms, ms, q) - 2.0 * a0(ms, q)) +
     3.0 * sqr(displayYukawaElement(YD, 1, 1)) * 
     (sqr(p) * b0(p, mD, mD, q) - 2.0 * a0(mD, q)));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YD, 1, 1)) * sinb2 +
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (-0.5 + 1.0 / 3.0 * sw2)) *
    (a0(displayPhys().md(1, 1), q)) +
    3.0 * (sqr(displayYukawaElement(YD, 2, 2)) * sinb2 + 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (-0.5 + 1.0 / 3.0 * sw2)) *
    (a0(displayPhys().md(1, 2), q)) +
    3.0 * (sqr(displayYukawaElement(YD, 3, 3)) * sinb2 + 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * (-0.5 + 1.0 / 3.0 * sw2)) *
    (sqr(cb) * a0(displayPhys().md(1, 3), q) + 
     sqr(sb) * a0(displayPhys().md(2, 3), q));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YD, 1, 1)) * sinb2 -
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 1.0 / 3.0 * sw2) *
    (a0(displayPhys().md(2, 1), q)) +
    3.0 * (sqr(displayYukawaElement(YD, 2, 2)) * sinb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 1.0 / 3.0 * sw2) *
    (a0(displayPhys().md(2, 2), q)) +
    3.0 * (sqr(displayYukawaElement(YD, 3, 3)) * sinb2 - 
	   sqr(g) / (cw2DRbar) * cos2b * 0.5 * 1.0 / 3.0 * sw2) *
    (sqr(sb) * a0(displayPhys().md(1, 3), q) + 
     sqr(cb) * a0(displayPhys().md(2, 3), q));
  
  ans = ans +
    3.0 * (sqr(displayYukawaElement(YD, 1, 1) * 
	       (-displaySusyMu() * cosb - 
		displaySoftA(DA, 1, 1) * sinb))) * 0.5 * 
    (b0(p, displayPhys().md(1, 1), displayPhys().md(2, 1), q) +
     b0(p, displayPhys().md(2, 1), displayPhys().md(1, 1), q)) + 
    3.0 * (sqr(displayYukawaElement(YD, 2, 2) * 
	       (-displaySusyMu() * cosb - 
		displaySoftA(DA, 2, 2) * sinb))) * 0.5 * 
    (b0(p, displayPhys().md(1, 2), displayPhys().md(2, 2), q) +
     b0(p, displayPhys().md(2, 2), displayPhys().md(1, 2), q)) + 
    3.0 * (sqr(displayYukawaElement(YD, 3, 3) * 
	       (-displaySusyMu() * cosb - 
		displaySoftA(DA, 3, 3) * sinb))) * 0.5 * 
    (b0(p, displayPhys().md(1, 3), displayPhys().md(2, 3), q) +
     b0(p, displayPhys().md(2, 3), displayPhys().md(1, 3), q));

  return ans / (16.0 * sqr(PI));
}


// Has been checked
/*double MssmSoftsusy::piZGT(double p, double q) const {
#include "softbrevity.h"
  
  double ans = 0.0;
  
  ans = ans + 
    (12.0 * sw2DRbar - 10.0) * b22bar(p, MW, MW, q) - 
    2.0 * (sqr(MW) + 2.0 * cw2DRbar * sqr(p)) * b0(p, MW, MW, q);
  
  double guL = 0.5 - 2.0 * sw2 / 3.0; 
  double gdL = -0.5 + sw2 / 3.0; 
  double geL = -0.5 + sw2; 
  double guR = 2.
0 * sw2 / 3.0; 
  double gdR = -sw2 / 3.0; 
  double geR = -sw2; 
  
  ans = ans + 2.0 * (guL - guR) * (4.0 * b22bar(p, mU, mU, q) +
				   sqr(p) * b0(p, mU, mU, q));
  ans = ans + 2.0 * (guL - guR) * (4.0 * b22bar(p, mc, mc, q) +
				   sqr(p) * b0(p, mc, mc, q));
  ans = ans + 2.0 * (guL - guR) * (4.0 * b22bar(p, mtop, mtop, q) +
				   sqr(p) * b0(p, mtop, mtop, q));
  ans = ans - (gdL - gdR) * (4.0 * b22bar(p, mD, mD, q) +
			     sqr(p) * b0(p, mD, mD, q));
  ans = ans - (gdL - gdR) * (4.0 * b22bar(p, ms, ms, q) +
			     sqr(p) * b0(p, ms, ms, q));
  ans = ans - (gdL - gdR) * (4.0 * b22bar(p, mb, mb, q) +
			     sqr(p) * b0(p, mb, mb, q));
  ans = ans - (geL - geR) * (4.0 * b22bar(p, mE, mE, q) +
			     sqr(p) * b0(p, mE, mE, q));
  ans = ans - (geL - geR) * (4.0 * b22bar(p, mmu, mmu, q) +
			     sqr(p) * b0(p, mmu, mmu, q));
  ans = ans - (geL - geR) * (4.0 * b22bar(p, mtau, mtau, q) +
			     sqr(p) * b0(p, mtau, mtau, q));
  
  ans = ans - 2.0 * cos(2.0 * thetaWDRbar) * b22bar(p, mHc, mHc, q);
  
  DoubleMatrix v(2, 2), u(2, 2);
  v = rot2d(physpars.thetaR); u = rot2d(physpars.thetaL); // conventions
  
  int i; for (i=1; i<=2; i++) {
    ans = ans + 0.5 * (sqr(v(i, 1)) + sqr(u(i, 1)) 
		       + 2.0 * cos(2.0 * thetaWDRbar))
      * (4.0 * b22bar(p, displayPhys().mch(i), displayPhys().mch(i), q) +
	 sqr(p) * b0(p, displayPhys().mch(i), displayPhys().mch(i), q));
    
    ans = ans - 
      8.0 * 
      (guL * b22bar(p, displayPhys().mu(1, i), displayPhys().mu(1, i), q) 
       - guR * 
       b22bar(p, displayPhys().mu(2, i), displayPhys().mu(2, i), q)) +
      4.0 * 
      (gdL * b22bar(p, displayPhys().md(1, i), displayPhys().md(1, i), q) 
       - gdR * 
       b22bar(p, displayPhys().md(2, i), displayPhys().md(2, i), q)) +
      4.0 * 
      (geL * b22bar(p, displayPhys().me(1, i), displayPhys().me(1, i), q) 
       - geR * 
       b22bar(p, displayPhys().me(2, i), displayPhys().me(2, i), q));
  }
  
  ans = ans -  8.0 * 
    ((guL * ct2 - guR * st2) * b22bar(p, mstop1, mstop1, q) + 
     (guL * st2 - guR * ct2) * b22bar(p, mstop2, mstop2, q));
  ans = ans +  4.0 * 
    ((gdL * cb2 - gdR * sb2) * b22bar(p, msbot1, msbot1, q) + 
     (gdL * sb2 - gdR * cb2) * b22bar(p, msbot2, msbot2, q));
  ans = ans +  4.0 * 
    ((geL * ctau2 - geR * stau2) * b22bar(p, mstau1, mstau1, q) + 
     (geL * stau2 - geR * ctau2) * b22bar(p, mstau2, mstau2, q));
  
  double e = sqrt(ALPHAEM0 * 4.0 * PI);
  
  return ans * e * g / (16 * sqr(PI) * cos(thetaWDRbar)); 
} */

double rho2(double r) {// checked 
  if (r <= 1.9)
    return 19.0 - 16.5 * r + 43.0 * sqr(r) / 12.0 + 7.0 / 120.0 * sqr(r) * r -
      PI * sqrt(r) * (4.0 - 1.5 * r + 3.0 / 32.0 * sqr(r) + sqr(r) * r /
		      256.0) - sqr(PI) * (2.0 - 2.0 * r + 0.5 * sqr(r)) -
      log(r) * (3.0 * r - 0.5 * sqr(r));
  else {
    double rm1 = 1.0 / r, rm2 = sqr(rm1), rm3 = rm2 * rm1, rm4 = rm3 * rm1,
      rm5 = rm4 * rm1;
    return sqr(log(r)) * (1.5 - 9.0 * rm1 - 15.0 * rm2 - 48.0 * rm3 - 168.0
			  * rm4 - 612.0 * rm5) -
      log(r) * (13.5 + 4.0 * rm1 - 125.0 / 4.0 * rm2 - 558.0 / 5.0 * rm3 -
		8307.0 / 20.0 * rm4 - 109321.0 / 70.0 * rm5)
      + sqr(PI) * (1.0 - 4.0 * rm1 - 5.0 * rm2 - 16.0 * rm3 -
		   56.0 * rm4 - 204.0 * rm5)
      + 49.0 / 4.0 + 2.0 / 3.0 * rm1 + 1613.0 / 48.0 * rm2 + 87.57 * rm3 +
      341959.0 / 1200.0 * rm4 + 9737663.0 / 9800.0 * rm5;
  }
}

double d0(double m1, double m2, double m3, double m4) {// checked
  if (close(m1, m2, EPSTOL)) {
    return 
      (sqr(m4) / sqr(sqr(m1) - sqr(m4)) * log(sqr(m4) / sqr(m1)) + 
       1.0 / (sqr(m1) * (sqr(m1) - sqr(m4))) -
       sqr(m3) / sqr(sqr(m1) - sqr(m3)) * log(sqr(m3) / sqr(m1)) -
       1.0 / (sqr(m1) * (sqr(m1) - sqr(m3)))) / (sqr(m3) - sqr(m4));
  }
  return (c0(m1, m3, m4) - c0(m2, m3, m4)) / (sqr(m1) - sqr(m2));
}

double d27(double m1, double m2, double m3, double m4) {// checked
  if (close(m1, m2, EPS)) {
    double m1n = m1 + EPS * 0.01;
    return (sqr(m1n) * c0(m1n, m3, m4) - sqr(m2) * c0(m2, m3, m4)) 
      / (4.0 * (sqr(m1n) - sqr(m2)));
  }
  return (sqr(m1) * c0(m1, m3, m4) - sqr(m2) * c0(m2, m3, m4)) 
    / (4.0 * (sqr(m1) - sqr(m2)));
}

double c0(double m1, double m2, double m3) {// checked 22.11.00
  if (close(m1, m2, EPS)) {
    return (sqr(m2) * log(sqr(m2) / sqr(m1)) / (sqr(m1) - sqr(m2)) + 1.0) 
      / (sqr(m2) - sqr(m1));
  }
  else
    if (close(m2, m3, EPS)) {
      return (-1.0 - sqr(m3) * log(sqr(m3) / sqr(m1)) 
	      / (sqr(m1) - sqr(m3))) / (sqr(m1) - sqr(m3));
    }
    else
      if (close(m3, m1, EPS)) {
	return (1.0 + sqr(m1) * log(sqr(m2) / sqr(m1)) 
		/ (sqr(m1) - sqr(m2))) / (sqr(m1) - sqr(m2));
      }
      else
	return 1.0 / (sqr(m2) - sqr(m3)) * (sqr(m2) / (sqr(m1) - sqr(m2)) *
					    log(sqr(m2) / sqr(m1)) -
					    sqr(m3) / (sqr(m1) - sqr(m3)) *
					    log(sqr(m3) / sqr(m1)));
}

// Checked 20.11.00
void MssmSoftsusy::rhohat(double & inrho, double & insin, double & outrho,
			  double & outsin, double alphaDRbar, 
			  double tol, int maxTries) const {
  if (displayMu() != MZ) {
    cout << "Called MssmSoftsusy::rhohat "
	 << "with scale" << displayMu() << endl;
    exit(1);
  }
  
  static int numTries = 0;
  
  if (numTries - 1 > maxTries) { 
    numTries = 0;
    cout << "rhohat reached maxtries\n"; 
    return;
  }
  
  // Difference to last iteration
  double sumTol;
  if (outrho < EPS || outsin < 0.0) sumTol = 1.0;
  else
    sumTol = fabs(inrho / outrho - 1.0) + fabs(insin / outsin - 1.0);
  
  if (numTries != 0 && sumTol < tol) {
    outrho = inrho; outsin = insin;
    numTries = 0;
    if (PRINTOUT > 2) cout << "sinrho converged\n";
    return;
  }
  
  double    beta    = atan(displaySusy().displayTanb());
  double    g       = displaySusy().displayGauge()(2);
  double    gp      = displaySusy().displayGaugeCoupling(1) * sqrt(0.6);
  double    costh  = (MW / MZ);
  double    thetaW = acos(costh);
  double    sinth  = sqrt(1.0 - sqr(costh))  ;
  double    cw2    = sqr(costh) ;
  double    sw2    = (1.0 - cw2);

  static ComplexMatrix n(4, 4); static DoubleVector mneut(4);
  static ComplexMatrix u(2, 2), v(2, 2); static DoubleVector mch(2);
  if (numTries == 0) {
    mpzNeutralinos(n, mneut); // gets to Matchev+Pierce's conventions 
    mpzCharginos(u, v, mch);          
  }
  
  numTries = numTries + 1;
  
  outrho = inrho; outsin = insin; 
  double outcos = cos(asin(insin));
  
  if (PRINTOUT > 2) cout << " st2=" << sumTol;
  
  // 2 loop SM contribution
  double mt = displayDataSet().displayPoleMt(), q = displayMu();
  double sinb = sin(beta);
  
  double xt = 3.0 * GMU * sqr(mt) / (8.0 * sqr(PI) * sqrt(2.0));
  
  double deltaRho2LoopSm = alphaDRbar * sqr(displayGaugeCoupling(3)) / 
    (16.0 * PI * sqr(PI) * sqr(outsin) * sqr(outcos)) * 
    (-2.145 * sqr(mt) / sqr(MW) + 1.262 * log(mt / MZ) - 2.24 - 0.85 * sqr(MZ)
     / sqr(mt)) + sqr(xt) * sqr(cos(displayPhys().thetaH)) / sqr(sinb) *
    rho2(displayPhys().mhiggs(1) / mt) / 3.0;
  
  double pizztMZ = piZZT(MZ, displayMu());
  double deltaRhoOneLoop = pizztMZ / (outrho * sqr(MZ))
    - piWWT(MW, displayMu()) / sqr(MW);
  
  double deltaRho = deltaRhoOneLoop + deltaRho2LoopSm;
  
  // checked to here
  double deltaVbSm = outrho * alphaDRbar / (4.0 * PI * sqr(outsin)) *
    (6.0 + log(cw2) / sw2 * 
     (3.5 - 2.5 * sw2 - sqr(outsin) * (5.0 - 1.5 * cw2 / sqr(outcos))));
  
  DoubleVector bPsi0NuNul(4), bPsicNuSell(2);
  DoubleVector bPsi0ESell(4), aPsicESnul(2);
  ComplexVector bChi0NuNul(4), bChicNuSell(2);
  ComplexVector bChi0ESell(4), aChicESnul(2);
  
  double he = displayYukawaMatrix(YE)(3, 3);
  bPsicNuSell(1) = g;
  bPsi0NuNul(2) = sqrt(2.0) * g * 0.5;
  bPsi0NuNul(1) = - gp / sqrt(2.0);
  aPsicESnul(1) = g;
  bPsi0ESell(1) = -gp / sqrt(2.0);
  bPsi0ESell(2) = -g * sqrt(2.0) * 0.5;
  
  bChicNuSell = u * bPsicNuSell;
  bChi0ESell =  n * bPsi0ESell;
  bChi0NuNul = n * bPsi0NuNul;

  aChicESnul = v.complexConjugate() * aPsicESnul;
  
  double deltaZnue = 0.0, deltaZe = 0.0;
  double mselL = displayPhys().me(1, 1), msnue = displayPhys().msnu(1);
  int i; for(i=1; i<=4; i++) {
    if (i < 3) {
      deltaZnue = deltaZnue -
	sqr(bChicNuSell(i).mod()) * b1(0.0, mch(i), mselL, q);
      deltaZe = deltaZe -
	sqr(aChicESnul(i).mod()) * b1(0.0, mch(i), msnue, q);
    }
    deltaZnue = deltaZnue -
      sqr(bChi0NuNul(i).mod()) * b1(0.0, mneut(i), msnue, q);
    deltaZe = deltaZe -
      sqr(bChi0ESell(i).mod()) * b1(0.0, mneut(i), mselL, q);
  }
  
  DoubleVector bPsicNuSmul(2);
  DoubleVector bPsi0MuSmul(4), aPsicMuSnul(2);
  ComplexVector bChicNuSmul(2);
  ComplexVector bChi0MuSmul(4), aChicMuSnul(2);
  
  double hmu = displayYukawaMatrix(YE)(2, 2);
  bPsicNuSmul(1) = g;
  bPsicNuSmul(2) = -hmu;
  aPsicMuSnul(1) = g;
  aPsicMuSnul(2) = -hmu;
  bPsi0MuSmul(1) = -gp / sqrt(2.0);
  bPsi0MuSmul(2) = -g * sqrt(2.0) * 0.5;
  
  bChicNuSmul = u * bPsicNuSmul;
  bChi0MuSmul =  n * bPsi0MuSmul;
  bChi0NuNul = n * bPsi0NuNul;
  aChicMuSnul = v.complexConjugate() * aPsicMuSnul;
  
  double deltaZnumu = 0.0, deltaZmu = 0.0;
  double msnumu = displayPhys().msnu(1), msmuL = displayPhys().me(1, 2);
  for(i=1; i<=4; i++) {
    if (i < 3) {
      deltaZnumu = deltaZnumu -
	sqr(bChicNuSmul(i).mod()) * b1(0.0, mch(i), msmuL, q);
      deltaZmu = deltaZmu -
	sqr(aChicMuSnul(i).mod()) * b1(0.0, mch(i), msnumu, q);
    }
    deltaZnumu = deltaZnumu -
      sqr(bChi0NuNul(i).mod()) * b1(0.0, mneut(i), msnumu, q);
    deltaZmu = deltaZmu -
      sqr(bChi0MuSmul(i).mod()) * b1(0.0, mneut(i), msmuL, q);
  }
  
  DoubleMatrix aPsi0PsicW(4, 2), bPsi0PsicW(4, 2), fW(4, 2), gW(4, 2);
  ComplexMatrix aChi0ChicW(4, 2), bChi0ChicW(4, 2);
  
  aPsi0PsicW(2, 1) = - g;
  bPsi0PsicW(2, 1) = - g;
  aPsi0PsicW(4, 2) = g / sqrt(2.0);		     
  bPsi0PsicW(3, 2) = -g / sqrt(2.0);		     
  
  // These ought to be in physpars
  aChi0ChicW = n.complexConjugate() * aPsi0PsicW * v.transpose();
  bChi0ChicW = n * bPsi0PsicW * u.hermitianConjugate();
  
  Complex deltaVE = 0.0;
  int j; for(i=1; i<=2; i++)
    for(j=1; j<=4; j++) {
      deltaVE = deltaVE - bChicNuSell(i) * bChi0ESell(j).conj() *
	(- sqrt(2.0) / g * aChi0ChicW(j, i) * mch(i) * mneut(j) *
	 c0(mselL, mch(i), mneut(j)) + 1.0 / (sqrt(2.0) * g) *
	 bChi0ChicW(j, i) *
	 (b0(0.0, mch(i), mneut(j), q) + sqr(mselL) * 
	  c0(mselL, mch(i), mneut(j)) - 0.5));
      deltaVE = deltaVE - aChicESnul(i) * bChi0NuNul(j) *
	(- sqrt(2.0) / g * bChi0ChicW(j, i) * mch(i) * mneut(j) *
	 c0(msnue, mch(i), mneut(j)) + 1.0 / (sqrt(2.0) * g) *
	 aChi0ChicW(j, i) * 
	 (b0(0.0, mch(i), mneut(j), q) + sqr(msnue) * 
	  c0(msnue, mch(i), mneut(j)) - 0.5));
      if (i == 1)
	deltaVE = deltaVE +
	  0.5 * bChi0ESell(j).conj() * bChi0NuNul(j) *
	  (b0(0.0, mselL, msnue, q) + sqr(mneut(j)) * c0(mneut(j), mselL,
							 msnue) + 0.5);
    }
  
  Complex deltaVMu = 0.0;
  for(i=1; i<=2; i++)
    for(j=1; j<=4; j++) {
      deltaVMu = deltaVMu - bChicNuSmul(i) * bChi0MuSmul(j).conj() *
	(- sqrt(2.0) / g * aChi0ChicW(j, i) * mch(i) * mneut(j) *
	 c0(msmuL, mch(i), mneut(j)) + 1.0 / (sqrt(2.0) * g) *
	 bChi0ChicW(j, i) *
	 (b0(0.0, mch(i), mneut(j), q) + sqr(msmuL) * 
	  c0(msmuL, mch(i), mneut(j)) - 0.5));
      deltaVMu = deltaVMu - aChicMuSnul(i) * bChi0NuNul(j) *
	(- sqrt(2.0) / g * bChi0ChicW(j, i) * mch(i) * mneut(j) *
	 c0(msnumu, mch(i), mneut(j)) + 1.0 / (sqrt(2.0) * g) *
	 aChi0ChicW(j, i) * 
	 (b0(0.0, mch(i), mneut(j), q) + sqr(msnumu) * 
	  c0(msnumu, mch(i), mneut(j)) - 0.5));
      if (i == 1)
	deltaVMu = deltaVMu +
	  0.5 * bChi0MuSmul(j).conj() * bChi0NuNul(j) *
	  (b0(0.0, msmuL, msnumu, q) + sqr(mneut(j)) * c0(mneut(j), msmuL,
							  msnumu) + 0.5);
    }
  
  ComplexMatrix Debug(2, 4);
  Complex a1(0.0, 0.0);
  for(i=1; i<=2; i++)
    for(j=1; j<=4; j++) {
      a1 = a1 + 0.5 * aChicMuSnul(i) * bChicNuSell(i).conj() *
	bChi0NuNul(j) * bChi0ESell(j) * mch(i) * mneut(j) * 
	d0(mselL, msnumu, mch(i), mneut(j));
      a1 = a1 + 0.5 * aChicESnul(i).conj() * bChicNuSmul(i) *
	bChi0NuNul(j).conj() * bChi0MuSmul(j).conj() * mch(i) * mneut(j) * 
	d0(msmuL, msnue, mch(i), mneut(j));
      a1 = a1 + bChicNuSmul(i) * bChicNuSell(i).conj() *
	bChi0MuSmul(j).conj() * bChi0ESell(j) * 
	d27(msmuL, mselL, mch(i), mneut(j));
      a1 = a1 + aChicMuSnul(i).conj() * aChicESnul(i) *
	bChi0NuNul(j) * bChi0NuNul(j).conj() * 
	d27(msnumu, msnue, mch(i), mneut(j));
    } 

  double deltaVbSusy = 
    (-sqr(outsin) * sqr(outcos) / (2.0 * PI * alphaDRbar) * sqr(MZ)
     * a1.real() + deltaVE.real() + deltaVMu.real() + 
     0.5 * (deltaZe + deltaZnue + deltaZmu + deltaZnumu) ) /
    (sqr(PI) * 16.0); 

  double deltaVb = deltaVbSusy + deltaVbSm;

  double deltaR =  outrho * piWWT(0.0, displayMu()) / sqr(MW) 
    - pizztMZ / sqr(MZ) + deltaVb; 

  // Dominant two-loop SM term
  double deltaR2LoopSm = alphaDRbar * sqr(displayGaugeCoupling(3)) / 
    (16.0 * sqr(PI) * PI * sqr(outsin) * sqr(outcos)) *
    (2.145 * sqr(mt) / sqr(MZ) + 0.575 * log(mt / MZ) - 0.224 
     - 0.144 * sqr(MZ) / sqr(mt)) - 
    sqr(xt) * sqr(cos(displayPhys().thetaH)) / sqr(sinb) *
    rho2(displayPhys().mhiggs(1) / mt) * (1.0 - deltaR) * outrho / 3.0;
  
  deltaR = deltaR + deltaR2LoopSm; 
  
  double sin2thetasqO4 = PI * alphaDRbar / 
    (sqrt(2.0) * sqr(MZ) * GMU * (1.0 - deltaR)); 
  
  double sin2theta = sqrt(4.0 * sin2thetasqO4);
  
  if (fabs(sin2theta) > 1.0 || sin2thetasqO4 < 0.0) { 
    cout << 
      "\nWARNING: sin2thetasqO4=" << sin2thetasqO4 
	 << " in unphysical regime\n"; 
    exit(1); 
  }
  
  double theta = 0.5 * asin(sin2theta);
  
  outsin = sin(theta); 
  
  outrho = 1.0 / (1.0 - deltaRho);
  
  if (PRINTOUT > 2) cout << " drho=" << deltaRho << " sw=" << outsin << endl;

  rhohat(outrho, outsin, inrho, insin, alphaDRbar, tol, maxTries);
}

// Returns mixing matrix n and neutralino masses mneut in the MPZ convention
// (hep-ph/9606211), n is 4 by 4 and mneut is 1->4.
void MssmSoftsusy::mpzNeutralinos(ComplexMatrix & n, DoubleVector & mneut) const {
  // We want to change the PHASES of the neutralino mixing matrix in order to
  // produce POSITIVE neutralino masses, a la Matchev, Pierce and Zhang

  DoubleMatrix temp(displayPhys().mneut);
  
  ComplexMatrix K(4, 4);
  int i, j; for (i=1; i<=4; i++) 
    if (displayPhys().mneut(i) < 0.0) K(i, i) = Complex(0.0, 1.0);
    else
      K(i, i) = Complex(1.0, 0.0);
  
  mneut = displayPhys().mneut.apply(fabs);
  n = K.hermitianConjugate() * displayPhys().mixNeut.transpose();
}

// Returns mixing matrices u,v and neutralino masses mneut in the MPZ
// convention (hep-ph/9606211),  u+v are (2,2) and mch is 1->2.
void MssmSoftsusy::mpzCharginos(ComplexMatrix & u, ComplexMatrix & v,
				DoubleVector & mch) const {
  // We want to change the PHASES of the neutralino mixing matrix in order to
  // produce POSITIVE neutralino masses, a la Matchev, Pierce and Zhang
  positivise(displayPhys().thetaL, displayPhys().thetaR, displayPhys().mch,
	     u, v);
  mch = displayPhys().mch.apply(fabs); 
}
